/* (C) 2022 YiRing, Inc. */
package com.yiring.app.push.domain;

import com.alibaba.fastjson.JSONObject;
import com.vladmihalcea.hibernate.type.json.JsonBinaryType;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Objects;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.Hibernate;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.TypeDef;

/**
 * 推送消息日志
 *
 * @author Jim
 * @version 0.1
 * 2022/4/14 14:55
 */

@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@TypeDef(name = "jsonb", typeClass = JsonBinaryType.class)
@Table(
    name = "SYS_PUSH_MESSAGE",
    indexes = {
        @Index(columnList = "type"),
        @Index(columnList = "status"),
        @Index(columnList = "source"),
        @Index(columnList = "sourceId"),
        @Index(columnList = "target"),
        @Index(columnList = "targetId"),
        @Index(columnList = "pushTime"),
    }
)
@Comment("推送消息日志")
public class PushMessage extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 1478640364892356248L;

    @Comment("消息类型")
    @Enumerated(EnumType.STRING)
    Type type;

    @Comment("消息来源")
    String source;

    @Comment("消息来源标识")
    String sourceId;

    @Comment("消息目标")
    String target;

    @Comment("消息目标标识")
    String targetId;

    @Comment("消息内容")
    String content;

    @Comment("扩展数据")
    @org.hibernate.annotations.Type(type = "jsonb")
    @Column(columnDefinition = "jsonb")
    JSONObject extra;

    @Comment("消息状态")
    @Enumerated(EnumType.STRING)
    Status status;

    @Comment("推送反馈结果")
    @org.hibernate.annotations.Type(type = "jsonb")
    @Column(columnDefinition = "jsonb")
    JSONObject result;

    @Comment("重试次数")
    Integer retryCount;

    @Comment("推送时间")
    LocalDateTime pushTime;

    @SuppressWarnings({ "unused" })
    public enum Type {
        WEBHOOK("webhook"),
        APP("APP 消息"),
        SMS("短信消息"),
        EMAIL("邮件消息"),
        CALL_TTS("TTS 文本合成语音消息（电话）"),
        CALL_AUDIO("自定义音频消息（电话）"),
        DEVICE_TONE("自定义音频消息（音柱）");

        final String text;

        Type(String text) {
            this.text = text;
        }

        public String text() {
            return this.text;
        }

        public String queue() {
            return String.format("push.%s.queue", this.name().toLowerCase());
        }
    }

    @SuppressWarnings({ "unused" })
    public enum Status {
        SUCCESS("成功"),
        FAIL("失败");

        final String text;

        Status(String text) {
            this.text = text;
        }

        public String text() {
            return this.text;
        }
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || Hibernate.getClass(this) != Hibernate.getClass(o)) return false;
        PushMessage that = (PushMessage) o;
        return getId() != null && Objects.equals(getId(), that.getId());
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }
}
