/* (C) 2022 YiRing, Inc. */
package com.yiring.app.push.rabbitmq;

import com.yiring.app.push.domain.PushMessageRepository;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * rabbitmq配置
 *
 * @author ifzm
 * 2019/8/21 16:07
 */

@SuppressWarnings({ "unused" })
@Slf4j
@Component("PushRabbitReceiver")
@Transactional(rollbackFor = Exception.class)
public class PushRabbitReceiver {

    @Resource
    PushMessageRepository repository;

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_WEBHOOK_QUEUE)
    public void receiverWebHookMessage(Long id) {
        log.info("[WebHook] Message: " + id);
        repository.findById(id).ifPresent(message -> log.info("{}", message));
        // TODO
        // 实现调用 WebHook，基于 WebHook API 发起 HTTPs 请求
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_APP_QUEUE)
    public void receiverAppMessage(Long id) {
        log.info("[App] Message: " + id);
        // TODO
        // 实现推送消息到 App，基于个推 API
        // https://github.com/GetuiLaboratory/getui-pushapi-java-client-v2
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_SMS_QUEUE)
    public void receiverSmsMessage(Long id) {
        log.info("[SMS] Message: " + id);
        // TODO
        // 实现发送短信，基于阿里云短信平台 API
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_MAIL_QUEUE)
    public void receiverMailMessage(Long id) {
        log.info("[Mail] Message: " + id);
        // TODO
        // 实现发送邮件，基于邮件配置
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_CALL_TTS_QUEUE)
    public void receiverTtsMessage(Long id) {
        log.info("[Phone TTS] Message: " + id);
        // TODO
        // 实现拨打电话播放 TTS 转语音，基于壹润外呼系统 API
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_CALL_AUDIO_QUEUE)
    public void receiverAudioMessage(Long id) {
        log.info("[Phone Audio] Message: " + id);
        // TODO
        // 实现拨打电话播放音频文件，基于壹润外呼系统 API
    }

    @RabbitHandler
    @RabbitListener(queues = PushRabbitConfig.PUSH_DEVICE_TONE_QUEUE)
    public void receiverToneMessage(Long id) {
        log.info("[Device Tone] Message: " + id);
        // TODO
        // 实现播放设备铃声，基于音柱广播设备 API
        // SDK 暂未拿到，设备未采购，未进行联调
    }
}
