/* (C) 2022 YiRing, Inc. */
package com.yiring.app.push.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.yiring.app.push.domain.PushMessage;
import com.yiring.app.push.domain.PushMessageRepository;
import com.yiring.app.push.param.PushAppParam;
import com.yiring.app.push.rabbitmq.PushRabbitConfig;
import com.yiring.app.push.service.PushService;
import javax.annotation.Resource;
import javax.transaction.Transactional;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Service;

/**
 * 推送服务实现
 *
 * @author Jim
 * @version 0.1
 * 2022/4/14 16:08
 */

@Slf4j
@Service
@Transactional(rollbackOn = Exception.class)
public class PushServiceImpl implements PushService {

    @Resource
    PushMessageRepository repository;

    @Resource
    RabbitTemplate rabbitTemplate;

    @Override
    public void push(PushMessage.Type type, JSONObject raw) {
        PushMessage message = new PushMessage();
        message.setType(type);
        message.setExtra(raw);
        repository.saveAndFlush(message);

        rabbitTemplate.convertAndSend(PushRabbitConfig.PUSH_TOPIC_EXCHANGE, type.queue(), message.getId());
    }

    @Override
    public void app(PushAppParam param) {}
}
