/* (C) 2022 YiRing, Inc. */
package com.yiring.app.constant.alarm;

import com.yiring.app.vo.CodeNameVo;
import java.util.ArrayList;
import java.util.List;
import lombok.Getter;

/**
 * 围栏类别枚举
 * @author tml
 * @version 1.0
 * @date 2022/4/27 13:36
 */
public enum FenceTypeEnum {
    /**
     * 普通围栏
     */
    ORDINARY(1, "普通围栏"),

    /**
     * 特殊作业
     */
    SPECIAL(2, "特殊作业"),

    /**
     * 重大危险源
     */
    DANGEROUS(3, "重大危险源");

    private static final List<CodeNameVo> LIST;

    public static final int MIN = 1;

    public static final int MAX = 3;

    public static final int TOTAL = 3;

    static {
        LIST = new ArrayList<>();
        for (FenceTypeEnum item : values()) {
            LIST.add(CodeNameVo.builder().code(item.code).name(item.name).build());
        }
    }

    @Getter
    private final Integer code;

    @Getter
    private final String name;

    FenceTypeEnum(Integer code, String name) {
        this.code = code;
        this.name = name;
    }

    /**
     * 根据key获取value
     * @param code 围栏类别key
     * @return 围栏类别
     */
    public static String getByCode(Integer code) {
        if (code != null) {
            for (FenceTypeEnum item : values()) {
                if (item.code.equals(code)) {
                    return item.name;
                }
            }
        }
        return "未知围栏类别";
    }

    /**
     * 获取所有围栏类别
     * @return 所有围栏类别集合
     */
    public static List<CodeNameVo> getAll() {
        return LIST;
    }
}
