/* (C) 2022 YiRing, Inc. */
package com.yiring.app.constant.alarm;

import com.yiring.app.vo.CodeNameVo;
import java.util.ArrayList;
import java.util.List;
import lombok.Getter;

/**
 * 关联参数枚举
 * @author tml
 * @version 1.0
 * @date 2022/4/27 13:43
 */
public enum RelevanceParamEnum {
    /**
     * 最大人数
     */
    MAX_PEOPLE_NUMBER(1, "最多人数"),

    /**
     * 最小人数
     */
    MIN_PEOPLE_NUMBER(2, "最少人数"),

    /**
     * 允许进入人员
     */
    ALLOW_ENTRANCE(3, "允许进入人员"),

    /**
     * 不允许离开人员
     */
    NOT_ALLOW_LEAVE(4, "不允许离开人员"),

    /**
     * 静止时长
     */
    STATIC_DURATION(5, "静止时长(分钟)"),

    /**
     * 滞留时长
     */
    RETENTION_DURATION(6, "滞留时长(分钟)"),

    /**
     * 触发报警距离
     */
    TRIGGER_ALARM_DISTANCE(7, "触发报警距离");

    private static final List<CodeNameVo> LIST;

    public static final int MIN = 1;

    public static final int MAX = 7;

    public static final int TOTAL = 7;

    static {
        LIST = new ArrayList<>();
        for (RelevanceParamEnum item : values()) {
            LIST.add(CodeNameVo.builder().code(item.code).name(item.name).build());
        }
    }

    @Getter
    private final Integer code;

    @Getter
    private final String name;

    RelevanceParamEnum(Integer code, String name) {
        this.code = code;
        this.name = name;
    }

    /**
     * 根据key获取value
     * @param code 关联参数key
     * @return 关联参数
     */
    public static String getByCode(Integer code) {
        if (code != null) {
            for (RelevanceParamEnum item : values()) {
                if (item.code.equals(code)) {
                    return item.name;
                }
            }
        }
        return "未知关联参数";
    }

    /**
     * 获取所有关联参数
     * @return 所有关联参数集合
     */
    public static List<CodeNameVo> getAll() {
        return LIST;
    }
}
