/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.check.fence;

import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.design.check.IParamInitStrategy;
import com.yiring.app.param.location.rule.LocationFenceRuleAddParam;
import com.yiring.common.core.Result;
import java.util.concurrent.ConcurrentHashMap;
import lombok.extern.slf4j.Slf4j;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/29 11:09
 */
@Slf4j
public class LocationFenceTypeContext {

    private final IParamInitStrategy<LocationFenceRuleAddParam> checkStrategy;

    private static final ConcurrentHashMap<Integer, IParamInitStrategy<LocationFenceRuleAddParam>> FENCE_TYPE_MAP = new ConcurrentHashMap<>(
        4
    );

    public static void register(Integer relevanceParam, IParamInitStrategy<LocationFenceRuleAddParam> strategy) {
        FENCE_TYPE_MAP.put(relevanceParam, strategy);
    }

    public LocationFenceTypeContext(Integer relevanceParam) {
        if (relevanceParam == null || relevanceParam > FenceTypeEnum.MAX || relevanceParam < FenceTypeEnum.MIN) {
            log.warn("报警类型的关联参数异常, relevanceParam:[{}]", relevanceParam);
            throw new RuntimeException("报警类型的关联参数异常");
        }
        IParamInitStrategy<LocationFenceRuleAddParam> strategy = FENCE_TYPE_MAP.get(relevanceParam);
        if (strategy == null) {
            strategy = FENCE_TYPE_MAP.get(0);
        }
        this.checkStrategy = strategy;
    }

    public Result<String> paramInit(LocationFenceRuleAddParam param) {
        return checkStrategy.paramInit(param);
    }
}
