/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.check.rule;

import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.design.check.IParamInitStrategy;
import com.yiring.app.design.check.fence.LocationFenceTypeContext;
import com.yiring.app.param.location.rule.LocationFenceRuleAddParam;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import java.util.concurrent.ConcurrentHashMap;
import lombok.extern.slf4j.Slf4j;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/29 9:36
 */
@Slf4j
public class LocationFenceRuleContext {

    private final IParamInitStrategy<LocationFenceRuleAddParam> checkStrategy;

    private static final ConcurrentHashMap<Integer, IParamInitStrategy<LocationFenceRuleAddParam>> RULE_MAP = new ConcurrentHashMap<>(
        10
    );

    public static void register(Integer relevanceParam, IParamInitStrategy<LocationFenceRuleAddParam> strategy) {
        RULE_MAP.put(relevanceParam, strategy);
    }

    public LocationFenceRuleContext(Integer relevanceParam) {
        if (
            relevanceParam == null || relevanceParam > RelevanceParamEnum.MAX || relevanceParam < RelevanceParamEnum.MIN
        ) {
            log.warn("报警类型的关联参数异常, relevanceParam:[{}]", relevanceParam);
            throw new RuntimeException("报警类型的关联参数异常");
        }
        this.checkStrategy = RULE_MAP.get(relevanceParam);
    }

    public Result<String> paramInit(LocationFenceRuleAddParam param) {
        Result<String> result = new LocationFenceTypeContext(param.getFenceType()).paramInit(param);
        if (Status.OK.value() != result.getStatus()) {
            return result;
        }
        return checkStrategy.paramInit(param);
    }
}
