/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.check.rule;

import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.design.check.IParamInitStrategy;
import com.yiring.app.param.location.rule.*;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import java.util.ArrayList;
import java.util.List;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

/**
 * 最多人数校验
 * @author tml
 * @version 1.0
 * @date 2022/4/29 9:28
 */
@Component
public class MaxPeopleNumberStrategy implements IParamInitStrategy<LocationFenceRuleAddParam> {

    public MaxPeopleNumberStrategy() {
        Integer relevanceParam = RelevanceParamEnum.MAX_PEOPLE_NUMBER.getCode();
        LocationFenceRuleContext.register(relevanceParam, this);
    }

    @Override
    public Result<String> paramInit(LocationFenceRuleAddParam param) {
        RuleParam ruleParam = param.getRuleParam();
        List<TimeAndNumberParam> timeAndNumber = ruleParam.getTimeAndNumber();
        if (CollectionUtils.isEmpty(timeAndNumber)) {
            return Result.no(Status.EXPECTATION_FAILED, "请至少配置一条最多人数的规则");
        }
        for (TimeAndNumberParam item : timeAndNumber) {
            if (item.getNumber() == null || item.getNumber() < 0) {
                item.setNumber(0);
            }
            if (item.getBeginTime() == null || item.getEndTime() == null) {
                item.setBeginTime(null);
                item.setEndTime(null);
            }
        }
        //将时间和距离都设为-1
        ruleParam.setDuration(-1);
        ruleParam.setDistance(-1);
        ArrayList<TimeAndUserParam> list = new ArrayList<>();
        ruleParam.setTimeAndUser(list);
        return Result.ok();
    }
}
