/* (C) 2022 YiRing, Inc. */
package com.yiring.app.design.check.rule;

import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.design.check.IParamInitStrategy;
import com.yiring.app.param.location.rule.LocationFenceRuleAddParam;
import com.yiring.app.param.location.rule.RuleParam;
import com.yiring.app.param.location.rule.TimeAndUserParam;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import java.util.ArrayList;
import java.util.List;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/29 9:32
 */
@Component
public class NotAllowLeaveStrategy implements IParamInitStrategy<LocationFenceRuleAddParam> {

    public NotAllowLeaveStrategy() {
        Integer relevanceParam = RelevanceParamEnum.NOT_ALLOW_LEAVE.getCode();
        LocationFenceRuleContext.register(relevanceParam, this);
    }

    @Override
    public Result<String> paramInit(LocationFenceRuleAddParam param) {
        RuleParam ruleParam = param.getRuleParam();
        List<TimeAndUserParam> timeAndUser = ruleParam.getTimeAndUser();
        if (CollectionUtils.isEmpty(timeAndUser)) {
            return Result.no(Status.EXPECTATION_FAILED, "请至少配置一条不允许离开人员的规则");
        }
        for (TimeAndUserParam item : timeAndUser) {
            if (CollectionUtils.isEmpty(item.getUser())) {
                return Result.no(Status.EXPECTATION_FAILED, "请至少配置一个不允许离开的人员");
            }
        }
        ruleParam.setDuration(-1);
        ruleParam.setDistance(-1);
        ruleParam.setTimeAndNumber(new ArrayList<>());
        return Result.ok();
    }
}
