/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.broadcast;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.CreationTimestamp;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.UpdateTimestamp;
import org.hibernate.snowflake.SnowflakeId;
import org.locationtech.jts.geom.Point;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/5 17:06
 */
@Getter
@Setter
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Comment("播报设备表")
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_BROADCAST")
public class Broadcast implements Serializable {

    @Serial
    private static final long serialVersionUID = 2856845594409003209L;

    @Comment("编号")
    @Id
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("播报设备编号")
    String broadcastNum;

    @Comment("播报设备名称")
    String broadcastName;

    @Comment("坐标点信息")
    Point point;

    @Comment("播报设备地址")
    String broadcastAdd;

    @Comment("备注")
    String remark;

    @Comment("是否启用")
    String status;

    @Comment("创建时间")
    @CreationTimestamp
    LocalDateTime createTime;

    @Comment("修改时间")
    @UpdateTimestamp
    LocalDateTime updateTime;
}
