/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.district;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Type;
import org.hibernate.annotations.Where;
import org.hibernate.snowflake.SnowflakeId;
import org.locationtech.jts.geom.Geometry;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.annotation.LastModifiedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/26 11:44
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Entity
@Where(clause = "deleted = false")
@Table(name = "BS_District")
@Comment("区域信息")
@EntityListeners(AuditingEntityListener.class)
public class District implements Serializable {

    @Serial
    private static final long serialVersionUID = -1469002957843445743L;

    @Id
    @Comment("主键id")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    private Long id;

    @Comment("区域信息名称")
    private String name;

    @Comment("风险等级")
    private String riskGrade;

    @Comment("消抖时间(秒)")
    private Integer debouncingDuration;

    @Comment("超时时间(秒)")
    private Integer timeoutDuration;

    @Comment("区域信息")
    @Type(type = "jts_geometry")
    @Column(columnDefinition = "geometry")
    private Geometry geometry;

    @Comment("创建时间")
    @CreatedDate
    @Column(nullable = false)
    private LocalDateTime createTime;

    @Comment("最后修改时间")
    @LastModifiedDate
    @Column(nullable = false)
    private LocalDateTime lastUpdateTime;

    @Comment(value = "是否删除")
    @Column(nullable = false)
    Boolean deleted;
}
