/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.district;

import java.io.Serializable;
import java.util.List;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/26 13:59
 */
@Repository
public interface DistrictRepository extends JpaRepository<District, Serializable>, JpaSpecificationExecutor<District> {
    /**
     * 查询名称是否存在
     * @param name 区域名称
     * @return true:存在 false:不存在
     */
    Boolean existsByName(String name);

    /**
     * 根据名称查询区域信息列表
     * @param name 区域名称
     * @return 区域列表
     */
    List<District> findAllByName(String name);

    /**
     * 根据名称模糊查询区域信息
     * @param name 名称
     * @return 区域列表
     */
    @Query("SELECT d FROM District d WHERE d.name like %?1%")
    List<District> findLikeName(String name);
}
