/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.key;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.user.User;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;

/**
 * 按键报警规则
 *
 * @author LJ-2204
 * @date 2022/5/6
 */

@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_KEY_ALARM_RULES")
@Comment("按键报警规则")
public class KeyAlarmRules extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = -302167871277966250L;

    @Comment("所属部门")
    @ManyToOne
    @JsonIgnore
    @JoinColumn(name = "department_id")
    Department department;

    @JsonIgnore
    @Builder.Default
    @Comment("用户集合")
    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(
        name = "BS_KEY_ALARM_RULES_USERS",
        joinColumns = { @JoinColumn(name = "key_id") },
        inverseJoinColumns = { @JoinColumn(name = "user_id") }
    )
    Set<User> users = new HashSet<>(0);

    @Comment("推送类型")
    String types;
}
