/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.auth.domain.user.User;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.util.Set;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.Where;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/5 14:25
 */
@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Where(clause = "deleted = false")
@Entity
@Table(name = "BS_LOCATION_ALARM_RULE")
@Comment("电子围栏的报警规则")
public class LocationAlarmRule extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = -2268859882881201793L;

    @Comment("地图ID")
    private Long mapId;

    @Comment("地图名称")
    private String mapName;

    @Comment("电子围栏")
    @ManyToOne
    @JoinColumn(name = "fence_id")
    private LocationFence locationFence;

    @Comment("接收人集合")
    @ManyToMany
    @ToString.Exclude
    private Set<User> users;

    @Comment("通知方式")
    private String informManner;

    @Comment("报警类型")
    @ManyToOne
    @JoinColumn(name = "alarm_type_id")
    private AlarmType alarmType;

    @Comment(value = "是否删除")
    @Column(nullable = false)
    Boolean deleted;
}
