/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.yiring.common.annotation.FieldMapping;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.locationtech.jts.geom.Point;

/**
 * 定位信标
 * 引用:
 *  1. 查询地图分区（定位系统）, <a href="https://nl.yz-cloud.com/position/area/list">https://nl.yz-cloud.com/position/area/list</a>
 *  2. 查询信标点（定位系统）, <a href="https://nl.yz-cloud.com/position/config/point/list">https://nl.yz-cloud.com/position/config/point/list</a>
 *
 * @author Jim
 * @version 0.1
 * 2022/4/7 11:02
 */

@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(
    name = "BS_LOCATION_BEACON",
    indexes = { @Index(columnList = "linkId"), @Index(columnList = "code", unique = true) }
)
@Comment("定位信标")
public class LocationBeacon extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 5419734189897829250L;

    /**
     * 数据来源于【真源人员定位系统 - 定位信标】
     * 作用: 用于双向联动进行数据同步
     */
    @FieldMapping("id")
    @Comment("外链主键")
    Long linkId;

    @Comment("地图 ID")
    Long areaId;

    /**
     * 前缀: BTI
     * 后缀: 8 位数字
     */
    @FieldMapping("deviceId")
    @Comment("编号")
    @Column(unique = true, nullable = false)
    String code;

    @Comment("x")
    BigDecimal x;

    @Comment("y")
    BigDecimal y;

    @Comment("z")
    BigDecimal z;

    @Comment("距离（米）")
    Double distance;

    @Comment("坐标点信息")
    Point point;

    @FieldMapping
    @Comment("电量")
    Integer volt;

    @FieldMapping
    @Comment("电量单位")
    String voltUnit;

    @Comment("状态更新时间")
    LocalDateTime time;

    @Comment("围栏集合")
    @Builder.Default
    @ManyToMany
    @ToString.Exclude
    Set<LocationFence> fences = new HashSet<>(0);
}
