/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.yiring.app.domain.video.Video;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.Type;
import org.hibernate.annotations.Where;
import org.locationtech.jts.geom.Geometry;

/**
 * 围栏
 * 引用: 定位平台接口规范V3.0.1 #7.1
 *
 * @author Jim
 * @version 0.1
 * 2022/4/7 16:26
 */

@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Where(clause = "deleted = false")
@Entity
@Table(name = "BS_LOCATION_FENCE")
@Comment("围栏")
public class LocationFence extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 4155868702188991300L;

    @Comment("围栏名称")
    private String name;

    @Comment("地图ID")
    private Long mapId;

    @Comment("地图名称")
    private String mapName;

    @Comment("摄像头")
    @ManyToOne
    @JoinColumn(name = "video_id")
    private Video video;

    @Comment("围栏类别")
    private Integer fenceType;

    @Comment("空间信息")
    @Type(type = "jts_geometry")
    @Column(columnDefinition = "geometry")
    private Geometry geometry;

    @Comment("滞留时间(秒)")
    private Integer residenceTime;

    @Comment("消抖时间(秒)")
    private Integer threshold;

    @Comment("是否启用")
    private Boolean enable;

    @Comment(value = "是否删除")
    @Column(nullable = false)
    Boolean deleted;

    @Comment("信标集合")
    @Builder.Default
    @ManyToMany
    @ToString.Exclude
    private Set<LocationBeacon> beacons = new HashSet<>(0);

    @Comment("围栏规则集合")
    @Builder.Default
    @OneToMany(mappedBy = "fence")
    @ToString.Exclude
    private Set<LocationFenceRule> rules = new HashSet<>(0);
    /*@SuppressWarnings({ "unused" })
    public enum Mode {
        NORMAL("常规区域"),
        DANGER("危险源区域");

        @Getter
        final String text;

        Mode(String text) {
            this.text = text;
        }
    }*/
}
