/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import java.io.Serializable;
import java.util.List;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 13:48
 */
@Repository
public interface LocationFenceRepository
    extends JpaRepository<LocationFence, Serializable>, JpaSpecificationExecutor<LocationFence> {
    /**
     * 查询名称是否存在
     * @param name 围栏名称
     * @return true:存在 false:不存在
     */
    Boolean existsByName(String name);

    /**
     * 根据名称查询围栏信息
     * @param name 围栏名称
     * @return 围栏信息
     */
    List<LocationFence> findAllByName(String name);

    /**
     * 根据名称模糊查询围栏信息
     * @param name 围栏名称
     * @return 围栏信息
     */
    @Query("SELECT f FROM LocationFence f WHERE name like %?1%")
    List<LocationFence> findLikeName(String name);
}
