/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.vladmihalcea.hibernate.type.json.JsonBinaryType;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.Type;
import org.hibernate.annotations.TypeDef;
import org.locationtech.jts.geom.Point;

/**
 * 定位数据
 * 引用: 定位平台接口规范V3.0.1 #6
 * TODO:
 *  1. 实时数据日志的存储结构 TimeScale: 时间粒度，每天一个分区
 *      eg: SELECT create_hypertable('BS_LOCATION_LOG', 'time', chunk_time_interval => INTERVAL '1 day')
 *
 * @author Jim
 * @version 0.1
 * 2022/4/7 10:21
 */

@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@TypeDef(name = "jsonb", typeClass = JsonBinaryType.class)
@Table(name = "BS_LOCATION_LOG", indexes = { @Index(name = "idx_time", columnList = "time") })
@Comment("定位数据")
public class LocationLog implements Serializable {

    @Serial
    private static final long serialVersionUID = 3467455881020691989L;

    @Comment("定位标签时序复合主键")
    @EmbeddedId
    TagTimeId id;

    @Comment("地图 ID")
    Long areaId;

    @Comment("楼层")
    String floor;

    /**
     * 来源于定位数据产生时刻标签所属的人员
     */
    @Comment("用户")
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "user_id")
    User user;

    /**
     * 来源于定位标签定位时刻的人员状态
     */
    @Comment("用户状态")
    User.Status status;

    @Comment("坐标点信息")
    Point point;

    @Comment("信标集合")
    @Type(type = "jsonb")
    @Column(columnDefinition = "jsonb")
    JSONArray beacons;

    @Comment("围栏集合")
    @Type(type = "jsonb")
    @Column(columnDefinition = "jsonb")
    JSONArray fences;

    @Comment("静止/运动")
    Boolean silent;

    @Comment("电量")
    Integer volt;

    @Comment("电量单位")
    String voltUnit;

    @Comment("原始数据")
    @Type(type = "jsonb")
    @Column(columnDefinition = "jsonb")
    JSONObject raw;

    @Comment("定位时间")
    LocalDateTime locationTime;
}
