/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.video;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.snowflake.SnowflakeId;
import org.locationtech.jts.geom.Point;

/**
 * 监控视频
 *
 * @author Jim
 * @version 0.1
 * 2022/4/8 10:17
 */

@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_VIDEO", indexes = { @Index(columnList = "online"), @Index(columnList = "enable") })
@Comment("监控视频")
public class Video implements Serializable {

    @Serial
    private static final long serialVersionUID = -4382898847143469396L;

    @Comment("主键")
    @Id
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("坐标点信息")
    Point point;

    @Comment("标识")
    String uuid;

    @Comment("m3u8 地址")
    String m3u8;

    @Comment("备注")
    String remark;

    @Comment("创建时间")
    LocalDateTime createTime;

    @Comment("状态")
    String status;

    @Comment("摄像头名称")
    String videoName;

    @Comment("分类")
    String type;

    @Comment("rtsp 媒体地址")
    String rtsp;

    @Comment("是否在线")
    Boolean online;

    @Comment("是否启用")
    Boolean enable;
}
