/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.snowflake.SnowflakeId;

/**
 * 邀请管理
 *
 * @author Administrator
 * @version 1.0
 * @description: 邀请信息实体
 * @date 2022/4/24 16:43
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@DynamicInsert
@DynamicUpdate
@Table(name = "BS_INVITATION")
@Comment("邀请信息")
public class Invitation implements Serializable {

    @Serial
    private static final long serialVersionUID = -1330887992216252468L;

    @Id
    @Comment("主键id")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("邀请方式")
    String InvitationMethod;

    @Comment("状态")
    String status;

    //    @Comment("邀请人id")
    //    Long inviterId;

    @Comment("邀请人数")
    Integer numOfVisitor;

    @Comment("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime createTime;

    @Comment("修改时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime updateTime;

    //    @Comment("访客id")
    //    Long visitorId;

    @Comment("被邀请访客")
    @JsonIgnore
    @OneToOne(cascade = CascadeType.REMOVE)
    @JoinColumn(name = "visitor_id", referencedColumnName = "id")
    Visitor visitor;

    @Comment("邀请人")
    @JsonIgnore
    @OneToOne
    @JoinColumn(name = "inviter_id", referencedColumnName = "id")
    User user;
}
