/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.Table;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.*;
import org.hibernate.snowflake.SnowflakeId;

/**
 * @author tzl
 * 2022/4/19 11:41
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@DynamicInsert
@DynamicUpdate
@Table(name = "BS_VISITOR")
@Comment("访客信息")
public class Visitor implements Serializable {

    @Serial
    private static final long serialVersionUID = -7367226565168197562L;

    @Id
    @Comment("主键")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("到访人姓名")
    String visitorName;

    @Comment("到访人电话")
    String visitorMobile;

    @Comment("到访人身份证")
    String visitorCarNum;

    @Comment("是否特殊作业")
    String taskType;

    //    @Comment("邀请人数")
    //    Integer numOfVisitor;

    @Comment("访客来源")
    String visitorSource;

    @Comment("标签卡")
    String labelCard;

    @Comment("标签卡状态")
    String labelCardStatus;

    @Comment("所属单位id")
    String orgId;

    //    @Comment("被访人id")
    //    Long intervieweeId;

    @Comment("来访原因/邀请原因")
    String reason;

    @Comment("收卡时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardRecTime;

    @Comment("预约到访时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime appOfVisitTime;

    @Comment("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime createTime;

    @Comment("发卡时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardSendTime;

    @Comment("备用字段")
    Long reserve1;

    @Comment("是否已删除:Y是 N否")
    @Column(columnDefinition = "VARCHAR DEFAULT 'N'")
    String deleted;

    @Comment("主访人员id")
    Long mainVisitorId;

    @Comment("备用字段")
    String reserve3;

    @Comment("访客车辆")
    @OneToOne(cascade = { CascadeType.ALL })
    Car car;

    @Comment("被访人信息")
    @OneToOne
    @JoinColumn(name = "interviewee_id", referencedColumnName = "id")
    User user;

    @Comment("修改时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime updateTime;
    //        @Comment("邀请人")
    //        @OneToOne(cascade = { CascadeType.ALL })
    //        @JoinColumn(name = "main_visitor_id", referencedColumnName = "id")
    //        Visitor visitor;
}
