/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.alarm;

import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.domain.alarm.AlarmType;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/27 16:44
 */
@ExcelModel
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class AlarmTypeExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = -2986256700153819605L;

    @ExcelColumn(title = "名称")
    private String name;

    @ExcelColumn(title = "围栏类别")
    private String fenceType;

    @ExcelColumn(title = "关联参数")
    private String relevanceParam;

    @ExcelColumn(title = "备注", width = 15)
    private String comment;

    public static List<AlarmTypeExcel> transforms(List<AlarmType> alarmTypeList) {
        return alarmTypeList.stream().map(AlarmTypeExcel::transform).collect(Collectors.toList());
    }

    public static AlarmTypeExcel transform(AlarmType alarmType) {
        return AlarmTypeExcel
            .builder()
            .name(alarmType.getName())
            .fenceType(FenceTypeEnum.getByCode(alarmType.getFenceType()))
            .relevanceParam(RelevanceParamEnum.getByCode(alarmType.getRelevanceParam()))
            .comment(alarmType.getComment())
            .build();
    }
}
