/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.alarm;

import com.yiring.app.domain.alarm.AlarmType;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/27 11:28
 */
@ApiModel("AlarmTypeModifyParam(报警类型修改param)")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class AlarmTypeModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 6124966765550463652L;

    @ApiModelProperty(value = "报警类型id", example = "1", required = true)
    @NotNull(message = "报警类型id不能为空")
    private Long id;

    @ApiModelProperty(value = "报警类型名称", example = "超员报警", required = true)
    @NotEmpty(message = "报警类型名称不能为空")
    @Length(max = 10, message = "区域名称不能超过10个字符")
    private String name;

    @ApiModelProperty(value = "围栏类别", example = "1", required = true)
    @NotNull(message = "围栏类别不能为空")
    private Integer fenceType;

    @ApiModelProperty(value = "关联参数", example = "1", required = true)
    @NotNull(message = "关联参数不能为空")
    private Integer relevanceParam;

    @ApiModelProperty(value = "备注", example = "超员报警备注")
    @Length(max = 255, message = "区域名称不能超过10个字符")
    private String comment;

    public AlarmType transform() {
        return AlarmType
            .builder()
            .id(id)
            .name(name)
            .fenceType(fenceType)
            .relevanceParam(relevanceParam)
            .comment(comment)
            .deleted(false)
            .build();
    }
}
