/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.district;

import com.yiring.app.domain.district.District;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.*;
import org.hibernate.validator.constraints.Length;
import org.locationtech.jts.geom.Geometry;

/**
 *
 * @author tml
 * @version 1.0
 * @date 2022/4/26 10:40
 */
@ApiModel("DistrictAddParam(添加区域param)")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class DistrictAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 2936786907836076236L;

    @ApiModelProperty(value = "区域名称", example = "工作区域", required = true)
    @NotEmpty(message = "区域名称不能为空")
    @Length(max = 10, message = "区域名称不能超过10个字符")
    private String name;

    @ApiModelProperty(value = "风险等级", example = "1", required = true)
    @NotEmpty(message = "风险等级不能为空")
    @Length(min = 6, max = 7, message = "请选择正确的颜色")
    private String riskGrade;

    @ApiModelProperty(value = "消抖时间(秒)", example = "10", required = true)
    @NotNull(message = "消抖时间不能为空")
    private Integer debouncingDuration;

    @ApiModelProperty(value = "超时时间(秒)", example = "100", required = true)
    @NotNull(message = "超时时间不能为空")
    private Integer timeoutDuration;

    @ApiModelProperty(value = "区域信息", example = "100", required = true)
    @NotNull(message = "区域信息不能为空")
    private Geometry geometry;

    public District transform() {
        return District
            .builder()
            .name(name)
            .deleted(false)
            .riskGrade(riskGrade)
            .debouncingDuration(debouncingDuration)
            .timeoutDuration(timeoutDuration)
            .geometry(geometry)
            .build();
    }
}
