/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.location.beacon;

import com.yiring.app.domain.location.LocationBeacon;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 定位信标
 *
 * @author LJ-2204
 * @date 2022/4/28
 */

@ApiModel("LocationBeaconAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationBeaconAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -3955765845330886658L;

    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "地图", example = "BTI88888888")
    Long areaId;

    @ApiModelProperty(value = "编号", example = "BTI22085224")
    String deviceId;

    @ApiModelProperty(value = "x", example = "661.6708034161")
    BigDecimal x;

    @ApiModelProperty(value = "y", example = "64.609831996")
    BigDecimal y;

    @ApiModelProperty(value = "z", example = "0")
    BigDecimal z;

    @ApiModelProperty
    LocalDateTime time;

    @ApiModelProperty(value = "电量", example = "2900")
    Integer volt;

    @ApiModelProperty(value = "电量单位", example = "mv")
    String voltUnit;

    public static LocationBeacon transform(LocationBeaconAddParam locationBeaconAddParam) {
        return LocationBeacon
            .builder()
            .linkId(locationBeaconAddParam.getId())
            .areaId(locationBeaconAddParam.getAreaId())
            .code(locationBeaconAddParam.getDeviceId())
            .x(locationBeaconAddParam.getX())
            .y(locationBeaconAddParam.getY())
            .z(locationBeaconAddParam.getZ())
            //            .point(GeoUtils.xyzToPoint(
            //                locationBeaconAddParam.getPointX().doubleValue(),locationBeaconAddParam.getPointY().doubleValue(),locationBeaconAddParam.getPointZ().doubleValue()
            //            ))
            .time(locationBeaconAddParam.getTime())
            .volt(locationBeaconAddParam.getVolt())
            .voltUnit(locationBeaconAddParam.getVoltUnit())
            .build();
    }
}
