/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.location.fence;

import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.domain.location.LocationFence;
import com.yiring.app.domain.video.Video;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;
import org.hibernate.validator.constraints.Range;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 10:52
 */
@ApiModel("LocationFenceAddParam(添加围栏信息的param)")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class LocationFenceAddParam {

    @ApiModelProperty(value = "围栏名称", example = "1")
    @NotEmpty(message = "围栏名称不能为空")
    @Length(max = 10, message = "围栏名称不能超过10个字符")
    private String name;

    @ApiModelProperty(value = "地图ID", example = "1")
    @NotNull(message = "地图不能为空")
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "1")
    @NotNull(message = "地图名称不能为空")
    private String mapName;

    @ApiModelProperty(value = "摄像头ID", example = "1")
    @NotNull(message = "关联摄像头不能为空")
    private Long videoId;

    @ApiModelProperty(value = "围栏类别", example = "1")
    @NotNull(message = "围栏类别不能为空")
    @Range(min = FenceTypeEnum.MIN, max = FenceTypeEnum.MAX, message = "请选择正确的围栏类别")
    private Integer fenceType;

    @ApiModelProperty(value = "空间信息", example = "1")
    @NotNull(message = "区域信息不能为空")
    private Geometry geometry;

    @ApiModelProperty(value = "滞留时间(秒)", example = "1")
    @NotNull(message = "滞留时间不能为空")
    private Integer residenceTime;

    @ApiModelProperty(value = "消抖时间(秒)", example = "1")
    @NotNull(message = "消抖时间不能为空")
    private Integer threshold;

    public LocationFence transform() {
        Video video = Video.builder().id(videoId).build();
        return LocationFence
            .builder()
            .name(name)
            .mapId(mapId)
            .mapName(mapName)
            .video(video)
            .fenceType(fenceType)
            .geometry(geometry)
            .residenceTime(residenceTime)
            .threshold(threshold)
            .enable(false)
            .deleted(false)
            .build();
    }
}
