/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.location.rule;

import com.alibaba.fastjson.JSON;
import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.domain.location.LocationAlarmRule;
import com.yiring.app.domain.location.LocationFence;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/5 15:41
 */
@ApiModel("修改配置报警类别的报警规则")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class LocationAlarmRuleModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 388296602724939033L;

    @ApiModelProperty(value = "id", example = "1", required = true)
    @NotEmpty(message = "规则id不能为空")
    private Long id;

    @ApiModelProperty(value = "地图id", example = "1", required = true)
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "一层", required = true)
    private String mapName;

    @ApiModelProperty(value = "报警类型id", example = "1", required = true)
    @NotNull(message = "报警类型id不能为空")
    private Long alarmId;

    @ApiModelProperty(value = "电子围栏id", example = "1", required = true)
    private Long fenceId;

    @ApiModelProperty(value = "接收人集合", required = true)
    private Set<Long> users;

    @ApiModelProperty(value = "通知方式集合", required = true)
    private Set<Integer> informManner;

    public LocationAlarmRule transform() {
        LocationFence locationFence = LocationFence.builder().id(fenceId).build();
        HashSet<User> set = new HashSet<>();
        for (Long item : this.users) {
            set.add(User.builder().id(item).build());
        }
        AlarmType alarmType = AlarmType.builder().id(alarmId).build();
        String json = JSON.toJSONString(informManner);
        return LocationAlarmRule
            .builder()
            .id(id)
            .mapId(mapId)
            .mapName(mapName)
            .locationFence(locationFence)
            .users(set)
            .alarmType(alarmType)
            .informManner(json)
            .deleted(false)
            .build();
    }
}
