/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.location.rule;

import com.alibaba.fastjson.JSON;
import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.domain.location.LocationFence;
import com.yiring.app.domain.location.LocationFenceRule;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Range;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 16:16
 */
@ApiModel("添加配置报警类别的报警规则,根据不同类型传入不同参数")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class LocationFenceRuleAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -7774789748161552583L;

    @ApiModelProperty(value = "所属的围栏id", example = "1", required = true)
    @NotNull(message = "所属的围栏id不能为空")
    private Long fenceId;

    @ApiModelProperty(value = "所属的围栏类别", example = "1", required = true)
    @NotNull(message = "所属的围栏类别不能为空")
    private Integer fenceType;

    @ApiModelProperty(value = "所属的报警类别id", example = "1", required = true)
    @NotNull(message = "所属的报警类别id不能为空")
    private Long alarmTypeId;

    @ApiModelProperty(value = "设置的关联参数类型", example = "1", required = true)
    @NotNull(message = "所属的关联参数类别不能为空")
    @Range(min = RelevanceParamEnum.MIN, max = RelevanceParamEnum.MAX, message = "关联参数类别异常")
    private Integer relevanceParamType;

    @NotNull(message = "所属的规则不能为空")
    private RuleParam ruleParam;

    public LocationFenceRule transform() {
        LocationFence locationFence = LocationFence.builder().id(fenceId).fenceType(fenceType).build();
        AlarmType alarmType = AlarmType.builder().id(alarmTypeId).relevanceParam(relevanceParamType).build();
        String rule = JSON.toJSONString(ruleParam);
        return LocationFenceRule
            .builder()
            .fence(locationFence)
            .relevanceParamType(relevanceParamType)
            .alarmType(alarmType)
            .rule(rule)
            .deleted(false)
            .build();
    }
}
