/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.location.tag;

import com.yiring.app.domain.location.LocationTag;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 定位标签新增入参
 * @author LJ-2204
 * @date 2022/4/14
 */

@ApiModel("LocationTagAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationTagAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -2942040230386389302L;

    @ApiModelProperty(value = "编号", example = "BTT88888888", required = true)
    @NotNull
    String code;

    @ApiModelProperty(value = "标签类型", example = "蓝牙人员定位卡", required = true)
    @NotNull
    LocationTag.Type type;

    @ApiModelProperty(value = "imei 设备编码标识", example = "88888888")
    String imei;

    public static LocationTag transform(LocationTagAddParam locationTagAddParam) {
        return LocationTag
            .builder()
            .code(locationTagAddParam.getCode())
            .type(locationTagAddParam.getType())
            .imei(locationTagAddParam.getImei())
            .used(false)
            .silent(false)
            .volt(0)
            .createTime(LocalDateTime.now())
            .updateTime(LocalDateTime.now())
            .build();
    }
}
