/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.post;

import cn.hutool.core.date.LocalDateTimeUtil;
import com.yiring.auth.domain.post.Post;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 职位修改
 *
 * @author LJ-2204
 * @date 2022/4/25
 */

@ApiModel("PostModifyParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PostModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 9182648236336186660L;

    @ApiModelProperty(value = "主键", example = "1", required = true)
    @NotNull(message = "编号不能为空")
    Long id;

    @ApiModelProperty(value = "名称", example = "Java", required = true)
    @NotNull(message = "名称不能为空")
    String name;

    @ApiModelProperty(value = "描述", example = "描述")
    String describe;

    @ApiModelProperty(value = "是否启用", example = "true")
    Boolean enable;

    public void transform(PostModifyParam postParam, Post post) {
        post.setName(postParam.getName());
        post.setDescribe(postParam.getDescribe());
        post.setEnable(postParam.getEnable());
        post.setUpdateTime(LocalDateTimeUtil.now());
    }
}
