/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.user;

import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户新增入参
 *
 * @author LJ-2204
 * @date 2022/4/25
 */

@ApiModel("UserAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -4976674015255774601L;

    @ApiModelProperty(value = "头像", example = "url")
    String avatar;

    @ApiModelProperty(value = "真实姓名", example = "张三", required = true)
    String realName;

    @ApiModelProperty(value = "电话", example = "1888888888", required = true)
    String mobile;

    @ApiModelProperty(value = "图标类型", example = "EMPLOYEES人员、GUEST访客", required = true)
    User.Type type;

    @ApiModelProperty(value = "性别", example = "0/1")
    Boolean gender;

    @ApiModelProperty(value = "归属部门", example = "1", required = true)
    Long deptId;

    @ApiModelProperty(value = "工号", example = "1888888888", required = true)
    String uuid;

    @ApiModelProperty(value = "职位", example = "1")
    Long postId;

    @ApiModelProperty(value = "是否特殊人员", example = "0/1", required = true)
    Boolean isSpecial;

    public static User transform(UserAddParam userAddParam) {
        return User
            .builder()
            .avatar(userAddParam.getAvatar())
            .realName(userAddParam.getRealName())
            .mobile(userAddParam.getMobile())
            .type(userAddParam.getType())
            .gender(userAddParam.getGender())
            .uuid(userAddParam.getUuid())
            .isSpecial(userAddParam.getIsSpecial())
            .build();
    }
}
