/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.user;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.ObjectUtil;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.post.Post;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户修改入参
 *
 * @author LJ-2204
 * @date 2022/4/25
 */

@ApiModel("UserModifyParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -5475181111082029313L;

    @ApiModelProperty(value = "主键", example = "11", required = true)
    @NotNull
    Long id;

    @ApiModelProperty(value = "头像", example = "url")
    String avatar;

    @ApiModelProperty(value = "真实姓名", example = "张三", required = true)
    @NotNull
    String realName;

    @ApiModelProperty(value = "电话", example = "1888888888", required = true)
    @NotNull
    String mobile;

    @ApiModelProperty(value = "图标类型", example = "EMPLOYEES人员、GUEST访客", required = true)
    @NotNull
    User.Type type;

    @ApiModelProperty(value = "性别", example = "0/1")
    Boolean gender;

    @ApiModelProperty(value = "归属部门", example = "1", required = true)
    @NotNull
    Long deptId;

    @ApiModelProperty(value = "工号", example = "1888888888", required = true)
    @NotNull
    String uuid;

    @ApiModelProperty(value = "职位", example = "1")
    Long postId;

    @ApiModelProperty(value = "是否特殊人员", example = "0/1", required = true)
    @NotNull
    Boolean isSpecial;

    public static void transform(UserModifyParam userModifyParam, User user) {
        user.setAvatar(userModifyParam.getAvatar());
        user.setRealName(userModifyParam.getRealName());
        user.setMobile(userModifyParam.getMobile());
        user.setType(userModifyParam.getType());
        user.setGender(userModifyParam.getGender());
        user.setDepartment(Department.builder().id(Convert.toLong(userModifyParam.getDeptId())).build());
        user.setUuid(userModifyParam.getUuid());
        if (ObjectUtil.isNotEmpty(userModifyParam.getPostId())) {
            user.setPost(Post.builder().id(Convert.toLong(userModifyParam.getPostId())).build());
        }
    }
}
