/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.video;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 监控视频入参类
 *
 * @author tzl
 * 2022/4/8 16:07
 */
@ApiModel("VideoParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class VideoParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 6031274771790265507L;

    @ApiModelProperty(value = "编号", example = "88888888", required = true)
    @NotEmpty(message = "标识不能为空")
    String uuid;

    @ApiModelProperty(value = "m3u8 媒体地址", example = "m3u8 媒体地址", required = true)
    @NotEmpty(message = "m3u8 媒体地址不能为空")
    String m3u8;

    @ApiModelProperty(value = "摄像头名称", example = "摄像头1", required = true)
    @NotEmpty(message = "摄像头名称不能为空")
    String videoName;

    @ApiModelProperty(value = "经度", example = "1.00", required = true)
    @NotNull(message = "经度")
    Double lon;

    @ApiModelProperty(value = "纬度", example = "1.00", required = true)
    @NotNull(message = "纬度")
    Double lat;

    @ApiModelProperty(value = "备注", example = "厂区摄像头")
    @Size(max = 100, message = "备注不能超过100字")
    String remark;
    //    @ApiModelProperty(value = "m3u8 地址", example = "")
    //    @NotEmpty(message = "m3u8 地址不能为空")
    //    String m3u8;

    //    Point point;

    //    @ApiModelProperty(value = "分类", example = "")
    //    String type;

    //    @ApiModelProperty(value = "是否在线", example = "")
    //    Boolean online;

    //    @ApiModelProperty(value = "是否启用", example = "")
    //    Boolean enable;
}
