/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 邀请信息入参
 *
 * @author tzl
 * @version 1.0
 * @description: 邀请信息入参
 * @date 2022/4/24 17:30
 */
@ApiModel("VisitorInfo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class InvitationParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 3394438557179083143L;

    @ApiModelProperty(value = "邀请方式:个人 公司", example = "个人", required = true)
    @NotEmpty(message = "邀请方式不能为空")
    String InvitationMethod;

    @ApiModelProperty(value = "邀请原因/来访原因", example = "随便看看", required = true)
    @Size(min = 1, max = 20, message = "邀请原因")
    String reason;

    @ApiModelProperty(value = "到访人姓名", example = "张三", required = true)
    @NotEmpty(message = "到访人姓名")
    String visitorName;

    @ApiModelProperty(value = "到访人电话", example = "17688888888", required = true)
    @Pattern(regexp = RegEx.MOBILE, message = "手机号码格式不正确")
    @NotEmpty(message = "到访人电话不能为空")
    String visitorMobile;

    @ApiModelProperty(value = "到访人身份证", example = "430441190001255417")
    String visitorCarNum;

    @ApiModelProperty(value = "是否特殊作业", example = "false", required = true)
    String taskType;

    //    @ApiModelProperty(value = "访客来源", example = "外部邀请", required = true)
    //    String visitorSource;

    @ApiModelProperty(value = "访客公司", example = "壹润科技")
    String orgId;

    @ApiModelProperty(value = "预约时间", example = "2022-04-19 14:28:00", required = true)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime appOfVisitTime;

    @ApiModelProperty(value = "邀请人id", example = "1", required = true)
    Long inviterId;

    @ApiModelProperty(value = "邀请人数", example = "1")
    Integer numOfVisitor;
}
