/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiring.common.constant.RegEx;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * @author tzl
 * 2022/4/19 14:15
 */
@ApiModel("VisitorParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class VisitorParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 1444009404727514785L;

    @ApiModelProperty(value = "到访人姓名", example = "张三", required = true)
    @NotEmpty(message = "到访人姓名不能为空")
    String visitorName;

    @ApiModelProperty(value = "到访人电话", example = "17688888888", required = true)
    @Pattern(regexp = RegEx.MOBILE, message = "手机号码格式不正确")
    @NotEmpty(message = "到访人电话不能为空")
    String visitorMobile;

    @ApiModelProperty(value = "到访人身份证", example = "430441190001255417", required = true)
    @NotEmpty(message = "到访人身份证不能为空")
    String visitorCarNum;

    @ApiModelProperty(value = "是否特殊作业", example = "fasle", required = true)
    String taskType;

    @ApiModelProperty(value = "访客来源", example = "外部邀请", required = true)
    String visitorSource;

    @ApiModelProperty(value = "访客所属公司", example = "壹润科技")
    String orgId;

    @ApiModelProperty(value = "被访人id", example = "1", required = true)
    String intervieweeId;

    @ApiModelProperty(value = "来访原因", example = "看看", required = true)
    String reason;

    @ApiModelProperty(value = "来访时间", example = "2022-04-19 14:28:00")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime appOfVisitTime;

    @ApiModelProperty(value = "是否有车(是 1 ,否 2)", example = "2")
    Integer hasCar;

    @ApiModelProperty(value = "车牌号码", example = "湘A99999")
    @Pattern(regexp = RegEx.CARNUM, message = "车牌号码格式不正确")
    String carNum;

    @ApiModelProperty(value = "车辆类型", example = "货车")
    String carType;

    @ApiModelProperty(value = "车辆标签卡", example = "1")
    String labelCard;

    @ApiModelProperty(value = "主访人员id", example = "1")
    Long mainVisitorId;
}
