/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.zy.dept;

import cn.hutool.core.util.ObjectUtil;
import com.yiring.auth.domain.dept.Department;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * zy部门新增参数
 *
 * @author LJ-2204
 * @date 2022/5/5
 */

@ApiModel("ZyDepartmentAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class ZyDepartmentAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -2949706685712988765L;

    @ApiModelProperty(value = "名称", example = "Java", required = true)
    @NotNull
    String deptName;

    @ApiModelProperty(value = "邮箱", example = "@163.com")
    String email;

    @ApiModelProperty(value = "真实姓名", example = "张三")
    String leader;

    @ApiModelProperty(value = "工厂", example = "100")
    Integer orgId;

    @ApiModelProperty(value = "上级部门", example = "1", required = true)
    @NotNull
    Long parentId;

    @ApiModelProperty(value = "电话", example = "18888888888")
    String phone;

    @ApiModelProperty(value = "部门状态", example = "0/1")
    String status;

    public static ZyDepartmentAddParam transform(Department department, Integer orgId) {
        ZyDepartmentAddParam zyDepartmentAddParam = ZyDepartmentAddParam
            .builder()
            .deptName(department.getName())
            .orgId(orgId)
            .status(department.getEnable() ? "0" : "1")
            .build();

        if (ObjectUtil.isNotEmpty(department.getLeader())) {
            zyDepartmentAddParam.setEmail(department.getLeader().getEmail());
            zyDepartmentAddParam.setLeader(department.getLeader().getRealName());
            zyDepartmentAddParam.setPhone(department.getLeader().getMobile());
        }

        return zyDepartmentAddParam;
    }
}
