/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.zy.dept;

import cn.hutool.core.util.ObjectUtil;
import com.yiring.auth.domain.dept.Department;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * zy部门修改参数
 *
 * @author LJ-2204
 * @date 2022/5/5
 */

@ApiModel("ZyDepartmentModifyParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class ZyDepartmentModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -1008100771548933210L;

    @ApiModelProperty(value = "主键", example = "100", required = true)
    @NotNull
    Long deptId;

    @ApiModelProperty(value = "名称", example = "Java", required = true)
    @NotNull
    String deptName;

    @ApiModelProperty(value = "邮箱", example = "@163.com")
    String email;

    @ApiModelProperty(value = "真实姓名", example = "张三")
    String leader;

    @ApiModelProperty(value = "工厂", example = "100")
    Integer orgId;

    @ApiModelProperty(value = "上级部门", example = "1", required = true)
    @NotNull
    Long parentId;

    @ApiModelProperty(value = "电话", example = "18888888888")
    String phone;

    @ApiModelProperty(value = "部门状态", example = "0/1")
    String status;

    public static ZyDepartmentModifyParam transform(Department department, Integer orgId) {
        ZyDepartmentModifyParam zyDepartmentModifyParam = ZyDepartmentModifyParam
            .builder()
            .deptId(department.getLinkId())
            .deptName(department.getName())
            .orgId(orgId)
            .status(department.getEnable() ? "0" : "1")
            .build();

        if (ObjectUtil.isNotEmpty(department.getLeader())) {
            zyDepartmentModifyParam.setEmail(department.getLeader().getEmail());
            zyDepartmentModifyParam.setLeader(department.getLeader().getRealName());
            zyDepartmentModifyParam.setPhone(department.getLeader().getMobile());
        }

        return zyDepartmentModifyParam;
    }
}
