/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.zy.location.tag;

import cn.hutool.core.util.StrUtil;
import com.yiring.app.domain.location.LocationTag;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * zy定位标签新增入参
 * @author LJ-2204
 * @date 2022/4/15
 */

@ApiModel("ZyLocationTagAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class ZyLocationTagAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -8828137320896062620L;

    @ApiModelProperty(value = "工厂", example = "100")
    Integer orgId;

    @ApiModelProperty(value = "标签类型", example = "蓝牙人员定位卡", required = true)
    LocationTag.Type types;

    @ApiModelProperty(value = "编号", example = "BTT88888888", required = true)
    String tagId;

    @ApiModelProperty(value = "实体类型", example = "car", required = true)
    String entityType;

    @ApiModelProperty(value = "card", example = "card")
    String card;

    public static ZyLocationTagAddParam transform(LocationTag locationTag, Integer orgId) {
        String entityType = StrUtil.equals(locationTag.getType().name(), "BTT02") ? "car" : "staff";
        return ZyLocationTagAddParam
            .builder()
            .orgId(orgId)
            .tagId(locationTag.getCode())
            .types(locationTag.getType())
            .entityType(entityType)
            .card(locationTag.getImei())
            .build();
    }
}
