/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.zy.user;

import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * zy用户新增参数
 *
 * @author LJ-2204
 * @date 2022/5/5
 */

@ApiModel("ZyUserAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class ZyUserAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -7945473190204335719L;

    @ApiModelProperty(value = "部门id", example = "100")
    Long deptId;

    @ApiModelProperty(value = "真实姓名", example = "张三")
    String name;

    @ApiModelProperty(value = "工厂", example = "100")
    Integer orgId;

    @ApiModelProperty(value = "电话", example = "18888888888")
    String phone;

    @ApiModelProperty(value = "性别", example = "男/1女2")
    Integer sex;

    @ApiModelProperty(value = "工号", example = "YH10086")
    String jobNumber;

    @ApiModelProperty(value = "类型", example = "1")
    Integer type;

    @ApiModelProperty(value = "图标类型", example = "1普通,10028特殊")
    Integer entityIconId;

    public static ZyUserAddParam transform(User user, Integer factoryId) {
        return ZyUserAddParam
            .builder()
            .name(user.getRealName())
            .orgId(factoryId)
            .phone(user.getMobile())
            .sex(user.getGender() ? 1 : 2)
            .jobNumber(user.getUuid())
            .type(1)
            .build();
    }
}
