/* (C) 2022 YiRing, Inc. */
package com.yiring.app.rabbit.receiver;

import com.rabbitmq.client.Channel;
import com.yiring.app.rabbit.config.ZyRabbitConfig;
import com.yiring.app.service.message.ZyMessageService;
import java.io.IOException;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.stereotype.Component;

/**
 * 真源 RabbitMQ 消息监听（消息消费者）
 *
 * @author Jim
 * @version 0.1
 * 2022/4/13 17:13
 */

@Slf4j
@Component
@Configuration
@ConditionalOnProperty(prefix = "zy-config.rabbitmq", value = "enabled", havingValue = "true")
public class ZyRabbitReceiver {

    // TODO
    // 1. 新增消息订阅定时任务，检查是否正常订阅了真源定位系统的消息
    // 2. 如果没有所需的订阅记录，则发起消息订阅（见接口文档: 6.2）
    // 3. 订阅 position（定位数据）、lowPower（低电量报警）、deviceStatus（设备状态）、keyWarning（按键报警）

    @Resource
    ZyMessageService zyMessageService;

    /**
     * 订阅真源定位系统 RabbitMQ 推送过来的消息（主动订阅的一些消息类别）
     * 参见: 定位平台接口规范V3.0.1 - 通用版.pdf #6
     * @param msg 消息内容
     * @param channel 消息通道
     * @param message 消息主体
     * @throws IOException 消息确认异常
     */
    @RabbitHandler
    //    @RabbitListener(
    //        queues = ZyRabbitConfig.MESSAGE_QUEUES_NAME,
    //        containerFactory = ZyRabbitConfig.LISTENER_FACTORY_NAME
    //    )
    @RabbitListener(queues = ZyRabbitConfig.MESSAGE_QUEUES_NAME, containerFactory = "rabbitListenerContainerFactory")
    public void listen(String msg, Channel channel, Message message) throws IOException {
        // 消费消息
        zyMessageService.consume(msg);
        // 手动确认消息已收到
        channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
    }
}
