/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.appletUser.impl;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.yiring.app.domain.appletUser.AppletUser;
import com.yiring.app.domain.appletUser.AppletUserRepository;
import com.yiring.app.feign.WxClient;
import com.yiring.app.param.appUser.AppletUserParam;
import com.yiring.app.param.appUser.AppletUserQueryParam;
import com.yiring.app.service.appletUser.AppletUserService;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import java.util.Optional;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author Administrator
 * @version 1.0
 * @description: TODO
 * @date 2022/4/24 9:25
 */
@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class AppletUserServiceImpl implements AppletUserService {

    @Resource
    AppletUserRepository appletUserRepository;

    @Resource
    WxClient wxClient;

    @Override
    public Result<String> selectMobile(AppletUserQueryParam appletUserQueryParam) {
        JSONObject jsonObject = wxClient.getOpenid(
            appletUserQueryParam.getAppid(),
            appletUserQueryParam.getSecret(),
            appletUserQueryParam.getJs_code(),
            appletUserQueryParam.getGrant_type()
        );
        Object openid = jsonObject.get("openid");
        if (StrUtil.isNotBlank(openid.toString())) {
            Optional<AppletUser> optional = appletUserRepository.findById(openid.toString());
            //如果该微信为第一次登录小程序
            if (optional.isEmpty()) {
                return Result.no(Status.NOT_FOUND);
            }
            AppletUser appletUser = optional.get();
            return Result.ok(appletUser.getMobile());
        }
        return null;
    }

    @Override
    public Result<String> saveAppUser(AppletUserParam appletUserParam) {
        Integer integer = appletUserRepository.countMobile(appletUserParam.getMobile());
        if (integer > 0) {
            return Result.no(Status.BAD_REQUEST, "手机号已绑定");
        }
        AppletUser appletUser = new AppletUser();
        BeanUtils.copyProperties(appletUserParam, appletUser);
        appletUserRepository.saveAndFlush(appletUser);
        return Result.ok(appletUser.getMobile());
    }
}
