/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.broadcast;

import com.yiring.app.param.broadcast.BroadcastParam;
import com.yiring.app.param.broadcast.BroadcastQueryParam;
import com.yiring.app.vo.broadcast.BroadcastVo;
import com.yiring.app.vo.broadcast.BroadcastjcVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;
import org.locationtech.jts.geom.Point;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/5 17:31
 */
public interface BroadcastService {
    /**
     * 新增播报设备
     * @author tzl
     * @date 2022/5/5 17:33
     * @param broadcastParam BroadcastParam
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> saveBroadcast(BroadcastParam broadcastParam);
    /**
     * 修改播报设备
     * @author tzl
     * @date 2022/5/5 17:34
     * @param broadcastParam BroadcastParam
     * @param idParam IdParam
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> updateBroadcast(BroadcastParam broadcastParam, IdParam idParam);
    /**
     * 删除播报设备
     * @author tzl
     * @date 2022/5/5 17:35
     * @param idParam IdParam
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> deleteBroadcast(IdParam idParam);
    /**
     * 查看设备位置
     * @author tzl
     * @date 2022/5/5 17:47
     * @param idParam IdParam
     * @return com.yiring.common.core.Result<org.locationtech.jts.geom.Point>
     */
    Result<Point> selectPoint(IdParam idParam);
    /**
     * 分页查询设备
     * @author tzl
     * @date 2022/5/5 17:49
     * @param broadcastQueryParam BroadcastQueryParam
     * @return com.yiring.common.core.Result<com.yiring.app.vo.broadcast.BroadcastVo>
     */
    Result<PageVo<BroadcastVo>> pageBroadcast(BroadcastQueryParam broadcastQueryParam);
    /**
     * 导出播报设备
     * @author tzl
     * @date 2022/5/6 8:56
     * @param broadcastQueryParam BroadcastQueryParam
     * @param response HttpServletResponse
     */
    void exportBroadcast(BroadcastQueryParam broadcastQueryParam, HttpServletResponse response);
    /**
     * 播报设备导入
     * @author tzl
     * @date 2022/5/6 10:00
     * @param file 文件
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> importBroadcast(MultipartFile file);
    /**
     * 根据名字检索
     * @author tzl
     * @date 2022/5/6 10:26
     * @param indexParam 入参
     * @return com.yiring.common.core.Result<com.yiring.common.vo.PageVo<com.yiring.app.vo.broadcast.BroadcastVo>>
     */
    Result<PageVo<BroadcastjcVo>> selectBroadcastName(IndexParam indexParam);
}
