/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.dept;

import com.yiring.app.param.dept.DepartmentAddParam;
import com.yiring.app.param.dept.DepartmentExportParam;
import com.yiring.app.param.dept.DepartmentFindParam;
import com.yiring.app.param.dept.DepartmentModifyParam;
import com.yiring.app.vo.dept.DepartmentInfoVo;
import com.yiring.app.vo.dept.DepartmentVo;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import java.util.HashMap;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.multipart.MultipartFile;

/**
 * 部门管理
 * @author LJ-2204
 * @date 2022/4/19
 */
public interface DepartmentService {
    /**
     * 新增部门
     * @param departmentAddParam DepartmentAddParam
     * @return Result<String>
     */
    Result<String> addDepartment(DepartmentAddParam departmentAddParam);

    /**
     * 查询树状图
     * @param departmentFindParam DepartmentFindParam
     * @return Result<PageVo<DepartmentVo>>
     */
    Result<PageVo<DepartmentVo>> findDepartmentTree(DepartmentFindParam departmentFindParam);

    /**
     * 根据id查询详细信息
     * @param idParam IdParam
     * @return Result<DepartmentInfoVo>
     */
    Result<DepartmentInfoVo> findDepartmentInfo(IdParam idParam);

    /**
     * 导出部门
     * @param departmentExportParam DepartmentFindParam
     * @param response HttpServletResponse
     */
    void exportDepartment(DepartmentExportParam departmentExportParam, HttpServletResponse response);

    /**
     * 逻辑删除部门
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> deleteDepartment(IdParam idParam);

    /**
     * 部门添加岗位
     * @param idParam IdParam
     * @param idsParam IdsParam
     * @return Result<String>
     */
    Result<String> deptBingPost(IdParam idParam, IdsParam idsParam);

    /**
     * 部门修改
     * @param departmentModifyParam DepartmentModifyParam
     * @return Result<String>
     */
    Result<String> modifyDept(DepartmentModifyParam departmentModifyParam);

    /**
     * 导入部门
     * @param file MultipartFile
     * @return Result<String>
     */
    Result<String> importDepartment(MultipartFile file);

    /**
     * 部门名称字符串形式
     * @return HashMap<String, Department>
     */
    HashMap<String, Department> getStringDepartmentHashMap();
}
