/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.dict;

import com.yiring.app.param.dict.DictParam;
import com.yiring.app.param.dict.DictQueryParam;
import com.yiring.common.core.Result;
import com.yiring.common.dict.Dict;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.ArrayList;

/**
 * 字典
 *
 * @author tzl
 * 2022/4/13 15:36
 */
public interface DictService {
    /**
     * 根据条件分页查询字典数据
     *
     * @param dictQueryParam DictQueryParam
     * @return 字典数据集合信息
     */
    Result<PageVo<Dict>> pageDictInfo(DictQueryParam dictQueryParam, PageParam param);

    /**
     * 根据字典类型和字典键值查询字典数据信息
     *
     * @param dictType  String
     * @param dictValue String
     * @return 字典标签
     */
    Result<String> selectDictLabel(String dictType, String dictValue);

    /**
     * 从缓存中获取字典
     *
     * @param dictType 字典类型
     * @return 字典数据集合
     */
    Result<ArrayList<Dict>> selectDict(String dictType);

    /**
     * 根据字典数据ID查询信息
     *
     * @param id Long
     * @return 字典数据
     */
    Result<Dict> getDictInfo(Long id);

    /**
     * 删除字典数据信息
     *
     * @param idParam 主键id
     */
    Result<String> deleteDictById(IdParam idParam);

    /**
     * 新增字典数据信息
     *
     * @param dictParam 字典数据信息入参
     * @return 结果
     */
    Result<String> saveDictInfo(DictParam dictParam);

    /**
     * 修改字典数据信息
     *
     * @param idParam   主键id
     * @param dictParam 字典数据信息入参
     * @return 结果
     */
    Result<String> updateDictInfo(DictParam dictParam, IdParam idParam);

    /**
     * 是否已有该字典标签
     *
     * @param param String
     * @return 是否存在
     */
    boolean has(String param);

    /**
     * 是否该类型字典已有该字典值
     *
     * @param dictType  String
     * @param dictValue String
     * @return 是否存在
     */
    boolean hasValue(String dictType, String dictValue);

    /**
     * 加载字典缓存
     */
    void loadingDictCache();
}
