/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.district.impl;

import com.yiring.app.domain.district.District;
import com.yiring.app.domain.district.DistrictRepository;
import com.yiring.app.param.district.DistrictAddParam;
import com.yiring.app.param.district.DistrictModifyParam;
import com.yiring.app.service.district.DistrictService;
import com.yiring.app.util.JpaUtil;
import com.yiring.app.vo.district.DistrictVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import com.yiring.common.util.Commons;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.Optional;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/26 13:53
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class DistrictServiceImpl implements DistrictService {

    @Resource
    private DistrictRepository districtRepository;

    @Override
    public Result<String> addDistrict(DistrictAddParam param) {
        Boolean exists = districtRepository.existsByName(param.getName());
        if (exists) {
            return Result.no(Status.EXPECTATION_FAILED, "区域名称已存在");
        }
        District district = param.transform();
        districtRepository.save(district);
        return Result.ok();
    }

    @Override
    public Result<String> modifyDistrict(DistrictModifyParam param) {
        List<District> list = districtRepository.findAllByName(param.getName());
        District district = null;
        if (list.size() > 1) {
            log.warn("DistrictServiceImpl.modifyDistrict时查询出两条区域信息名称相同的数据,param:[{}]", param);
        }
        //校验名称是否重复
        for (District item : list) {
            if (item.getId().equals(param.getId())) {
                district = item;
            } else {
                return Result.no(Status.EXPECTATION_FAILED, "区域名称已存在");
            }
        }
        //如果上面查出来的数据没有这条要修改的数据，则根据id查询出来
        if (district == null) {
            Optional<District> optional = districtRepository.findById(param.getId());
            if (optional.isEmpty()) {
                return Result.no(Status.EXPECTATION_FAILED, "修改的区域信息不存在");
            }
            district = optional.get();
        }
        //只修改要修改的值
        JpaUtil.copyNotNullProperties(param, district);
        return Result.ok();
    }

    @Override
    public Result<String> removeDistrict(IdParam idParam) {
        Optional<District> optional = districtRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.EXPECTATION_FAILED, "删除的区域信息不存在");
        }
        District district = optional.get();
        district.setDeleted(true);
        return Result.ok();
    }

    @Override
    public Result<PageVo<DistrictVo>> findByNameLike(String name) {
        List<District> list = districtRepository.findLikeName(name);
        List<DistrictVo> voList = Commons.transform(list, DistrictVo.class);
        PageVo<DistrictVo> pageVo = PageVo.build(voList, voList.size());
        return Result.ok(pageVo);
    }
}
