/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.icon.impl;

import com.yiring.app.domain.icon.Icon;
import com.yiring.app.domain.icon.IconRepository;
import com.yiring.app.param.icon.IconParam;
import com.yiring.app.service.icon.IconService;
import com.yiring.app.vo.icon.IconVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.data.domain.*;
import org.springframework.stereotype.Service;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/5 9:28
 */
@Service
public class IconServiceImpl implements IconService {

    @Resource
    IconRepository iconRepository;

    @Override
    public Result<String> saveIcon(IconParam iconParam) {
        if (hasIconName(iconParam.getIconName())) {
            return Result.no(Status.BAD_REQUEST, "图标名称已存在");
        }
        Icon icon = new Icon();
        BeanUtils.copyProperties(iconParam, icon);
        iconRepository.saveAndFlush(icon);
        return Result.ok();
    }

    @Override
    public Result<String> deleteIcon(IdParam idParam) {
        Optional<Icon> optional = iconRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }
        Icon icon = optional.get();
        iconRepository.delete(icon);
        return Result.ok();
    }

    @Override
    public Result<String> updateIcon(IconParam iconParam, IdParam idParam) {
        Optional<Icon> optional = iconRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }

        Icon icon = optional.get();
        //当修改图标名称时
        if (!icon.getIconName().equals(iconParam.getIconName())) {
            if (hasIconName(iconParam.getIconName())) {
                return Result.no(Status.BAD_REQUEST, "图标名称已存在");
            }
        }
        BeanUtils.copyProperties(iconParam, icon);
        iconRepository.saveAndFlush(icon);
        return Result.ok();
    }

    @Override
    public Result<PageVo<IconVo>> pageIcon(PageParam pageParam) {
        //分页
        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());
        Page<Icon> all = iconRepository.findAll(pageable);
        List<IconVo> data = all
            .get()
            .map(icon -> {
                IconVo vo = new IconVo();
                BeanUtils.copyProperties(icon, vo);
                return vo;
            })
            .collect(Collectors.toList());
        PageVo<IconVo> resultVo = PageVo.build(data, all.getTotalElements());
        return Result.ok(resultVo);
    }

    public boolean hasIconName(String param) {
        Icon icon = Icon.builder().iconName(param).build();
        long count = iconRepository.count(Example.of(icon));
        return count > 0;
    }
}
