/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.location.rule;

import com.yiring.app.param.location.rule.LocationAlarmRuleAddParam;
import com.yiring.app.param.location.rule.LocationAlarmRuleModifyParam;
import com.yiring.app.param.location.rule.LocationAlarmRuleParam;
import com.yiring.app.vo.IdNameVo;
import com.yiring.app.vo.location.rule.LocationAlarmRuleVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/5 16:55
 */
public interface LocationAlarmRuleService {
    /**
     * 添加一条规则
     * @param param 规则信息
     * @return 是否成功
     */
    Result<String> addRule(LocationAlarmRuleAddParam param);

    /**
     * 修改一条规则
     * @param param 规则信息
     * @return 是否成功
     */
    Result<String> modifyRule(LocationAlarmRuleModifyParam param);

    /**
     * 删除一条规则
     * @param idParam 规则id
     * @return 是否成功
     */
    Result<String> removeRule(IdParam idParam);

    /**
     * 根据id查询规则
     * @param idParam 规则id
     * @return 规则信息
     */
    Result<LocationAlarmRuleVo> findById(IdParam idParam);

    /**
     * 根据条件查询规则信息
     * @param param 条件
     * @param pageParam 分页参数
     * @return 规则信息
     */
    Result<PageVo<LocationAlarmRuleVo>> findByCondition(LocationAlarmRuleParam param, PageParam pageParam);

    /**
     * 导出电子围栏规则
     * @param param 条件
     * @param response response
     * @param pageParam 分页参数
     */
    void exportAlarmRule(LocationAlarmRuleParam param, HttpServletResponse response, PageParam pageParam);

    /**
     * 根据电子围栏名称模糊查询围栏id和名称
     * @param name 名称
     * @return 围栏id和名称
     */
    Result<PageVo<IdNameVo>> findFenceList(String name);

    /**
     * 查询报警类型下拉框
     * @return 报警类型列表
     */
    Result<PageVo<IdNameVo>> findAlarmTypeList();
}
