/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.location.rule.impl;

import com.yiring.app.domain.location.LocationFenceRule;
import com.yiring.app.domain.location.LocationFenceRuleRepository;
import com.yiring.app.param.location.rule.LocationFenceRuleAddParam;
import com.yiring.app.param.location.rule.LocationFenceRuleModifyParam;
import com.yiring.app.service.location.rule.LocationFenceRuleService;
import com.yiring.app.util.JpaUtil;
import com.yiring.app.vo.location.rule.LocationFenceRuleVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import java.util.Optional;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/29 11:39
 */
@Service
@Transactional(rollbackFor = Exception.class)
@Slf4j
public class LocationFenceRuleServiceImpl implements LocationFenceRuleService {

    @Resource
    private LocationFenceRuleRepository locationFenceRuleRepository;

    @Override
    public Result<String> addRule(LocationFenceRuleAddParam param) {
        LocationFenceRule locationFenceRule = param.transform();
        locationFenceRuleRepository.saveAndFlush(locationFenceRule);
        return Result.ok();
    }

    @Override
    public Result<String> modifyRule(LocationFenceRuleModifyParam param) {
        LocationFenceRule locationFenceRule = param.transform();
        Optional<LocationFenceRule> optional = locationFenceRuleRepository.findById(param.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.EXPECTATION_FAILED, "要修改的规则不存在");
        }
        JpaUtil.copyNotNullProperties(locationFenceRule, optional.get());
        return Result.ok();
    }

    @Override
    public Result<String> removeRule(IdParam idParam) {
        Optional<LocationFenceRule> optional = locationFenceRuleRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.EXPECTATION_FAILED, "要删除的规则不存在");
        }
        optional.get().setDeleted(true);
        return Result.ok();
    }

    @Override
    public Result<LocationFenceRuleVo> findRule(IdParam idParam) {
        Optional<LocationFenceRule> optional = locationFenceRuleRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.EXPECTATION_FAILED, "要删除的规则不存在");
        }
        LocationFenceRuleVo ruleVo = LocationFenceRuleVo.transform(optional.get());
        return Result.ok(ruleVo);
    }
}
