/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.post;

import com.yiring.app.param.post.*;
import com.yiring.app.vo.post.PostIndexVo;
import com.yiring.app.vo.post.PostInfoVo;
import com.yiring.app.vo.post.PostVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;

/**
 * 职位信息
 * @author LJ-2204
 * @date 2022/4/13
 */
public interface PostService {
    /**
     * 新增职位信息
     * @param postAddParam PostAddParam
     * @return Result<String>
     */
    Result<String> addPost(PostAddParam postAddParam);

    /**
     * 修改职位信息
     * @param postModifyParam PostModifyParam
     * @return Result<String>
     */
    Result<String> modifyPost(PostModifyParam postModifyParam);

    /**
     * 销毁职位信息
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> deletePost(IdParam idParam);

    /**
     * 职位信息分页
     * @param postFindParam PostFindParam
     * @param pageParam PageParam
     * @return Result<PageVo<PostVo>>
     */
    Result<PageVo<PostVo>> findPostPage(PostFindParam postFindParam, PageParam pageParam);

    /**
     * 详细信息查询
     * @param idParam IdParam
     * @return Result<PostInfoVo>
     */
    Result<PostInfoVo> findPostById(IdParam idParam);

    /**
     * 根据名称判断是否存在职业信息
     * @param name String
     * @return boolean
     */
    boolean hasPostInfo(String name);

    /**
     * 导出职位信息
     * @param postExportParam PostExportParam
     * @param response HttpServletResponse
     */
    void exportPostInfo(PostExportParam postExportParam, HttpServletResponse response);

    /**
     * 职位检索
     * @param indexParam IndexParam
     * @return Result<PageVo<PostIndexVo>>
     */
    Result<PageVo<PostIndexVo>> indexPost(IndexParam indexParam);
}
