/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.user;

import com.yiring.app.param.user.*;
import com.yiring.app.vo.user.UserInfoVo;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户
 * @author LJ-2204
 * @date 2022/4/20
 */
public interface UserService {
    /**
     * 表格查询
     * @param userFindParam UserByNameParam
     * @param pageParam PageParam
     * @return Result<PageVo<UserAutoVo>>
     */
    Result<PageVo<UserVo>> findUserPage(UserFindParam userFindParam, PageParam pageParam);

    /**
     * 用户详细信息
     * @param idParam IdParam
     * @return Result<UserVo>
     */
    Result<UserInfoVo> findUserById(IdParam idParam);

    /**
     * 用户绑定标签
     * @param userBingTagParam UserBingTagParam
     * @return Result<String>
     */
    Result<String> userBingTag(UserBingTagParam userBingTagParam);

    /**
     * 收卡
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> userUnBingTag(IdParam idParam);

    /**
     * 删除用户
     * @param idsParam IdsParam
     * @return Result<String>
     */
    Result<String> deleteUser(IdsParam idsParam);

    /**
     * 导出用户
     * @param userFindParam UserFindParam
     * @param response HttpServletResponse
     */
    void exportUser(UserFindParam userFindParam, HttpServletResponse response);

    /**
     * 启用/停用
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> stateUser(IdParam idParam);

    /**
     * 修改用户
     * @param userModifyParam UserModifyParam
     * @return Result<String>
     */
    Result<String> modifyUser(UserModifyParam userModifyParam);

    /**
     * 新增用户
     * @param userAddParam UserAddParam
     * @return Result<String>
     */
    Result<String> addUser(UserAddParam userAddParam);

    /**
     * 导入
     * @param file MultipartFile
     * @return Result<String>
     */
    Result<String> importUser(MultipartFile file);

    /**
     * 用户索引
     * @param indexParam IndexParam
     * @return Result<PageVo<UserVo>>
     */
    Result<PageVo<UserVo>> indexUser(IndexParam indexParam);

    /**
     * 用户条件查询
     * @param userFindParam UserFindParam
     * @return Result<PageVo<UserVo>>
     */
    Result<PageVo<UserVo>> findUser(UserFindParam userFindParam);
}
