/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.user.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.liaochong.myexcel.core.DefaultStreamExcelBuilder;
import com.github.liaochong.myexcel.core.SaxExcelReader;
import com.yiring.app.domain.location.LocationTag;
import com.yiring.app.domain.location.LocationTagRepository;
import com.yiring.app.excel.user.UserExportExcel;
import com.yiring.app.excel.user.UserImportExcel;
import com.yiring.app.feign.zy.user.UserClient;
import com.yiring.app.param.user.*;
import com.yiring.app.param.zy.user.ZyUserAddParam;
import com.yiring.app.param.zy.user.ZyUserFindParam;
import com.yiring.app.param.zy.user.ZyUserModifyParam;
import com.yiring.app.service.dept.DepartmentService;
import com.yiring.app.service.user.UserService;
import com.yiring.app.util.zy.ZyUtil;
import com.yiring.app.vo.user.UserInfoVo;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.dept.DepartmentRepository;
import com.yiring.auth.domain.post.Post;
import com.yiring.auth.domain.post.PostRepository;
import com.yiring.auth.domain.user.User;
import com.yiring.auth.domain.user.UserRepository;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.domain.BasicEntity;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.*;
import java.util.concurrent.Executors;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.EntityManager;
import javax.persistence.criteria.*;
import javax.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.jetbrains.annotations.NotNull;
import org.springframework.data.domain.Example;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户
 * @author LJ-2204
 * @date 2022/4/20
 */

@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class UserServiceImpl implements UserService {

    final Integer FACTORY_ID = 100;

    @Resource
    EntityManager em;

    @Resource
    UserRepository userRepository;

    @Resource
    LocationTagRepository locationTagRepository;

    @Resource
    DepartmentRepository departmentRepository;

    @Resource
    DepartmentService departmentService;

    @Resource
    PostRepository postRepository;

    @Resource
    UserClient userClient;

    @Override
    public Result<PageVo<UserVo>> findUserPage(UserFindParam userFindParam, PageParam pageParam) {
        CriteriaQuery<UserVo> cq = getUserVoCriteriaQuery(userFindParam);

        List<UserVo> userVos = em
            .createQuery(cq)
            .setFirstResult((pageParam.getPageNo() - 1) * pageParam.getPageSize())
            .setMaxResults(pageParam.getPageSize())
            .getResultList();

        int size = em.createQuery(cq).getResultList().size();
        PageVo<UserVo> page = PageVo.build(userVos, size);
        return Result.ok(page);
    }

    @Override
    public Result<UserInfoVo> findUserById(IdParam idParam) {
        Optional<User> userOptional = userRepository.findOne(Example.of(User.builder().id(idParam.getId()).build()));
        if (userOptional.isPresent()) {
            UserInfoVo userInfoVo = UserInfoVo.transform(userOptional.get());
            return Result.ok(userInfoVo);
        }
        return Result.no(Status.BAD_REQUEST);
    }

    @Override
    public Result<String> userBingTag(UserBingTagParam userBingTagParam) {
        Optional<User> userOptional = userRepository.findById(userBingTagParam.getId());

        if (userOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "员工不存在");
        }

        User user = userOptional.get();

        Optional<LocationTag> locationTagOptional = locationTagRepository.findOne(
            Example.of(LocationTag.builder().code(userBingTagParam.getCode()).build())
        );
        if (locationTagOptional.isEmpty()) throw new RuntimeException("标签卡不存在");

        LocationTag locationTag = locationTagOptional.get();
        if (locationTag.getUsed()) {
            throw new RuntimeException("已绑定其他用户 : " + locationTag.getUser().getRealName());
        }

        JSONObject jsonObject = userClient.unbind(
            user.getLinkId(),
            userBingTagParam.getCode(),
            FACTORY_ID,
            ZyUtil.clientLogin()
        );
        if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
        }
        locationTag.setUser(User.builder().id(userBingTagParam.getId()).build());
        locationTag.setUsed(true);
        locationTagRepository.save(locationTag);

        return Result.ok();
    }

    @Override
    public Result<String> userUnBingTag(IdParam idParam) {
        Optional<User> userOptional = userRepository.findById(idParam.getId());

        if (userOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST, "员工不存在");
        }

        User user = userOptional.get();

        Optional<LocationTag> locationTagOptional = locationTagRepository.findOne(
            Example.of(LocationTag.builder().user(User.builder().id(idParam.getId()).build()).build())
        );
        if (locationTagOptional.isEmpty()) return Result.no(Status.BAD_REQUEST);

        JSONObject jsonObject = userClient.unbind(user.getLinkId(), FACTORY_ID, ZyUtil.clientLogin());
        if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
        }
        LocationTag locationTag = locationTagOptional.get();
        locationTag.setUser(null);
        locationTag.setUsed(false);
        locationTagRepository.save(locationTag);

        return Result.ok();
    }

    @Override
    public Result<String> deleteUser(IdsParam idsParam) {
        String[] strings = idsParam.getIds().split(",");
        Long[] ids = Convert.toLongArray(strings);
        StringBuilder linkIds = new StringBuilder();
        for (Long id : ids) {
            Optional<User> userOptional = userRepository.findById(id);

            if (userOptional.isEmpty()) {
                return Result.no(Status.BAD_REQUEST, "员工不存在");
            }

            User user = userOptional.get();
            linkIds.append(user.getLinkId()).append(",");
            LocationTag locationTagBuild = LocationTag
                .builder()
                .user(User.builder().id(Convert.toLong(id)).build())
                .build();
            long locationTagCount = locationTagRepository.count(Example.of(locationTagBuild));
            if (locationTagCount > 0) return Result.no(Status.BAD_REQUEST, "已发卡，不可删除");

            Department departmentBuild = Department
                .builder()
                .leader(User.builder().id(Convert.toLong(id)).build())
                .build();
            long departmentCount = departmentRepository.count(Example.of(departmentBuild));
            if (departmentCount > 0) return Result.no(Status.BAD_REQUEST, "部门负责人，请先解绑");
        }
        String linkId = linkIds.toString();
        if (linkIds.indexOf(",") != -1) {
            linkId = linkIds.substring(0, linkIds.length() - 1);
        }

        JSONObject jsonObject = userClient.delete(linkId, ZyUtil.clientLogin());
        if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
        }
        userRepository.deleteAllById(ListUtil.toList(ids));
        return Result.ok();
    }

    @Override
    public void exportUser(UserFindParam userFindParam, HttpServletResponse response) {
        CriteriaQuery<UserVo> cq = getUserVoCriteriaQuery(userFindParam);
        List<UserVo> userVos = em.createQuery(cq).getResultList();
        List<UserExportExcel> userExportExcels = userVos
            .stream()
            .map(UserExportExcel::transform)
            .collect(Collectors.toList());
        try (
            DefaultStreamExcelBuilder<UserExportExcel> streamExcelBuilder = DefaultStreamExcelBuilder
                .of(UserExportExcel.class)
                .threadPool(Executors.newFixedThreadPool(2))
                .rowHeight(14)
                .titleRowHeight(14)
                .style(
                    "cell->vertical-align:center;text-align:center",
                    "title->vertical-align:center;text-align:center;font-weight:bold;font-family:等线"
                )
                .start()
        ) {
            streamExcelBuilder.append(userExportExcels);

            String fileName = URLEncoder.encode("用户信息.xlsx", StandardCharsets.UTF_8);
            response.setContentType("application/octet-stream");
            response.setHeader("Access-Control-Expose-Headers", "Content-Disposition");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            OutputStream out = response.getOutputStream();

            Workbook workbook = streamExcelBuilder.fixedTitles().build();
            workbook.write(out);
            workbook.close();
            out.flush();
            out.close();
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new RuntimeException("用户信息导出失败: " + e.getMessage());
        }
    }

    @Override
    public Result<String> stateUser(IdParam idParam) {
        LocationTag locationTagBuild = LocationTag.builder().user(User.builder().id(idParam.getId()).build()).build();
        long locationTagCount = locationTagRepository.count(Example.of(locationTagBuild));
        if (locationTagCount > 0) return Result.no(Status.BAD_REQUEST, "已发卡，不可停用");

        Department departmentBuild = Department.builder().leader(User.builder().id(idParam.getId()).build()).build();
        long departmentCount = departmentRepository.count(Example.of(departmentBuild));
        if (departmentCount > 0) return Result.no(Status.BAD_REQUEST, "部门负责人，请先解绑");

        Optional<User> userOptional = userRepository.findOne(Example.of(User.builder().id(idParam.getId()).build()));
        if (userOptional.isEmpty()) return Result.no(Status.BAD_REQUEST);

        User user = userOptional.get();
        user.setEnabled(!user.getEnabled());

        userRepository.save(user);

        return Result.ok();
    }

    @Override
    public Result<String> modifyUser(UserModifyParam userModifyParam) {
        Optional<User> userOptional = userRepository.findOne(
            Example.of(User.builder().id(userModifyParam.getId()).build())
        );

        if (userOptional.isEmpty()) return Result.no(Status.BAD_REQUEST, "用户不存在");

        User user = userOptional.get();

        if (
            !StrUtil.equals(user.getMobile(), userModifyParam.getMobile()) &&
            StrUtil.isNotEmpty(userModifyParam.getMobile())
        ) {
            // 验证手机号码是否相同
            long count = userRepository.count(Example.of(User.builder().mobile(userModifyParam.getMobile()).build()));
            if (count > 0) {
                return Result.no(Status.BAD_REQUEST, "手机号码已存在");
            }
        }

        // 获取部门信息
        Optional<Department> departmentOptional = departmentRepository.findOne(
            Example.of(Department.builder().id(userModifyParam.getDeptId()).build())
        );

        if (departmentOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST);
        }

        Long linkId = departmentOptional.get().getLinkId();

        user.setDepartment(departmentOptional.get());
        UserModifyParam.transform(userModifyParam, user);

        ZyUserModifyParam zyUserModifyParam = ZyUserModifyParam.transform(user, FACTORY_ID);
        zyUserModifyParam.setId(user.getLinkId());
        zyUserModifyParam.setDeptId(linkId);
        zyUserModifyParam.setEntityIconId(user.getIsSpecial() ? 10028 : 1);
        JSONObject jsonObject = userClient.save(JSONUtil.toJsonStr(zyUserModifyParam), ZyUtil.clientLogin());
        if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
        }

        userRepository.save(user);

        return Result.ok();
    }

    @Override
    public Result<String> addUser(UserAddParam userAddParam) {
        User user = UserAddParam.transform(userAddParam);

        // 验证手机号码是否相同
        if (StrUtil.isNotEmpty(userAddParam.getMobile())) {
            long count = userRepository.count(Example.of(User.builder().mobile(userAddParam.getMobile()).build()));
            if (count > 0) {
                return Result.no(Status.BAD_REQUEST, "手机号码已存在");
            }
        }

        // 获取部门信息
        Optional<Department> departmentOptional = departmentRepository.findOne(
            Example.of(Department.builder().id(userAddParam.getDeptId()).build())
        );

        if (departmentOptional.isEmpty()) {
            return Result.no(Status.BAD_REQUEST);
        }

        Long linkId = departmentOptional.get().getLinkId();
        user.setDepartment(departmentOptional.get());

        ZyUserAddParam zyUserAddParam = ZyUserAddParam.transform(user, FACTORY_ID);
        zyUserAddParam.setDeptId(linkId);
        zyUserAddParam.setEntityIconId(user.getIsSpecial() ? 10028 : 1);

        JSONObject jsonObject = userClient.save(JSONUtil.toJsonStr(zyUserAddParam), ZyUtil.clientLogin());
        if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
        }

        ZyUserFindParam zyUserFindParam = ZyUserFindParam
            .builder()
            .orgId(FACTORY_ID)
            .jobNum(zyUserAddParam.getJobNumber())
            .type(1)
            .pageNum(1)
            .pageSize(1)
            .build();
        JSONObject result = userClient.list(JSONUtil.toJsonStr(zyUserFindParam), ZyUtil.clientLogin());
        if (!ObjectUtil.equals(result.get("code"), 200)) {
            throw new RuntimeException(StrUtil.toString(result.get("msg")));
        }

        JSONObject data = JSONUtil.parseObj(result.get("data"));
        JSONArray records = JSONUtil.parseArray(data.get("records"));

        // 拿第一个数据的id
        Object id = JSONUtil.parseObj(records.get(0)).get("id");

        // 绑定post
        if (ObjectUtil.isNotEmpty(userAddParam.getPostId())) {
            Optional<Post> postOptional = postRepository.findOne(
                Example.of(Post.builder().id(userAddParam.getPostId()).build())
            );

            postOptional.ifPresent(user::setPost);
        }
        user.setLinkId(Convert.toLong(id));
        userRepository.save(user);

        return Result.ok();
    }

    @Override
    public Result<String> importUser(MultipartFile file) {
        if (file.isEmpty()) return Result.no(Status.BAD_REQUEST, "请选择文件");
        List<UserImportExcel> userImportExcels;
        try (InputStream inputStream = file.getInputStream()) {
            userImportExcels =
                SaxExcelReader
                    .of(UserImportExcel.class)
                    .rowFilter(row -> row.getRowNum() > 0)
                    .ignoreBlankRow()
                    .read(inputStream);
        } catch (IOException e) {
            log.info(e.getMessage());
            throw new RuntimeException("文件导入异常");
        }
        // 部门信息
        HashMap<String, Department> hashMap = departmentService.getStringDepartmentHashMap();

        // 职位信息
        Map<String, List<Post>> postMap = postRepository
            .findAll()
            .stream()
            .collect(Collectors.groupingBy(Post::getName));

        userImportExcels =
            userImportExcels
                .stream()
                .filter(userImportExcel ->
                    userRepository.count(Example.of(User.builder().uuid(userImportExcel.getUuid()).build())) == 0
                )
                .filter(userImportExcel ->
                    locationTagRepository.count(
                        Example.of(LocationTag.builder().code(userImportExcel.getCode()).used(true).build())
                    ) ==
                    0
                )
                .collect(Collectors.toList());

        userImportExcels.forEach(userImportExcel -> {
            User user = UserImportExcel.transform(userImportExcel);
            Department department = hashMap.get(userImportExcel.getDeptName());

            ZyUserAddParam zyUserAddParam = ZyUserAddParam.transform(user, FACTORY_ID);
            zyUserAddParam.setDeptId(department.getLinkId());
            zyUserAddParam.setEntityIconId(user.getIsSpecial() ? 10028 : 1);

            JSONObject jsonObject = userClient.save(JSONUtil.toJsonStr(zyUserAddParam), ZyUtil.clientLogin());
            if (!ObjectUtil.equals(jsonObject.get("code"), 200)) {
                throw new RuntimeException(StrUtil.toString(jsonObject.get("msg")));
            }

            ZyUserFindParam zyUserFindParam = ZyUserFindParam
                .builder()
                .orgId(FACTORY_ID)
                .jobNum(zyUserAddParam.getJobNumber())
                .type(1)
                .pageNum(1)
                .pageSize(1)
                .build();
            JSONObject result = userClient.list(JSONUtil.toJsonStr(zyUserFindParam), ZyUtil.clientLogin());
            if (!ObjectUtil.equals(result.get("code"), 200)) {
                throw new RuntimeException(StrUtil.toString(result.get("msg")));
            }

            JSONObject data = JSONUtil.parseObj(result.get("data"));
            JSONArray records = JSONUtil.parseArray(data.get("records"));

            // 拿第一个数据的id
            Object id = JSONUtil.parseObj(records.get(0)).get("id");

            Post post = postMap.get(userImportExcel.getPostName()).get(0);
            user.setLinkId(Convert.toLong(id));
            user.setDepartment(department);
            user.setPost(post);
            User saveUser = userRepository.save(user);
            if (StrUtil.isNotEmpty(userImportExcel.getCode())) {
                LocationTag locationTag = LocationTag.builder().code(userImportExcel.getCode()).user(saveUser).build();
                locationTagRepository.save(locationTag);
            }
        });

        return Result.ok();
    }

    @Override
    public Result<PageVo<UserVo>> indexUser(IndexParam indexParam) {
        CriteriaBuilder cb = em.getCriteriaBuilder();
        CriteriaQuery<UserVo> cq = cb.createQuery(UserVo.class);
        Root<User> root = cq.from(User.class);
        Expression<Long> id = root.get(BasicEntity.Fields.id);
        Expression<String> realName = root.get(User.Fields.realName);
        Expression<String> avatar = root.get(User.Fields.avatar);
        Expression<String> uuid = root.get(User.Fields.uuid);
        Expression<User.Type> type = root.get(User.Fields.type);
        Expression<Boolean> gender = root.get(User.Fields.gender);
        Expression<Boolean> isSpecial = root.get(User.Fields.isSpecial);
        Expression<String> mobile = root.get(User.Fields.mobile);

        Join<User, Department> departmentJoin = root.join(User.Fields.department, JoinType.LEFT);
        Expression<String> department = departmentJoin.get(Department.Fields.name);
        Expression<Long> departmentId = departmentJoin.get(BasicEntity.Fields.id);

        Join<User, Post> postJoin = root.join(User.Fields.post, JoinType.LEFT);
        Expression<String> post = postJoin.get(Post.Fields.name);
        Expression<Long> postId = departmentJoin.get(BasicEntity.Fields.id);

        Subquery<String> query = cq.subquery(String.class);
        Root<LocationTag> tagRoot = query.from(LocationTag.class);
        query.select(tagRoot.get(LocationTag.Fields.code));
        query.where(cb.equal(tagRoot.get(LocationTag.Fields.user), root));

        cq.multiselect(
            id,
            realName,
            uuid,
            type,
            department,
            mobile,
            post,
            query,
            gender,
            isSpecial,
            departmentId,
            postId,
            avatar
        );
        List<Predicate> predicates = ListUtil.toList();

        if (StrUtil.isNotEmpty(indexParam.getStr())) {
            if (StrUtil.isNumeric(indexParam.getStr())) {
                predicates.add(cb.like(root.get(User.Fields.mobile), indexParam.getStr() + "%"));
            } else {
                predicates.add(cb.like(root.get(User.Fields.realName), indexParam.getStr() + "%"));
            }
        }

        Order order = cb.desc(root.get(BasicEntity.Fields.createTime));

        cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();

        List<UserVo> userVos = em.createQuery(cq).getResultList();
        PageVo<UserVo> page = PageVo.build(userVos, getCount());

        return Result.ok(page);
    }

    @Override
    public Result<PageVo<UserVo>> findUser(UserFindParam userFindParam) {
        Specification<User> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (ObjectUtil.isNotEmpty(userFindParam.getDeptId())) {
                predicates.add(
                    cb.equal(root.get(User.Fields.department).get(BasicEntity.Fields.id), userFindParam.getDeptId())
                );
            }

            if (ObjectUtil.isNotEmpty(userFindParam.getRealName())) {
                predicates.add(cb.like(root.get(User.Fields.realName), "%" + userFindParam.getRealName() + "%"));
            }

            Order order = cb.desc(root.get(BasicEntity.Fields.createTime));
            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };
        List<User> users = userRepository.findAll(specification);
        List<UserVo> userVos = users
            .stream()
            .map(user -> {
                UserVo userVo = UserVo.builder().id(user.getId()).realName(user.getRealName()).build();
                if (ObjectUtil.isNotEmpty(user.getDepartment())) {
                    userVo.setDepartment(user.getDepartment().getName());
                    userVo.setDepartmentId(user.getDepartment().getId());
                }
                return userVo;
            })
            .collect(Collectors.toList());
        PageVo<UserVo> pageVo = PageVo.build(userVos, userVos.size());

        return Result.ok(pageVo);
    }

    @NotNull
    private CriteriaQuery<UserVo> getUserVoCriteriaQuery(UserFindParam param) {
        CriteriaBuilder cb = em.getCriteriaBuilder();
        CriteriaQuery<UserVo> cq = cb.createQuery(UserVo.class);
        Root<User> root = cq.from(User.class);
        Expression<Long> id = root.get(BasicEntity.Fields.id);
        Expression<String> realName = root.get(User.Fields.realName);
        Expression<String> avatar = root.get(User.Fields.avatar);
        Expression<String> uuid = root.get(User.Fields.uuid);
        Expression<User.Type> type = root.get(User.Fields.type);
        Expression<Boolean> gender = root.get(User.Fields.gender);
        Expression<Boolean> isSpecial = root.get(User.Fields.isSpecial);
        Expression<String> mobile = root.get(User.Fields.mobile);

        Join<User, Department> departmentJoin = root.join(User.Fields.department, JoinType.LEFT);
        Expression<String> department = departmentJoin.get(Department.Fields.name);
        Expression<Long> departmentId = departmentJoin.get(BasicEntity.Fields.id);

        Join<User, Post> postJoin = root.join(User.Fields.post, JoinType.LEFT);
        Expression<String> post = postJoin.get(Post.Fields.name);
        Expression<Long> postId = postJoin.get(BasicEntity.Fields.id);

        Subquery<String> query = cq.subquery(String.class);
        Root<LocationTag> tagRoot = query.from(LocationTag.class);
        query.select(tagRoot.get(LocationTag.Fields.code));
        query.where(cb.equal(tagRoot.get(LocationTag.Fields.user), root));

        cq.multiselect(
            id,
            realName,
            uuid,
            type,
            department,
            mobile,
            post,
            query,
            gender,
            isSpecial,
            departmentId,
            postId,
            avatar
        );

        List<Predicate> predicates = ListUtil.toList();

        if (StrUtil.isNotEmpty(param.getRealName())) {
            predicates.add(cb.like(root.get(User.Fields.realName), "%" + param.getRealName() + "%"));
        }

        if (StrUtil.isNotEmpty(param.getCode())) {
            predicates.add(cb.like(query, "%" + param.getCode() + "%"));
        }

        if (StrUtil.isNotEmpty(param.getUuid())) {
            predicates.add(cb.like(root.get(User.Fields.uuid), "%" + param.getUuid() + "%"));
        }

        if (StrUtil.isNotEmpty(param.getMobile())) {
            predicates.add(cb.like(root.get(User.Fields.mobile), "%" + param.getMobile() + "%"));
        }

        if (ObjectUtil.isNotEmpty(param.getDeptId())) {
            predicates.add(cb.equal(root.get(User.Fields.department).get("id"), param.getDeptId()));
        }

        Order order = cb.desc(root.get(BasicEntity.Fields.createTime));

        cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        return cq;
    }

    public Long getCount() {
        return userRepository.count();
    }
}
