/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.video;

import com.yiring.app.domain.video.Video;
import com.yiring.app.param.video.VideoParam;
import com.yiring.app.param.video.VideoQueryParam;
import com.yiring.app.vo.video.VideoNameVo;
import com.yiring.app.vo.video.VideoVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.vo.PageVo;
import java.awt.*;
import javax.servlet.http.HttpServletResponse;
import org.locationtech.jts.geom.Point;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author tzl
 * 2022/4/8 15:28
 */
public interface VideoService {
    /**
     * 监控视频点位添加
     *
     * @param videoParam VideoParam
     * @return Result<String>
     * @author tzl
     * @date 2022/4/8 16:23
     */
    Result<String> saveVideo(VideoParam videoParam);

    /**
     * 删除监控点位信息
     * @param idParam 主键id
     * @return Result<String>
     * @author tzl
     * @date 2022/4/15 10:16
     */
    Result<String> deleteVideo(IdParam idParam);

    /**
     * 修改监控点位信息
     * @param videoParam 修改的参数
     * @param idParam    主键id
     * @return Result<String>
     * @author tzl
     * @date 2022/4/15 10:19
     */
    Result<String> updateVideo(VideoParam videoParam, IdParam idParam);

    /**
     * 查询监控点坐标
     * @param idParam 主键id
     * @return Result<Point> 坐标信息
     * @author tzl
     * @date 2022/4/15 14:15
     */
    Result<Point> selectPoint(IdParam idParam);

    /**
     * 分页查询
     * @param videoQueryParam 筛选条件
     * @return Result<PageVo<VideoVo>> 分页结果集
     * @author tzl
     * @date 2022/4/15 14:35
     */
    Result<PageVo<VideoVo>> pageVideo(VideoQueryParam videoQueryParam);

    /**
     * 查询条件
     * @param videoQueryParam 查询条件
     * @return Specification<Video>
     * @author tzl
     * @date 2022/4/15 14:57
     */
    Specification<Video> condition(VideoQueryParam videoQueryParam);

    /**
     *  条件查询数据导出
     * @param videoQueryParam 查询条件
     * @param response HttpServletResponse
     */
    void exportVideo(VideoQueryParam videoQueryParam, HttpServletResponse response);

    /**
     * 导入视频监控点位信息
     * @param file  上传的excel文件
     * @return 是否成功
     */
    Result<String> importVideo(MultipartFile file);

    /**
     * 根据监控点位名称模糊查询
     * @author tzl
     * @date 2022/4/27 13:51
     * @param indexParam 入参
     * @return com.yiring.common.core.Result<com.yiring.app.vo.video.VideoNameVo>
     */
    Result<VideoNameVo> findByVideoNameLike(IndexParam indexParam);
}
