/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.visitor;

import com.yiring.app.domain.visitor.Car;
import com.yiring.app.param.visitor.CarQueryParam;
import com.yiring.app.vo.visitor.CarVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;
import org.springframework.data.jpa.domain.Specification;

/**
 * @author tzl
 * 2022/4/11 13:57
 */
public interface CarService {
    /**
     * 添加车辆来访信息
     *
     * @param car Car
     * @return 车辆来访信息id
     */
    Result<Long> saveCarInfo(Car car);

    /**
     * 修改车辆来访信息
     *
     * @param car Car
     * @return 修改的车辆来访信息id
     */
    Result<Long> updateCarInfo(Car car);

    /**
     * 收卡
     *
     * @param idParam IdParam
     * @return 收卡信息id
     */
    Result<Long> cardRec(IdParam idParam);

    /**
     * 发卡
     *
     * @param idParam IdParam
     * @param labelCard String
     * @return 发卡信息id
     */
    Result<Long> cardSend(IdParam idParam, String labelCard);

    /**
     * 删除车辆来访信息
     *
     * @param idParam IdParam
     * @return String
     */
    Result<String> deleteCarInfo(IdParam idParam);

    /**
     * 查询车辆来访信息详情
     *
     * @param idParam IdParam
     * @return 车辆来访信息
     */
    Result<CarVo> getCarInfo(IdParam idParam);

    /**
     * 查询车辆来访信息(分页)
     *
     * @param carParam CarParam
     * @return 车辆来访信息分页数据
     */
    Result<PageVo<CarVo>> pageCarInfo(CarQueryParam carParam);

    /**
     *  导出接口
     * @param carParam CarQueryParam
     * @param response HttpServletResponse
     */
    void export(CarQueryParam carParam, HttpServletResponse response);

    //    /**
    //     * 检查是否存在相同车牌号登记
    //     *
    //     * @param param String 车牌号码
    //     * @return 是否存在
    //     */
    //    boolean hasCarInfoByCarNum(String param);
    //
    //    /**
    //     *  检查是否存在相同手机号码登记
    //     *
    //     * @param param String 手机号码
    //     * @return 是否存在
    //     */
    //    boolean hasCarInfoByMobile(String param);

    /**
     * 筛选条件
     * @param carParam CarQueryParam
     * @return Specification
     */
    Specification<Car> condition(CarQueryParam carParam);
}
