/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.visitor;

import com.yiring.app.param.visitor.InvitationAppQueryParam;
import com.yiring.app.param.visitor.InvitationParam;
import com.yiring.app.param.visitor.InvitationQueryParam;
import com.yiring.app.vo.visitor.InvitationDetailsVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;

/**
 * @author tzl
 * @date 2022/4/24 16:57
 */
public interface InvitationService {
    /**
     * 发起邀请
     * @param invitationParam 新增邀请入参
     * @return 是否成功
     */
    Result<String> saveInv(InvitationParam invitationParam);
    /**
     * 修改邀请
     * @date 2022/4/24 17:50
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> updateInv(InvitationParam invitationParam, IdParam idParam);

    /**
     * 删除邀请
     * @date 2022/4/24 17:52
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> deleteInv(IdParam idParam);
    /**
     * 分页
     * @date 2022/4/24 17:56
     * @return com.yiring.common.core.Result<com.yiring.common.vo.PageVo<java.lang.String>>
     */
    Result<PageVo<InvitationDetailsVo>> pageInv(InvitationQueryParam invitationQueryParam);

    /**
     * 撤回邀请
     * @author tzl
     * @date 2022/4/25 11:30
     * @param idParam 主键id
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> recallInv(IdParam idParam);

    /**
     * 发送邀请
     * @author tzl
     * @date 2022/4/25 11:31
     * @param idParam 主键id
     * @return com.yiring.common.core.Result<java.lang.String>
     */
    Result<String> sendInv(IdParam idParam);

    /**
     * 导出邀请信息
     * @author tzl
     * @date 2022/4/25 11:34
     * @param invitationQueryParam  筛选条件
     */
    void exportInv(InvitationQueryParam invitationQueryParam, HttpServletResponse response);

    /**
     *  小程序查询全部
     * @author tzl
     * @date 2022/4/28 10:56
     * @param idParam 主键id
     * @return com.yiring.common.core.Result<com.yiring.app.vo.visitor.InvitationDetailsVo>
     */
    Result<InvitationDetailsVo> detailsInv(IdParam idParam);

    /**
     * 小程序用户查看邀请信息
     * @author tzl
     * @date 2022/4/28 11:30
     * @param invitationAppQueryParam 入参
     * @return com.yiring.common.core.Result<com.yiring.common.vo.PageVo<com.yiring.app.vo.visitor.InvitationVo>>
     */
    Result<PageVo<InvitationDetailsVo>> findAllByVisitor_VisitorMobileAndVisitor_Deleted(
        InvitationAppQueryParam invitationAppQueryParam
    );
}
