/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.visitor.impl;

import cn.hutool.core.util.StrUtil;
import com.github.liaochong.myexcel.core.DefaultStreamExcelBuilder;
import com.yiring.app.domain.visitor.Invitation;
import com.yiring.app.domain.visitor.InvitationRepository;
import com.yiring.app.domain.visitor.Visitor;
import com.yiring.app.domain.visitor.VisitorRepository;
import com.yiring.app.excel.visitor.InvitationExportExcel;
import com.yiring.app.param.visitor.InvitationAppQueryParam;
import com.yiring.app.param.visitor.InvitationParam;
import com.yiring.app.param.visitor.InvitationQueryParam;
import com.yiring.app.service.visitor.InvitationService;
import com.yiring.app.vo.visitor.InvitationDetailsVo;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.user.User;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.concurrent.Executors;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.Join;
import javax.persistence.criteria.JoinType;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import javax.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.BeanUtils;
import org.springframework.data.domain.*;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/4/24 17:05
 */
@Slf4j
@Transactional(rollbackFor = RuntimeException.class)
@Service
public class InvitationServiceImpl implements InvitationService {

    @Resource
    InvitationRepository invitationRepository;

    @Resource
    VisitorRepository visitorRepository;

    @Override
    public Result<String> saveInv(InvitationParam invitationParam) {
        User user = User.builder().id(invitationParam.getInviterId()).build();
        Visitor visitor = new Visitor();
        BeanUtils.copyProperties(invitationParam, visitor);
        visitor.setUser(user);
        visitor.setCreateTime(LocalDateTime.now());
        //身份证验证
        //        if(StrUtil.isNotBlank(invitationParam.getVisitorCarNum())){
        //            if (invitationParam.getVisitorCarNum().matches(RegEx.)) {
        //                return Result.no(Status.BAD_REQUEST, "请输入正确的车牌号码");
        //            }
        //        }
        //设置创建时间和默认状态
        Invitation invitation = Invitation
            .builder()
            .createTime(LocalDateTime.now())
            .updateTime(LocalDateTime.now())
            .status("已发送")
            .visitor(visitor)
            .InvitationMethod(invitationParam.getInvitationMethod())
            .numOfVisitor(invitationParam.getNumOfVisitor())
            .user(user)
            .build();
        //添加一条访客未到访信息
        if (invitationParam.getInvitationMethod().equals("1")) {
            visitor.setVisitorSource("邀请个人");
        } else {
            visitor.setVisitorSource("邀请公司");
        }
        visitorRepository.saveAndFlush(visitor);

        invitationRepository.saveAndFlush(invitation);
        //短信通知该手机用户

        return Result.ok();
    }

    @Override
    public Result<String> updateInv(InvitationParam invitationParam, IdParam idParam) {
        Optional<Invitation> optional = invitationRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }

        Invitation invitation = optional.get();

        Visitor visitor2 = invitation.getVisitor();
        if (invitation.getVisitor().getCardSendTime() != null) {
            return Result.no(Status.BAD_REQUEST, "访客已到访,无法修改");
        }
        BeanUtils.copyProperties(invitationParam, invitation);

        invitation.setUpdateTime(LocalDateTime.now());
        invitationRepository.saveAndFlush(invitation);
        //修改访客未到访信息
        if (visitor2 == null) {
            //            为空添加
            visitor2 = new Visitor();
        }
        BeanUtils.copyProperties(invitationParam, visitor2);
        visitor2.setUser(invitation.getUser());
        //        visitor2.setIntervieweeId(invitationParam.getInviterId());
        visitorRepository.saveAndFlush(visitor2);
        //短信通知该手机用户
        //
        //

        return Result.ok();
    }

    @Override
    public Result<String> deleteInv(IdParam idParam) {
        Optional<Invitation> optional = invitationRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }
        Invitation invitation = optional.get();
        invitationRepository.delete(invitation);
        //        visitorRepository.delete(invitation.getVisitor());
        //短信通知该手机用户邀请取消
        //
        //
        return Result.ok();
    }

    @Override
    public Result<PageVo<InvitationDetailsVo>> pageInv(InvitationQueryParam invitationQueryParam) {
        PageVo<InvitationDetailsVo> resultVo;
        //排序
        Sort sort = Sort.by(Sort.Order.desc(Invitation.Fields.updateTime));
        if (Objects.nonNull(invitationQueryParam.getPageNo()) && Objects.nonNull(invitationQueryParam.getPageSize())) {
            //分页
            Pageable pageable = PageRequest.of(
                invitationQueryParam.getPageNo() - 1,
                invitationQueryParam.getPageSize()
            );
            Page<Invitation> all = invitationRepository.findAll(condition(invitationQueryParam), pageable);
            List<InvitationDetailsVo> data = all
                .get()
                .map(invitation -> {
                    InvitationDetailsVo vo = new InvitationDetailsVo();
                    BeanUtils.copyProperties(invitation, vo);
                    //翻译邀请人姓名,部门
                    if (invitation.getUser() != null) {
                        InvitationDetailsVo.User user = new InvitationDetailsVo.User();
                        user.setDeptName(invitation.getUser().getDepartment().getName());
                        user.setRealName(invitation.getUser().getRealName());
                        user.setMobile(invitation.getUser().getMobile());
                        user.setId(invitation.getUser().getId());
                        vo.setUser(user);
                    }
                    return vo;
                })
                .collect(Collectors.toList());
            resultVo = PageVo.build(data, all.getTotalElements());
        } else {
            List<Invitation> all = invitationRepository.findAll(condition(invitationQueryParam), sort);
            List<InvitationDetailsVo> data = all
                .stream()
                .map(invitation -> {
                    InvitationDetailsVo vo = new InvitationDetailsVo();
                    BeanUtils.copyProperties(invitation, vo);
                    //翻译邀请人姓名,部门
                    if (invitation.getUser() != null) {
                        InvitationDetailsVo.User user = new InvitationDetailsVo.User();
                        user.setDeptName(invitation.getUser().getDepartment().getName());
                        user.setRealName(invitation.getUser().getRealName());
                        user.setMobile(invitation.getUser().getMobile());
                        user.setId(invitation.getUser().getId());
                        vo.setUser(user);
                    }
                    return vo;
                })
                .collect(Collectors.toList());
            resultVo = PageVo.build(data, data.size());
        }
        return Result.ok(resultVo);
    }

    @Override
    public Result<String> recallInv(IdParam idParam) {
        Optional<Invitation> optional = invitationRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }
        Invitation invitation = optional.get();
        if (invitation.getVisitor().getCardSendTime() != null) {
            return Result.no(Status.BAD_REQUEST, "访客已到访,无法修改");
        }
        if (invitation.getVisitor().getAppOfVisitTime().isBefore(LocalDateTime.now())) {
            return Result.no(Status.BAD_REQUEST, "预约时间已过");
        }
        invitation.setStatus("已撤回");
        invitation.setUpdateTime(LocalDateTime.now());
        Visitor visitor = invitation.getVisitor();
        //        逻辑删除对应访客信息
        if (visitor != null) {
            visitor.setDeleted("Y");
            visitorRepository.saveAndFlush(visitor);
        }
        invitationRepository.saveAndFlush(invitation);
        return Result.ok();
    }

    @Override
    public Result<String> sendInv(IdParam idParam) {
        Optional<Invitation> optional = invitationRepository.findById(idParam.getId());
        if (optional.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }
        Invitation invitation = optional.get();
        if (invitation.getVisitor().getAppOfVisitTime().isBefore(LocalDateTime.now())) {
            return Result.no(Status.BAD_REQUEST, "预约时间已过");
        }
        invitation.setStatus("已发送");
        invitation.setUpdateTime(LocalDateTime.now());
        //添加访客信息
        Visitor visitor = invitation.getVisitor();
        //
        if (visitor != null) {
            visitor.setDeleted("N");
            visitorRepository.saveAndFlush(visitor);
        }
        invitationRepository.saveAndFlush(invitation);
        return Result.ok();
    }

    @Override
    public void exportInv(InvitationQueryParam invitationQueryParam, HttpServletResponse response) {
        List<Invitation> invitations = invitationRepository.findAll(condition(invitationQueryParam));

        List<InvitationExportExcel> invitationExportExcels = invitations
            .stream()
            .map(invitation -> {
                InvitationExportExcel invitationExportExcel = new InvitationExportExcel();
                BeanUtils.copyProperties(invitation, invitationExportExcel);
                BeanUtils.copyProperties(invitation.getVisitor(), invitationExportExcel);
                invitationExportExcel.setInviterName(invitation.getUser().getRealName());
                invitationExportExcel.setInviterDept(invitation.getUser().getDepartment().getName());

                return invitationExportExcel;
            })
            .toList();

        try (
            DefaultStreamExcelBuilder<InvitationExportExcel> defaultStreamExcelBuilder = DefaultStreamExcelBuilder
                .of(InvitationExportExcel.class)
                .threadPool(Executors.newFixedThreadPool(2))
                .rowHeight(14)
                .titleRowHeight(14)
                .widths(8)
                .style(
                    "cell->vertical-align:center;text-align:center",
                    "title->vertical-align:center;text-align:center;font-weight:bold;font-family:等线"
                )
                .start()
        ) {
            defaultStreamExcelBuilder.append(invitationExportExcels);

            String fileName = URLEncoder.encode("邀请信息.xlsx", StandardCharsets.UTF_8);
            response.setContentType("application/octet-stream");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            OutputStream out = response.getOutputStream();

            Workbook workbook = defaultStreamExcelBuilder.fixedTitles().build();
            workbook.write(out);
            workbook.close();
            out.flush();
            out.close();
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new RuntimeException("导出邀请信息失败: " + e.getMessage());
        }
    }

    @Override
    public Result<InvitationDetailsVo> detailsInv(IdParam idParam) {
        Optional<Invitation> byId = invitationRepository.findById(idParam.getId());
        if (byId.isEmpty()) {
            return Result.no(Status.NOT_FOUND);
        }
        Invitation invitation = byId.get();
        InvitationDetailsVo vo = new InvitationDetailsVo();
        BeanUtils.copyProperties(invitation, vo);
        //翻译邀请人姓名,部门
        if (invitation.getUser() != null) {
            InvitationDetailsVo.User user = new InvitationDetailsVo.User();
            user.setDeptName(invitation.getUser().getDepartment().getName());
            user.setRealName(invitation.getUser().getRealName());
            user.setMobile(invitation.getUser().getMobile());
            vo.setUser(user);
        }
        return Result.ok(vo);
    }

    @Override
    public Result<PageVo<InvitationDetailsVo>> findAllByVisitor_VisitorMobileAndVisitor_Deleted(
        InvitationAppQueryParam invitationAppQueryParam
    ) {
        PageVo<InvitationDetailsVo> resultVo;
        //排序
        Sort sort = Sort.by(Sort.Order.desc(Visitor.Fields.createTime));
        if (
            Objects.nonNull(invitationAppQueryParam.getPageNo()) &&
            Objects.nonNull(invitationAppQueryParam.getPageSize())
        ) {
            //分页
            Pageable pageable = PageRequest.of(
                invitationAppQueryParam.getPageNo() - 1,
                invitationAppQueryParam.getPageSize()
            );
            Page<Invitation> all = invitationRepository.findAllByVisitor_VisitorMobileAndVisitor_Deleted(
                invitationAppQueryParam.getVisitorMobile(),
                "N",
                pageable
            );
            List<InvitationDetailsVo> data = all
                .get()
                .map(invitationResult -> {
                    InvitationDetailsVo vo = new InvitationDetailsVo();
                    BeanUtils.copyProperties(invitationResult, vo);
                    //翻译邀请人姓名,部门
                    return getInvitationDetailsVo(invitationResult, vo);
                })
                .collect(Collectors.toList());
            resultVo = PageVo.build(data, all.getTotalElements());
        } else {
            Visitor visitor = Visitor
                .builder()
                .visitorMobile(invitationAppQueryParam.getVisitorMobile())
                .deleted("N")
                .build();
            Invitation invitation = Invitation.builder().visitor(visitor).build();
            List<Invitation> all = invitationRepository.findAll(Example.of(invitation), sort);
            List<InvitationDetailsVo> data = all
                .stream()
                .map(invitationResult -> {
                    InvitationDetailsVo vo = new InvitationDetailsVo();
                    BeanUtils.copyProperties(invitationResult, vo);
                    //翻译邀请人姓名,部门
                    return getInvitationDetailsVo(invitationResult, vo);
                })
                .collect(Collectors.toList());
            resultVo = PageVo.build(data, data.size());
        }
        return Result.ok(resultVo);
    }

    private InvitationDetailsVo getInvitationDetailsVo(Invitation invitationResult, InvitationDetailsVo vo) {
        if (invitationResult.getUser() != null) {
            InvitationDetailsVo.User user = new InvitationDetailsVo.User();
            user.setDeptName(invitationResult.getUser().getDepartment().getName());
            user.setRealName(invitationResult.getUser().getRealName());
            user.setMobile(invitationResult.getUser().getMobile());
            vo.setUser(user);
        }
        return vo;
    }

    public Specification<Invitation> condition(InvitationQueryParam invitationQueryParam) {
        return (root, query, criteriaBuilder) -> {
            Join<Invitation, Visitor> joinVisitor = root.join("visitor", JoinType.LEFT);
            Join<Invitation, User> joinUser = joinVisitor.join("user", JoinType.LEFT);
            Join<User, Department> departmentJoin = joinUser.join("department", JoinType.LEFT);
            //            Join<User, Department> joinDepartment = root.join(User.Fields.department, JoinType.LEFT);
            List<Predicate> list = new ArrayList<>();
            if (StrUtil.isNotBlank(invitationQueryParam.getVisitorName())) {
                list.add(
                    criteriaBuilder.like(
                        joinVisitor.get(Visitor.Fields.visitorName).as(String.class),
                        "%" + invitationQueryParam.getVisitorName() + "%"
                    )
                );
            }

            if (StrUtil.isNotBlank(invitationQueryParam.getVisitorMobile())) {
                list.add(
                    criteriaBuilder.like(
                        joinVisitor.get(Visitor.Fields.visitorMobile).as(String.class),
                        "%" + invitationQueryParam.getVisitorMobile() + "%"
                    )
                );
            }

            if (StrUtil.isNotBlank(invitationQueryParam.getOrgId())) {
                list.add(
                    criteriaBuilder.like(
                        joinVisitor.get(Visitor.Fields.orgId).as(String.class),
                        "%" + invitationQueryParam.getOrgId() + "%"
                    )
                );
            }
            if (StrUtil.isNotBlank(invitationQueryParam.getTaskType())) {
                list.add(
                    criteriaBuilder.equal(
                        joinVisitor.get(Visitor.Fields.taskType).as(String.class),
                        invitationQueryParam.getTaskType()
                    )
                );
            }

            if (invitationQueryParam.getRealName() != null) {
                list.add(
                    criteriaBuilder.like(
                        joinUser.get(User.Fields.realName).as(String.class),
                        "%" + invitationQueryParam.getRealName() + "%"
                    )
                );
            }

            if (invitationQueryParam.getDeptName() != null) {
                list.add(
                    criteriaBuilder.like(
                        departmentJoin.get(Department.Fields.name).as(String.class),
                        "%" + invitationQueryParam.getDeptName() + "%"
                    )
                );
            }

            if (
                Objects.nonNull(invitationQueryParam.getAppOfVisitTimeStart()) &&
                Objects.nonNull(invitationQueryParam.getAppOfVisitTimeEnd())
            ) {
                //预约到访时间区间段查询
                list.add(
                    criteriaBuilder.between(
                        joinVisitor.get(Visitor.Fields.appOfVisitTime),
                        invitationQueryParam.getAppOfVisitTimeStart(),
                        invitationQueryParam.getAppOfVisitTimeEnd()
                    )
                );
            }
            Order order = criteriaBuilder.desc(root.get(Invitation.Fields.updateTime));
            Predicate[] predicates = new Predicate[list.size()];
            query.where(list.toArray(predicates));
            query.orderBy(order);
            return criteriaBuilder.and(list.toArray(predicates));
        };
    }
    //    /**
    //     * 查看被邀人手机号码是否已经发出邀请
    //     *
    //     * @param mobile 手机号码
    //     * @return boolean
    //     * @author tzl
    //     * @date 2022/4/24 17:27
    //     */
    //    public boolean hasVisitorMobile(String mobile) {
    //        Invitation invitation = Invitation.builder().visitorMobile(mobile).status("已发送").build();
    //        long count = invitationRepository.count(Example.of(invitation));
    //        return count > 0;
    //    }
}
