/* (C) 2022 YiRing, Inc. */
package com.yiring.app.stomp;

import com.alibaba.fastjson.JSON;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.springframework.messaging.Message;
import org.springframework.messaging.MessageChannel;
import org.springframework.messaging.simp.stomp.StompCommand;
import org.springframework.messaging.simp.stomp.StompHeaderAccessor;
import org.springframework.messaging.support.ChannelInterceptor;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.messaging.support.MessageHeaderAccessor;
import org.springframework.stereotype.Component;

/**
 * ClientOutboundChannelInterceptor
 * 向客户端输出消息的拦截器
 *
 * @author ifzm
 * @version 0.1
 * 2019/10/12 11:05
 */

@Slf4j
@Component
public class ClientOutboundChannelInterceptor implements ChannelInterceptor {

    @Override
    public Message<?> preSend(@NonNull Message<?> message, @NonNull MessageChannel channel) {
        StompHeaderAccessor accessor = MessageHeaderAccessor.getAccessor(message, StompHeaderAccessor.class);
        assert accessor != null;
        if (StompCommand.CONNECTED.equals(accessor.getCommand())) {
            StompPrincipal principal = (StompPrincipal) accessor.getUser();
            return MessageBuilder.createMessage(JSON.toJSONBytes(principal), message.getHeaders());
        }

        return message;
    }
}
