/* (C) 2022 YiRing, Inc. */
package com.yiring.app.stomp;

import com.alibaba.fastjson.JSON;
import com.yiring.auth.domain.user.User;
import com.yiring.auth.util.Auths;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.util.Commons;
import java.util.Objects;
import java.util.Set;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.messaging.handler.annotation.MessageMapping;
import org.springframework.messaging.simp.SimpMessagingTemplate;
import org.springframework.messaging.simp.stomp.StompHeaderAccessor;
import org.springframework.messaging.simp.user.SimpUser;
import org.springframework.messaging.simp.user.SimpUserRegistry;
import org.springframework.stereotype.Controller;

/**
 * STOMP Receiver Controller
 *
 * @author ifzm
 * @version 0.1
 * 2019/9/28 23:13
 */

@Slf4j
@Controller
public class StompReceiver {

    @Resource
    Auths auths;

    @Resource
    SimpMessagingTemplate simpMessagingTemplate;

    @Resource
    SimpUserRegistry simpUserRegistry;

    @Resource
    StompUserRegistry stompUserRegistry;

    /**
     * 登录
     *
     * @param accessor StompHeaderAccessor
     */
    @MessageMapping("/login")
    public void login(StompHeaderAccessor accessor, String token) {
        try {
            User user = auths.getUserByToken(token);
            StompPrincipal principal = (StompPrincipal) accessor.getUser();
            assert principal != null;
            principal.setType(StompPrincipal.Type.LOGIN_USER);
            principal.setUser(user.getUsername());
            accessor.setUser(principal);
            stompUserRegistry.updateUser(accessor.getSessionId(), principal);
            log.info("STOMP user `{}` login success.", principal.getUser());
        } catch (Exception e) {
            simpMessagingTemplate.convertAndSendToUser(
                Objects.requireNonNull(accessor.getSessionId()),
                "/topic/notice",
                Result.no(Status.UNAUTHORIZED, "token 无效，登录失败！")
            );
        }
    }

    /**
     * 更新用户状态
     *
     * @param accessor 访问器
     */
    @MessageMapping("/state")
    public void state(StompHeaderAccessor accessor, String message) {
        log.info("收到来自 STOMP Client `/app/state` 消息：{}", message);

        StompPrincipal principal = (StompPrincipal) accessor.getUser();
        assert principal != null;
        principal.setOptions(JSON.parseObject(message));
        accessor.setUser(principal);
        log.info("principal info: {}", principal);

        stompUserRegistry.updateUser(accessor.getSessionId(), principal);
    }

    @MessageMapping("/test")
    public void test(StompHeaderAccessor accessor, String message) {
        log.info("收到来自 STOMP Client `/app/test` 消息：{}", message);

        Set<SimpUser> users = simpUserRegistry.getUsers();
        log.info("{}", users);

        simpMessagingTemplate.convertAndSendToUser(
            Objects.requireNonNull(accessor.getSessionId()),
            "/topic/reply",
            Result.ok(Commons.uuid())
        );
    }
}
