/* (C) 2022 YiRing, Inc. */
package com.yiring.app.stomp;

import com.yiring.app.constant.RedisKey;
import com.yiring.common.core.Redis;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.amqp.RabbitProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.messaging.simp.config.ChannelRegistration;
import org.springframework.messaging.simp.config.MessageBrokerRegistry;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.web.socket.config.annotation.EnableWebSocketMessageBroker;
import org.springframework.web.socket.config.annotation.StompEndpointRegistry;
import org.springframework.web.socket.config.annotation.WebSocketMessageBrokerConfigurer;
import org.springframework.web.socket.server.support.HttpSessionHandshakeInterceptor;

/**
 * WebSocketStompConfig
 *
 * @author ifzm
 * @version 0.1
 * 2019/9/25 20:12
 */

@Slf4j
@Configuration
@EnableScheduling
@EnableWebSocketMessageBroker
public class WebSocketStompConfig implements WebSocketMessageBrokerConfigurer {

    @Resource
    Redis redis;

    @Resource
    RabbitProperties rabbitProperties;

    @Resource
    ClientInboundChannelInterceptor clientInboundChannelInterceptor;

    @Resource
    ClientOutboundChannelInterceptor clientOutboundChannelInterceptor;

    @Override
    public void registerStompEndpoints(StompEndpointRegistry registry) {
        registry
            .addEndpoint("/stomp/ws")
            .setAllowedOriginPatterns("*")
            .addInterceptors(new HttpSessionHandshakeInterceptor())
            .withSockJS();
        log.info("Init STOMP Endpoints Success.");
    }

    @Override
    public void configureMessageBroker(MessageBrokerRegistry registry) {
        // 启动前先删除掉可能存在的残留STOMP连接缓存数据
        redis.del(RedisKey.STOMP_ONLINE_USERS);
        log.info("Clear STOMP online user info cache of redis.");

        registry.setPreservePublishOrder(true);
        registry.setUserDestinationPrefix("/user");
        registry.setApplicationDestinationPrefixes("/app");
        registry
            .enableStompBrokerRelay("/topic", "/queue")
            .setRelayHost(rabbitProperties.getHost())
            .setClientLogin(rabbitProperties.getUsername())
            .setClientPasscode(rabbitProperties.getPassword())
            .setSystemLogin(rabbitProperties.getUsername())
            .setSystemPasscode(rabbitProperties.getPassword());
        log.info("Init RabbitMQ STOMP MessageBroker Success.");
    }

    @Override
    public void configureClientInboundChannel(ChannelRegistration registration) {
        registration.interceptors(clientInboundChannelInterceptor);
    }

    @Override
    public void configureClientOutboundChannel(ChannelRegistration registration) {
        registration.interceptors(clientOutboundChannelInterceptor);
    }
}
