/* (C) 2022 YiRing, Inc. */
package com.yiring.app.util.zy;

import com.alibaba.fastjson.JSONObject;

/**
 * @author Jim
 * @version 0.1
 * 2022/5/9 16:41
 */
public class LonLatUtil {

    static final long LonLat_A = 6378137;
    static final double LonLat_B = 6356752.3142;
    static final double LonLat_F = 1 / 298.257223563;

    public static JSONObject getRoot() {
        JSONObject root = new JSONObject();
        root.put("lon", 0D);
        root.put("lat", 0D);
        root.put("x", 0D);
        root.put("y", 0D);
        root.put("altitude", 0D);
        return root;
    }

    // lon：基准点经度
    // lat：基准点纬度
    // distance：目标点离基准点距离
    // angle：目标点与基准点连线和正北方向夹角
    public static JSONObject ComputeLonLat(
        double lon,
        double lat,
        double rootX,
        double rootY,
        double postX,
        double postY
    ) {
        double distance = getDistance(rootX, rootY, postX, postY);
        double alpha1 = (Math.PI / 2) - Math.atan2(postY - rootY, postX - rootX);
        double sinAlpha1 = Math.sin(alpha1);
        double cosAlpha1 = Math.cos(alpha1);

        double tanU1 = (1 - LonLat_F) * Math.tan(Rad(lat));
        double cosU1 = 1 / Math.sqrt((1 + tanU1 * tanU1));
        double sinU1 = tanU1 * cosU1;
        double sigma1 = Math.atan2(tanU1, cosAlpha1);
        double sinAlpha = cosU1 * sinAlpha1;
        double cosSqAlpha = 1 - sinAlpha * sinAlpha;
        double uSq = cosSqAlpha * ((LonLat_A * LonLat_A) - LonLat_B * LonLat_B) / (LonLat_B * LonLat_B);
        double A = 1 + uSq / 16384 * (4096 + uSq * (-768 + uSq * (320 - 175 * uSq)));
        double B = uSq / 1024 * (256 + uSq * (-128 + uSq * (74 - 47 * uSq)));

        double sigma = distance / (LonLat_B * A);
        double sigmaP = 2 * Math.PI;
        double cos2SigmaM = Math.cos(2 * sigma1 + sigma);
        double sinSigma = Math.sin(sigma);
        double cosSigma = Math.cos(sigma);
        while (Math.abs(sigma - sigmaP) > 1e-12) {
            cos2SigmaM = Math.cos(2 * sigma1 + sigma);
            sinSigma = Math.sin(sigma);
            cosSigma = Math.cos(sigma);
            double deltaSigma =
                B *
                sinSigma *
                (
                    cos2SigmaM +
                    B /
                    4 *
                    (
                        cosSigma *
                        (-1 + 2 * cos2SigmaM * cos2SigmaM) -
                        B /
                        6 *
                        cos2SigmaM *
                        (-3 + 4 * sinSigma * sinSigma) *
                        (-3 + 4 * cos2SigmaM * cos2SigmaM)
                    )
                );
            sigmaP = sigma;
            sigma = distance / (LonLat_B * A) + deltaSigma;
        }

        double tmp = sinU1 * sinSigma - cosU1 * cosSigma * cosAlpha1;
        double lat2 = Math.atan2(
            sinU1 * cosSigma + cosU1 * sinSigma * cosAlpha1,
            (1 - LonLat_F) * Math.sqrt(sinAlpha * sinAlpha + tmp * tmp)
        );
        double lambda = Math.atan2(sinSigma * sinAlpha1, cosU1 * cosSigma - sinU1 * sinSigma * cosAlpha1);
        double C = LonLat_F / 16 * cosSqAlpha * (4 + LonLat_F * (4 - 3 * cosSqAlpha));
        double L =
            lambda -
            (1 - C) *
            LonLat_F *
            sinAlpha *
            (sigma + C * sinSigma * (cos2SigmaM + C * cosSigma * (-1 + 2 * cos2SigmaM * cos2SigmaM)));

        //        double revAz = Math.atan2(sinAlpha, -tmp); // final bearing4
        JSONObject lonLat = new JSONObject();
        lonLat.put("lon", lon + Deg(L));
        lonLat.put("lat", Deg(lat2));
        return lonLat;
    }

    public static double Rad(double d) {
        return d * Math.PI / 180.0;
    }

    public static double Deg(double d) {
        return d * 180 / Math.PI;
    }

    public static double getDistance(double rootX, double rootY, double postX, double postY) {
        double dx2 = Math.pow((rootX - postX), 2);
        double dy2 = Math.pow((rootY - postY), 2);
        double dz2 = Math.pow((0), 2);
        return Math.sqrt(dx2 + dy2 + dz2);
    }
}
