/* (C) 2022 YiRing, Inc. */
package com.yiring.app.util.zy;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import cn.hutool.http.Header;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.yiring.app.rabbit.config.ZyConfigProperties;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;
import lombok.experimental.UtilityClass;
import org.springframework.data.redis.core.RedisTemplate;

/**
 * 真源授权工具
 * @author LJ-2204
 * @date 2022/4/15
 */

@UtilityClass
public class ZyUtil {

    RedisTemplate<String, Object> redisTemplate;

    ZyConfigProperties.ZyConfigOpen zyConfigOpen;

    ZyConfigProperties.ZyConfigProxy zyConfigProxy;

    static {
        redisTemplate = SpringUtil.getBean("redisTemplate");
        zyConfigOpen = SpringUtil.getBean("zyConfigProperties.ZyConfigOpen");
        zyConfigProxy = SpringUtil.getBean("zyConfigProperties.ZyConfigProxy");
    }

    public final Integer ORG_ID = 100;

    public final String OPEN_KEY = "zy_open_token";

    //    public final String CLIENT_KEY = "zy_client_token";

    //    public final String MANAGE_KEY = "zy_manage_token";

    /**
     * 获取openToken
     * @return token
     */
    public static String openLogin() {
        Object obj = redisTemplate.opsForValue().get(OPEN_KEY);
        if (ObjectUtil.isNotEmpty(obj)) {
            return String.valueOf(obj);
        }
        Map<String, Object> map = MapUtil.createMap(HashMap.class);
        map.put("client_id", zyConfigOpen.getClientId());
        map.put("client_secret", zyConfigOpen.getClientSecret());
        map.put("grant_type", zyConfigOpen.getGrantType());
        String json = HttpUtil.get(zyConfigOpen.getApi() + "/oauth/token", map);
        JSONObject jsonObject = JSONUtil.parseObj(json);
        String access_token = Convert.toStr(jsonObject.get("access_token"));
        Integer expires_in = Convert.toInt(jsonObject.get("expires_in"));
        redisTemplate.opsForValue().set(OPEN_KEY, access_token, expires_in, TimeUnit.SECONDS);
        return access_token;
    }

    /**
     * 获取应用平台token
     * @return token
     */
    public static String clientLogin() {
        //        Object obj = redisTemplate.opsForValue().get(CLIENT_KEY);
        //        if (ObjectUtil.isNotEmpty(obj)) {
        //            return String.valueOf(obj);
        //        }
        Map<String, Object> map = MapUtil.createMap(HashMap.class);
        map.put("orgId", ORG_ID);
        map.put("tenantId", zyConfigProxy.getTenant());
        map.put("username", zyConfigProxy.getClient().getUsername());
        map.put("password", zyConfigProxy.getClient().getPassword());
        String json = HttpRequest
            .post(zyConfigProxy.getApi() + "/position/login")
            .header(Header.CONTENT_TYPE, "application/json")
            .body(JSONUtil.toJsonStr(map))
            .execute()
            .body();
        JSONObject jsonObject = JSONUtil.parseObj(json);
        //        String token = Convert.toStr(jsonObject.get("token"));
        //        redisTemplate.opsForValue().set(CLIENT_KEY, token, 1200, TimeUnit.SECONDS);
        return Convert.toStr(jsonObject.get("token"));
    }

    /**
     * 获取管理平台token
     * @return token
     */
    public static String manageLogin() {
        //        Object obj = redisTemplate.opsForValue().get(MANAGE_KEY);
        //        if (ObjectUtil.isNotEmpty(obj)) {
        //            return String.valueOf(obj);
        //        }
        Map<String, Object> map = MapUtil.createMap(HashMap.class);
        map.put("orgId", ORG_ID);
        map.put("tenantId", zyConfigProxy.getTenant());
        map.put("username", zyConfigProxy.getManage().getUsername());
        map.put("password", zyConfigProxy.getManage().getPassword());
        String json = HttpRequest
            .post(zyConfigProxy.getApi() + "/position/login")
            .header(Header.CONTENT_TYPE, "application/json")
            .body(JSONUtil.toJsonStr(map))
            .execute()
            .body();
        JSONObject jsonObject = JSONUtil.parseObj(json);
        //        String token = Convert.toStr(jsonObject.get("token"));
        //        redisTemplate.opsForValue().set(MANAGE_KEY, token, 1200, TimeUnit.SECONDS);
        return Convert.toStr(jsonObject.get("token"));
    }
}
