/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.alarm;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.domain.alarm.AlarmType;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/27 11:55
 */
@ApiModel("AlarmTypeVo(报警信息)")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class AlarmTypeVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 4743016000753778197L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "报警类型id", example = "1518841086628335616")
    private Long id;

    @ApiModelProperty(value = "报警类型名称", example = "超员报警")
    private String name;

    @ApiModelProperty(value = "围栏类别code", example = "1")
    private Integer fenceType;

    @ApiModelProperty(value = "围栏类别名称", example = "普通围栏")
    private String fenceTypeName;

    @ApiModelProperty(value = "关联参数code", example = "1")
    private Integer relevanceParam;

    @ApiModelProperty(value = "关联参数名称", example = "最多人数")
    private String relevanceParamName;

    @ApiModelProperty(value = "备注", example = "备注")
    private String comment;

    public static AlarmTypeVo transform(AlarmType alarmType) {
        return AlarmTypeVo
            .builder()
            .id(alarmType.getId())
            .name(alarmType.getName())
            .fenceType(alarmType.getFenceType())
            .fenceTypeName(FenceTypeEnum.getByCode(alarmType.getFenceType()))
            .relevanceParam(alarmType.getRelevanceParam())
            .relevanceParamName(RelevanceParamEnum.getByCode(alarmType.getRelevanceParam()))
            .comment(alarmType.getComment())
            .build();
    }
}
