/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.analysis.history;

import com.yiring.app.domain.location.LocationLog;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Point;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/6 14:18
 */
@Data
@Builder
@ApiModel("历史轨迹信息VO")
@NoArgsConstructor
@AllArgsConstructor
public class HistoryRouteVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -5915541034872568334L;

    @ApiModelProperty(value = "姓名", example = "张三")
    private String name;

    @ApiModelProperty(value = "工号", example = "ks2022")
    private String uuid;

    @ApiModelProperty(value = "经纬度")
    private Point point;

    @ApiModelProperty(value = "地图名称", example = "总图")
    private String mapName;

    @ApiModelProperty(value = "记录时间", example = "2022-05-06 14:00:00")
    private LocalDateTime writeTime;

    public static HistoryRouteVo transform(LocationLog locationLog) {
        return HistoryRouteVo
            .builder()
            .name(locationLog.getUser().getRealName())
            .uuid(locationLog.getUser().getUuid())
            .point(locationLog.getPoint())
            .writeTime(locationLog.getLocationTime())
            .build();
    }
}
