/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.dept;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.post.Post;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.HashSet;
import java.util.Set;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 部门详细信息视图
 *
 * @author LJ-2204
 * @date 2022/4/21
 */

@ApiModel("DepartmentInfoVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class DepartmentInfoVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -1765633704385903288L;

    @ApiModelProperty(value = "部门名称", example = "研发部")
    String name;

    @ApiModelProperty(value = "负责人", example = "张三")
    UserVo userVo;

    @ApiModelProperty(value = "是否启用", example = "T/F")
    Boolean enable;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "上级部门", example = "0根目录")
    Long pid;

    @ApiModelProperty(value = "上级部门名称", example = "前端")
    String pName;

    @ApiModelProperty(value = "岗位", example = "岗位")
    @Builder.Default
    Set<Post> posts = new HashSet<>(0);

    @ApiModelProperty(value = "更新时间", example = "2022-02-02 11:11:11")
    LocalDateTime updateTime;

    @ApiModelProperty(value = "创建时间", example = "2022-02-02 11:11:11")
    LocalDateTime createTime;

    public static DepartmentInfoVo transform(Department department) {
        return DepartmentInfoVo
            .builder()
            .name(department.getName())
            .userVo(UserVo.transformDept(department.getLeader()))
            .enable(department.getEnable())
            .posts(department.getPosts())
            .pid(department.getPid())
            .createTime(department.getCreateTime())
            .updateTime(department.getUpdateTime())
            .build();
    }
}
