/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.dept;

import cn.hutool.core.util.ObjectUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.dept.Department;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 部门树型视图
 *
 * @author LJ-2204
 * @date 2022/4/20
 */

@ApiModel("DepartmentVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class DepartmentVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -8193039102015929156L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "111")
    Long id;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "上级部门", example = "0根目录")
    Long pid;

    @ApiModelProperty(value = "部门名称", example = "研发部")
    String name;

    @ApiModelProperty(value = "负责人", example = "张三")
    UserVo leader;

    @ApiModelProperty(value = "是否启用", example = "T/F")
    Boolean enable;

    @ApiModelProperty(value = "上级部门名称", example = "前端")
    String pName;

    @ApiModelProperty(value = "更新时间", example = "2022-02-02 11:11:11")
    LocalDateTime updateTime;

    @ApiModelProperty(value = "创建时间", example = "2022-02-02 11:11:11")
    LocalDateTime createTime;

    @ApiModelProperty(value = "子节点")
    List<DepartmentVo> childList;

    public static DepartmentVo transform(Department department) {
        DepartmentVo departmentVo = DepartmentVo
            .builder()
            .id(department.getId())
            .name(department.getName())
            .enable(department.getEnable())
            .pid(department.getPid())
            .updateTime(department.getUpdateTime())
            .createTime(department.getCreateTime())
            .build();
        if (ObjectUtil.isNotEmpty(department.getLeader())) {
            departmentVo.setLeader(UserVo.transformDept(department.getLeader()));
        }
        return departmentVo;
    }
}
