/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.key;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.key.KeyAlarmRules;
import com.yiring.app.vo.user.UserInfoVo;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 按键报警规则
 *
 * @author LJ-2204
 * @date 2022/5/7
 */

@ApiModel("KeyAlarmRulesVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class KeyAlarmRulesVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 5083435104462641333L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "111")
    Long id;

    @ApiModelProperty(value = "部门id", example = "111")
    Long deptId;

    @ApiModelProperty(value = "部门名称", example = "Java")
    String deptName;

    @ApiModelProperty(value = "负责人", example = "111")
    List<UserInfoVo> users;

    @ApiModelProperty(value = "推送类型", example = "111")
    String types;

    public static KeyAlarmRulesVo transform(KeyAlarmRules keyAlarmRules) {
        Set<User> users = keyAlarmRules.getUsers();
        List<UserInfoVo> userInfoVos = users.stream().map(UserInfoVo::transform).collect(Collectors.toList());

        return KeyAlarmRulesVo
            .builder()
            .id(keyAlarmRules.getId())
            .deptId(keyAlarmRules.getDepartment().getId())
            .deptName(keyAlarmRules.getDepartment().getName())
            .users(userInfoVos)
            .types(keyAlarmRules.getTypes())
            .build();
    }
}
