/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.fence;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.domain.location.LocationFence;
import com.yiring.app.domain.location.LocationFenceRule;
import com.yiring.app.vo.location.rule.LocationFenceRuleVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 11:07
 */
@ApiModel("围栏信息VO")
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class LocationFenceVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 3616144084051520412L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id")
    private Long id;

    @ApiModelProperty(value = "围栏名称")
    private String name;

    @ApiModelProperty(value = "地图名称")
    private String mapName;

    @ApiModelProperty(value = "摄像头名称")
    private String videoName;

    @ApiModelProperty(value = "围栏类别code")
    private Integer fenceType;

    @ApiModelProperty(value = "围栏类别名称")
    private String fenceTypeName;

    @ApiModelProperty(value = "滞留时间(秒)")
    private Integer residenceTime;

    @ApiModelProperty(value = "消抖时间(秒)")
    private Integer threshold;

    @ApiModelProperty(value = "是否启用")
    private Boolean enable;

    @ApiModelProperty(value = "报警规则")
    private Set<LocationFenceRuleVo> rules;

    public static LocationFenceVo transform(LocationFence locationFence) {
        Set<LocationFenceRule> rules = locationFence.getRules();
        Set<LocationFenceRuleVo> collect = rules
            .stream()
            .map(LocationFenceRuleVo::transform)
            .collect(Collectors.toSet());
        return LocationFenceVo
            .builder()
            .id(locationFence.getId())
            .name(locationFence.getName())
            .mapName(locationFence.getMapName())
            .videoName(locationFence.getVideo().getVideoName())
            .fenceType(locationFence.getFenceType())
            .fenceTypeName(FenceTypeEnum.getByCode(locationFence.getFenceType()))
            .residenceTime(locationFence.getResidenceTime())
            .threshold(locationFence.getThreshold())
            .rules(collect)
            .enable(locationFence.getEnable())
            .build();
    }

    public static List<LocationFenceVo> transforms(List<LocationFence> locationFences) {
        return locationFences.stream().map(LocationFenceVo::transform).collect(Collectors.toList());
    }
}
