/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.rule;

import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.constant.alarm.InformMannerEnum;
import com.yiring.app.domain.location.LocationAlarmRule;
import com.yiring.app.vo.CodeNameVo;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/5 15:27
 */
@ApiModel("电子围栏报警规则信息")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class LocationAlarmRuleVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 8291558248133685661L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id", example = "1", required = true)
    private Long id;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "地图id", example = "1", required = true)
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "一层", required = true)
    private String mapName;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "电子围栏id", example = "1", required = true)
    private Long fenceId;

    @ApiModelProperty(value = "电子围栏名称", example = "1", required = true)
    private String fenceName;

    @ApiModelProperty(value = "接收人集合", required = true)
    private List<UserVo> users;

    @ApiModelProperty(value = "通知方式集合", required = true)
    private List<CodeNameVo> informManner;

    public static LocationAlarmRuleVo transform(LocationAlarmRule locationAlarmRule) {
        Set<User> users = locationAlarmRule.getUsers();
        List<UserVo> userVos = users.stream().map(UserVo::transformDept).collect(Collectors.toList());
        String informManner = locationAlarmRule.getInformManner();
        List<Integer> list = JSON.parseArray(informManner, Integer.class);
        ArrayList<CodeNameVo> codeNameVos = new ArrayList<>();
        for (Integer item : list) {
            codeNameVos.add(new CodeNameVo(item, InformMannerEnum.getByCode(item)));
        }
        return LocationAlarmRuleVo
            .builder()
            .id(locationAlarmRule.getId())
            .mapId(locationAlarmRule.getMapId())
            .mapName(locationAlarmRule.getMapName())
            .fenceId(locationAlarmRule.getLocationFence().getId())
            .fenceName(locationAlarmRule.getLocationFence().getName())
            .users(userVos)
            .informManner(codeNameVos)
            .build();
    }
}
