/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.rule;

import cn.hutool.core.convert.Convert;
import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.domain.location.LocationFenceRule;
import com.yiring.app.param.location.rule.RuleParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 16:16
 */
@ApiModel("修改配置报警类别的报警规则,根据不同类型传入不同参数")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class LocationFenceRuleVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -7774789748161552583L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "规则id", example = "1", required = true)
    private Long id;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "所属的围栏id", example = "1", required = true)
    private Long fenceId;

    @ApiModelProperty(value = "所属的围栏类别code", example = "1", required = true)
    private Integer fenceType;

    @ApiModelProperty(value = "所属的围栏类别名称", example = "重大危险源", required = true)
    private String fenceTypeName;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "所属的报警类别id", example = "1", required = true)
    private Long alarmTypeId;

    @ApiModelProperty(
        value = "设置的关联参数类型(1:最大人数,2:最小人数,3:允许进入人员,4:不允许离开人员,5:静止时长(分钟),6:滞留时长(分钟),7:触发报警距离)",
        example = "1",
        required = true
    )
    private Integer relevanceParamType;

    @ApiModelProperty(value = "设置的关联参数类型名称", example = "最大人数", required = true)
    private String relevanceParamTypeName;

    private RuleVo ruleVo;

    public static LocationFenceRuleVo transform(LocationFenceRule locationFenceRule) {
        String rule = locationFenceRule.getRule();
        RuleParam ruleParam = JSON.parseObject(rule, RuleParam.class);
        RuleVo ruleVo = Convert.convert(RuleVo.class, ruleParam);
        return LocationFenceRuleVo
            .builder()
            .id(locationFenceRule.getId())
            .fenceId(locationFenceRule.getFence().getId())
            .fenceType(locationFenceRule.getFence().getFenceType())
            .fenceTypeName(FenceTypeEnum.getByCode(locationFenceRule.getFence().getFenceType()))
            .alarmTypeId(locationFenceRule.getAlarmType().getId())
            .relevanceParamType(locationFenceRule.getRelevanceParamType())
            .relevanceParamTypeName(RelevanceParamEnum.getByCode(locationFenceRule.getRelevanceParamType()))
            .ruleVo(ruleVo)
            .build();
    }
}
