/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.tag;

import cn.hutool.core.util.StrUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.location.LocationTag;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 标签分配
 *
 * @author LJ-2204
 * @date 2022/4/27
 */

@ApiModel("LocationTagTypeVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationTagTypeVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -5223102796143763942L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "188354391834")
    Long id;

    @ApiModelProperty(value = "编号", example = "BTT88888888")
    String code;

    @ApiModelProperty(value = "标签型号", example = "BTT01")
    LocationTag.Type type;

    @ApiModelProperty(value = "标签类型", example = "人员")
    String tagType;

    @ApiModelProperty(value = "类型", example = "类型(1:内部/2:访客/3:承包商)")
    Integer category;

    public static LocationTagTypeVo transform(LocationTag locationTag) {
        String entityType = StrUtil.equals(locationTag.getType().name(), "BTT02") ? "car" : "staff";
        return LocationTagTypeVo
            .builder()
            .id(locationTag.getId())
            .code(locationTag.getCode())
            .type(locationTag.getType())
            .tagType(entityType)
            .category(locationTag.getCategory())
            .build();
    }
}
