/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.tag;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.location.LocationTag;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 定位标签视图
 * @author LJ-2204
 * @date 2022/4/14
 */

@ApiModel("LocationTagVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationTagVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -7884163207638158359L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "188354391834")
    Long id;

    @ApiModelProperty(value = "编号", example = "BTT88888888")
    String code;

    @ApiModelProperty(value = "标签型号", example = "BTT01")
    LocationTag.Type type;

    @ApiModelProperty(value = "状态", example = "静止")
    Boolean silent;

    @ApiModelProperty(value = "imei 设备编码", example = "88888888")
    String imei;

    @ApiModelProperty(value = "电量", example = "1")
    Integer volt;

    @ApiModelProperty(value = "最近更新时间", example = "2022-01-01 00:00:00")
    LocalDateTime updateTime;

    public static LocationTagVo transform(LocationTag locationTag) {
        return LocationTagVo
            .builder()
            .id(locationTag.getId())
            .code(locationTag.getCode())
            .type(locationTag.getType())
            .silent(locationTag.getSilent())
            .volt(locationTag.getVolt())
            .imei(locationTag.getImei())
            .updateTime(locationTag.getUpdateTime())
            .build();
    }
}
