/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.post;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.auth.domain.post.Post;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 职位详细视图
 *
 * @author LJ-2204
 * @date 2022/4/27
 */

@ApiModel("PostInfoVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PostInfoVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -8256863200798776816L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "名称", example = "Java")
    String name;

    @ApiModelProperty(value = "描述", example = "描述")
    String describe;

    @ApiModelProperty(value = "创建时间", example = "创建时间")
    LocalDateTime createTime;

    @ApiModelProperty(value = "更新时间", example = "更新时间")
    LocalDateTime updateTime;

    @ApiModelProperty(value = "职位状态", example = "true")
    Boolean enable;

    public static PostInfoVo transform(Post post) {
        return PostInfoVo
            .builder()
            .id(post.getId())
            .name(post.getName())
            .describe(post.getDescribe())
            .enable(post.getEnable())
            .createTime(post.getCreateTime())
            .updateTime(post.getUpdateTime())
            .build();
    }
}
