/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.user;

import cn.hutool.core.util.ObjectUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户详细信息模型
 *
 * @author LJ-2204
 * @date 2022/4/27
 */

@ApiModel("UserInfoVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserInfoVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -1040199557851348068L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "真实姓名", example = "超级用户")
    String realName;

    @ApiModelProperty(value = "工号", example = "8888888")
    String uuid;

    @ApiModelProperty(value = "类型", example = "员工")
    User.Type type;

    @ApiModelProperty(value = "部门", example = "系统管理员")
    String department;

    @ApiModelProperty(value = "手机号", example = "13012345678")
    String mobile;

    @ApiModelProperty(value = "职位", example = "系统管理员")
    String post;

    @ApiModelProperty(value = "邮箱", example = "developer@yiring.com")
    String email;

    @ApiModelProperty(value = "头像", example = "https://s1.ax1x.com/2022/03/30/qggJH0.jpg")
    String avatar;

    @ApiModelProperty(value = "是否启用", example = "true")
    Boolean enabled;

    @ApiModelProperty(value = "是否删除", example = "false")
    Boolean deleted;

    @ApiModelProperty(value = "是否特殊", example = "false")
    Boolean isSpecial;

    @ApiModelProperty(value = "性别", example = "false")
    Boolean gender;

    @ApiModelProperty(value = "创建时间", example = "2022-01-01 00:00:00")
    LocalDateTime createTime;

    @ApiModelProperty(value = "更新时间", example = "2022-01-01 00:00:00")
    LocalDateTime updateTime;

    public static UserInfoVo transform(User user) {
        UserInfoVo userInfoVo = UserInfoVo
            .builder()
            .id(user.getId())
            .realName(user.getRealName())
            .uuid(user.getUuid())
            .type(user.getType())
            .department(user.getDepartment().getName())
            .mobile(user.getMobile())
            .email(user.getEmail())
            .avatar(user.getAvatar())
            .enabled(user.getEnabled())
            .deleted(user.getDeleted())
            .isSpecial(user.getIsSpecial())
            .gender(user.getGender())
            .createTime(user.getCreateTime())
            .updateTime(user.getUpdateTime())
            .build();
        if (ObjectUtil.isNotEmpty(user.getPost())) {
            userInfoVo.setPost(user.getPost().getName());
        }
        return userInfoVo;
    }
}
