/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.user;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户信息
 * @author ifzm
 * 2022/03/03 10:35
 **/

@ApiModel("UserVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -2184378273450466835L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "真实姓名", example = "超级用户")
    String realName;

    @ApiModelProperty(value = "工号", example = "8888888")
    String uuid;

    @ApiModelProperty(value = "类型", example = "员工")
    User.Type type;

    @ApiModelProperty(value = "部门", example = "系统管理员")
    String department;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "部门id", example = "200")
    Long departmentId;

    @ApiModelProperty(value = "手机号", example = "13012345678")
    String mobile;

    @ApiModelProperty(value = "职位", example = "系统管理员")
    String post;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "职位id", example = "100")
    Long postId;

    @ApiModelProperty(value = "标签编号", example = "BTT88888888")
    String code;

    @ApiModelProperty(value = "是否特殊", example = "false")
    Boolean isSpecial;

    @ApiModelProperty(value = "性别", example = "false")
    Boolean gender;

    @ApiModelProperty(value = "邮箱", example = "developer@yiring.com")
    String email;

    @ApiModelProperty(value = "头像", example = "baidu.com")
    String avatar;

    public UserVo(
        Long id,
        String realName,
        String uuid,
        User.Type type,
        String department,
        String mobile,
        String post,
        String code,
        Boolean gender,
        Boolean isSpecial,
        Long departmentId,
        Long postId,
        String avatar
    ) {
        this.id = id;
        this.realName = realName;
        this.uuid = uuid;
        this.type = type;
        this.department = department;
        this.mobile = mobile;
        this.post = post;
        this.code = code;
        this.gender = gender;
        this.isSpecial = isSpecial;
        this.departmentId = departmentId;
        this.postId = postId;
        this.avatar = avatar;
    }

    public static UserVo transformDept(User user) {
        return UserVo
            .builder()
            .id(user.getId())
            .realName(user.getRealName())
            .mobile(user.getMobile())
            .email(user.getEmail())
            .build();
    }
}
