/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.visitor;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.visitor.Car;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.List;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 访客详情反参
 *
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/4/27 15:25
 */
@ApiModel("VisitorDetailsVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class VisitorDetailsVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 9004209982164273860L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id", example = "1548548545755")
    Long id;

    @ApiModelProperty(value = "到访人姓名", example = "张三")
    String visitorName;

    @ApiModelProperty(value = "到访人电话", example = "17688888888")
    String visitorMobile;

    @ApiModelProperty(value = "到访人身份证", example = "430441190001255417")
    String visitorCarNum;

    @ApiModelProperty(value = "是否特殊作业", example = "true")
    boolean taskType;

    //    @ApiModelProperty(value = "邀请人数", example = "1")
    //    Integer numOfVisitor;

    @ApiModelProperty(value = "访客来源", example = "内部邀请")
    String visitorSource;

    @ApiModelProperty(value = "标签卡", example = "WE34421231")
    String labelCard;

    //    @ApiModelProperty(value = "标签卡状态", example = "使用中")
    //    String labelCardStatus;

    @ApiModelProperty(value = "所属单位id", example = "壹润科技")
    String orgId;

    //    @ApiModelProperty(value = "被访人id", example = "1")
    //    Long intervieweeId;

    @ApiModelProperty(value = "被访人姓名", example = "李四")
    String intervieweeName;

    @ApiModelProperty(value = "来访原因", example = "来访原因")
    String reason;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "收卡时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime cardRecTime;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "预约到访时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime appOfVisitTime;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "创建时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime createTime;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "发卡时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime cardSendTime;

    @ApiModelProperty(value = "车辆反参")
    Car car;

    UserVo userVo;

    @ApiModelProperty(value = "主访人id")
    Long mainVisitorId;

    List<VisitorResultVo> list;

    @ApiModel("VisitorResultVo")
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @FieldDefaults(level = AccessLevel.PRIVATE)
    public static class VisitorResultVo implements Serializable {

        @Serial
        private static final long serialVersionUID = 4115779013003587949L;

        @JsonSerialize(using = ToStringSerializer.class)
        @ApiModelProperty(value = "id", example = "1")
        Long id;

        @ApiModelProperty(value = "到访人姓名", example = "张三")
        String visitorName;

        @ApiModelProperty(value = "到访人电话", example = "17688888888")
        String visitorMobile;

        @ApiModelProperty(value = "主访人id")
        Long mainVisitorId;
    }

    @ApiModel("UserVo")
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @FieldDefaults(level = AccessLevel.PRIVATE)
    public static class UserVo implements Serializable {

        @Serial
        private static final long serialVersionUID = 4115779013003587949L;

        @JsonSerialize(using = ToStringSerializer.class)
        @ApiModelProperty(value = "id", example = "1")
        Long id;

        @ApiModelProperty(value = "被访人姓名", example = "张三")
        String realName;

        @ApiModelProperty(value = "被访人电话", example = "17688888888")
        String mobile;

        @ApiModelProperty(value = "被访人部门")
        String deptName;
    }
}
