/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.visitor;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * @author tzl
 * 2022/4/19 14:16
 */
@ApiModel("VisitorVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class VisitorVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 9004209982164273860L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "id", example = "1548548545755")
    Long id;

    @ApiModelProperty(value = "到访人姓名", example = "张三")
    String visitorName;

    @ApiModelProperty(value = "到访人电话", example = "17688888888")
    String visitorMobile;

    @ApiModelProperty(value = "到访人身份证", example = "430441190001255417")
    String visitorCarNum;

    @ApiModelProperty(value = "是否特殊作业", example = "false")
    String taskType;

    //    @ApiModelProperty(value = "邀请人数", example = "1")
    //    Integer numOfVisitor;

    @ApiModelProperty(value = "访客来源", example = "内部邀请")
    String visitorSource;

    @ApiModelProperty(value = "标签卡", example = "WE34421231")
    String labelCard;

    //    @ApiModelProperty(value = "标签卡状态", example = "使用中")
    //    String labelCardStatus;

    @ApiModelProperty(value = "所属单位id", example = "壹润科技")
    String orgId;

    @ApiModelProperty(value = "被访人姓名", example = "李四")
    String intervieweeName;

    @ApiModelProperty(value = "来访原因", example = "来访原因")
    String reason;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(value = "收卡时间", example = "2022-04-19 14:28:00")
    LocalDateTime cardRecTime;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "预约到访时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime appOfVisitTime;

    //    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    //    @ApiModelProperty(value = "创建时间", example = "2022-04-19 14:28:00")
    //    LocalDateTime createTime;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(value = "发卡时间", example = "2022-04-19 14:28:00")
    LocalDateTime cardSendTime;

    //    @ApiModelProperty(value = "车辆反参")
    //    Car car;

    @ApiModelProperty(value = "主访人id")
    Long mainVisitorId;

    UserVo userVo;

    @ApiModel("UserVo")
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @FieldDefaults(level = AccessLevel.PRIVATE)
    public static class UserVo implements Serializable {

        @Serial
        private static final long serialVersionUID = 4115779013003587949L;

        @ApiModelProperty(value = "被访人姓名", example = "张三")
        String realName;
    }
}
