/* (C) 2021 YiRing, Inc. */
package com.yiring.app.web;

import com.yiring.app.constant.Code;
import com.yiring.app.exception.CodeException;
import com.yiring.app.util.zy.ZyUtil;
import com.yiring.common.core.Result;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import java.util.Arrays;
import java.util.List;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.Geometry;
import org.locationtech.jts.geom.Polygon;
import org.locationtech.jts.io.ParseException;
import org.locationtech.jts.io.WKTReader;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@Validated
@Api(tags = "Hello")
@RequestMapping("/hello/")
@RestController
public class HelloController {

    String text = "😎 Hello World";

    @GetMapping
    public Result<String> hello() {
        return Result.ok(text);
    }

    /**
     * 测试失败自定义状态信息输出
     */
    @GetMapping("fail")
    public Result<String> fail() {
        throw new CodeException(Code.FAIL);
    }

    @GetMapping("page")
    public Result<PageVo<String>> page(@Valid PageParam pageParam) {
        log.info("PageParam: {}", pageParam);

        List<String> data = Arrays.asList(text.split(" "));
        PageVo<String> vo = PageVo.build(data, data.size());
        return Result.ok(vo);
    }

    @GetMapping("test")
    public Result<String> test() {
        return Result.ok(ZyUtil.manageLogin());
    }

    @GetMapping("test2")
    public Result<Geometry> test2() throws ParseException {
        WKTReader reader = new WKTReader();
        Geometry geometry = reader.read(
            "POLYGON((114.13726247683384 22.57453153296995,114.13726253585672 22.57362062876488,114.1379932868094 22.57336379439826,114.13860672275516 22.573820711775532,114.13726247683384 22.57453153296995))"
        );
        Polygon polygon = (Polygon) geometry;
        return Result.ok(polygon);
    }
}
