/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.alarm;

import com.yiring.app.constant.alarm.FenceTypeEnum;
import com.yiring.app.constant.alarm.RelevanceParamEnum;
import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.param.alarm.AlarmConditionParam;
import com.yiring.app.param.alarm.AlarmTypeAddParam;
import com.yiring.app.param.alarm.AlarmTypeModifyParam;
import com.yiring.app.service.alarm.AlarmService;
import com.yiring.app.vo.CodeNameVo;
import com.yiring.app.vo.alarm.AlarmTypeVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.Objects;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Sort;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 报警类型控制器
 * @author tml
 * @version 1.0
 * @date 2022/4/27 14:18
 */
@Slf4j
@Validated
@Api(tags = "AlarmType(报警类型)")
@RestController
@RequestMapping("/alarm/type")
public class AlarmTypeController {

    @Resource
    private AlarmService alarmService;

    @ApiOperation(value = "添加报警类型")
    @PostMapping("/addAlarmType")
    public Result<String> addAlarmType(@Valid AlarmTypeAddParam param) {
        return alarmService.addAlarmType(param);
    }

    @ApiOperation(value = "修改报警类型")
    @PostMapping("/modifyAlarmType")
    public Result<String> modifyAlarmType(@Valid AlarmTypeModifyParam param) {
        return alarmService.modifyAlarmType(param);
    }

    @ApiOperation(value = "删除报警类型")
    @PostMapping("/removeAlarmType")
    public Result<String> removeAlarmType(@Valid IdParam param) {
        return alarmService.removeAlarmType(param);
    }

    @ApiOperation(value = "根据id查询报警类型")
    @PostMapping("/findById")
    public Result<AlarmTypeVo> findById(@Valid IdParam param) {
        return alarmService.findById(param);
    }

    @ApiOperation(value = "根据条件查询")
    @PostMapping("/findByCondition")
    public Result<PageVo<AlarmTypeVo>> findByCondition(
        @Valid AlarmConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        if (Objects.isNull(pageParam.getSortField())) {
            pageParam.setSortField(AlarmType.Fields.createTime);
            pageParam.setSortOrder(Sort.Direction.DESC);
        }
        return alarmService.findByCondition(conditionParam, pageParam);
    }

    @ApiOperation(value = "获取所有围栏类别")
    @GetMapping("/findAllFenceType")
    public Result<PageVo<CodeNameVo>> findAllFenceType() {
        PageVo<CodeNameVo> pageVo = PageVo.build(FenceTypeEnum.getAll(), FenceTypeEnum.TOTAL);
        return Result.ok(pageVo);
    }

    @ApiOperation(value = "获取所有关联参数")
    @GetMapping("/findAllRelevanceParam")
    public Result<PageVo<CodeNameVo>> findAllRelevanceParam() {
        PageVo<CodeNameVo> pageVo = PageVo.build(RelevanceParamEnum.getAll(), RelevanceParamEnum.TOTAL);
        return Result.ok(pageVo);
    }

    @ApiOperation(value = "报警类型导出", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("/exportAlarmType")
    public void exportAlarmType(
        @Valid AlarmConditionParam conditionParam,
        HttpServletResponse response,
        @Valid PageParam pageParam
    ) {
        alarmService.exportAlarmType(conditionParam, response, pageParam);
    }
}
