/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.broadcast;

import com.yiring.app.param.broadcast.BroadcastParam;
import com.yiring.app.param.broadcast.BroadcastQueryParam;
import com.yiring.app.service.broadcast.BroadcastService;
import com.yiring.app.vo.broadcast.BroadcastVo;
import com.yiring.app.vo.broadcast.BroadcastjcVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.Point;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/6 10:15
 */
@Slf4j
@Validated
@Api(tags = "Broadcast(播报设备管理)")
@RestController
@RequestMapping("/broadcast/")
public class BroadcastController {

    @Resource
    BroadcastService broadcastService;

    @ApiOperation(value = "新增设备信息")
    @PostMapping("saveBroadcast")
    public Result<String> saveBroadcast(@Valid BroadcastParam broadcastParam) {
        return broadcastService.saveBroadcast(broadcastParam);
    }

    @ApiOperation(value = "删除设备信息")
    @PostMapping("deleteBroadcast")
    public Result<String> deleteBroadcast(@Valid IdParam idParam) {
        return broadcastService.deleteBroadcast(idParam);
    }

    @ApiOperation(value = "修改设备信息")
    @PostMapping("updateBroadcast")
    public Result<String> updateBroadcast(@Valid BroadcastParam broadcastParam, @Valid IdParam idParam) {
        return broadcastService.updateBroadcast(broadcastParam, idParam);
    }

    @ApiOperation(value = "查看设备位置")
    @GetMapping("selectPoint")
    public Result<Point> selectPoint(@Valid IdParam idParam) {
        return broadcastService.selectPoint(idParam);
    }

    @ApiOperation(value = "分页设备信息")
    @GetMapping("pageBroadcast")
    public Result<PageVo<BroadcastVo>> pageBroadcast(@Valid BroadcastQueryParam broadcastQueryParam) {
        return broadcastService.pageBroadcast(broadcastQueryParam);
    }

    @ApiOperation(value = "导出", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("exportBroadcast")
    public void exportBroadcast(HttpServletResponse response, @Valid BroadcastQueryParam broadcastQueryParam) {
        broadcastService.exportBroadcast(broadcastQueryParam, response);
    }

    @ApiOperation(value = "导入")
    @ApiImplicitParams({ @ApiImplicitParam(value = "文件", required = true, name = "file") })
    @PostMapping("importVideo")
    public Result<String> importVideo(MultipartFile file) {
        return broadcastService.importBroadcast(file);
    }

    @ApiOperation(value = "根据名字检索")
    @GetMapping("selectBroadcastName")
    public Result<PageVo<BroadcastjcVo>> selectBroadcastName(@Valid IndexParam indexParam) {
        return broadcastService.selectBroadcastName(indexParam);
    }
}
