/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.dict;

import com.yiring.app.param.dict.DictParam;
import com.yiring.app.param.dict.DictQueryParam;
import com.yiring.app.service.dict.DictService;
import com.yiring.common.core.Result;
import com.yiring.common.dict.Dict;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import java.util.ArrayList;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 字典数据控制器
 *
 * @author tzl
 * 2022/4/13 17:10
 */
@Slf4j
@Validated
@Api(tags = "Dict")
@RestController
@RequestMapping("/Dict/")
public class DictController {

    @Resource
    DictService dictService;

    @ApiOperation(value = "新增字典信息")
    @PostMapping("saveDictInfo")
    public Result<String> saveDictInfo(@Valid DictParam dictParam) {
        return dictService.saveDictInfo(dictParam);
    }

    @ApiOperation(value = "修改字典信息")
    @PostMapping("updateDictInfo")
    public Result<String> updateDictInfo(@Valid DictParam dictParam, @Valid IdParam idParam) {
        return dictService.updateDictInfo(dictParam, idParam);
    }

    @ApiOperation(value = "删除字典信息")
    @PostMapping("deleteDictById")
    public Result<String> deleteDictById(@Valid IdParam idParam) {
        return dictService.deleteDictById(idParam);
    }

    @ApiOperation(value = "查看字典信息(分页)")
    @GetMapping("pageDictInfo")
    public Result<PageVo<Dict>> pageDictInfo(@Valid DictQueryParam queryParam, @Valid PageParam param) {
        return dictService.pageDictInfo(queryParam, param);
    }

    @ApiOperation(value = "查看字典信息详情")
    @GetMapping("getDictInfo")
    public Result<Dict> getDictInfo(@Valid IdParam idParam) {
        return dictService.getDictInfo(idParam.getId());
    }

    @ApiOperation(value = "根据类型获取字典信息详情")
    @ApiImplicitParam(value = "字典类型", example = "user_sex", required = true, name = "dictType")
    @GetMapping("selectDict")
    public Result<ArrayList<Dict>> selectDict(String dictType) {
        return dictService.selectDict(dictType);
    }
}
