/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.district;

import com.yiring.app.param.district.DistrictAddParam;
import com.yiring.app.param.district.DistrictModifyParam;
import com.yiring.app.service.district.DistrictService;
import com.yiring.app.vo.district.DistrictVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 区域管理控制器
 * @author tml
 * @version 1.0
 * @date 2022/4/26 10:15
 */
@Slf4j
@Validated
@Api(tags = "District(区域管理)")
@RestController
@RequestMapping("/district/")
public class DistrictController {

    @Resource
    private DistrictService districtService;

    @ApiOperation(value = "新增区域信息")
    @PostMapping("/addDistrict")
    public Result<String> addDistrict(@Valid @RequestBody DistrictAddParam param) {
        return districtService.addDistrict(param);
    }

    @ApiOperation(value = "修改区域信息")
    @PostMapping("/modifyDistrict")
    public Result<String> modifyDistrict(@Valid @RequestBody DistrictModifyParam param) {
        return districtService.modifyDistrict(param);
    }

    @ApiOperation(value = "删除区域信息")
    @PostMapping("/removeDistrict")
    public Result<String> removeDistrict(@Valid IdParam idParam) {
        return districtService.removeDistrict(idParam);
    }

    @ApiOperation(value = "根据区域名称模糊查询区域信息")
    @ApiImplicitParam(value = "区域名称", example = "生产", required = true, name = "name")
    @GetMapping("/findByNameLike")
    public Result<PageVo<DistrictVo>> findByNameLike(String name) {
        if (name == null) {
            name = "";
        }
        return districtService.findByNameLike(name);
    }
}
