/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.icon;

import com.yiring.app.param.icon.IconParam;
import com.yiring.app.service.icon.IconService;
import com.yiring.app.vo.icon.IconVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/5/5 15:18
 */
@Slf4j
@Validated
@Api(tags = "Icon(图标管理)")
@RestController
@RequestMapping("/icon/")
public class IconController {

    @Resource
    IconService iconService;

    @ApiOperation(value = "新增图标信息")
    @PostMapping("saveIcon")
    public Result<String> saveIcon(@Valid IconParam iconParam) {
        return iconService.saveIcon(iconParam);
    }

    @ApiOperation(value = "删除图标信息")
    @PostMapping("deleteIcon")
    public Result<String> deleteIcon(@Valid IdParam idParam) {
        return iconService.deleteIcon(idParam);
    }

    @ApiOperation(value = "修改图标信息")
    @PostMapping("updateIcon")
    public Result<String> updateIcon(@Valid IconParam iconParam, @Valid IdParam idParam) {
        return iconService.updateIcon(iconParam, idParam);
    }

    @ApiOperation(value = "分页图标信息")
    @GetMapping("pageIcon")
    public Result<PageVo<IconVo>> pageIcon(@Valid PageParam pageParam) {
        return iconService.pageIcon(pageParam);
    }
}
