/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.key;

import com.yiring.app.param.key.KeyAlarmRulesAddParam;
import com.yiring.app.param.key.KeyAlarmRulesExportParam;
import com.yiring.app.param.key.KeyAlarmRulesModifyParam;
import com.yiring.app.param.key.KeyAlarmRulesPageParam;
import com.yiring.app.service.key.KeyAlarmRulesService;
import com.yiring.app.vo.key.KeyAlarmRulesVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 按键报警规则控制器
 *
 * @author LJ-2204
 * @date 2022/5/6
 */

@Slf4j
@Validated
@Api(tags = "按键报警规则")
@RestController
@RequestMapping("/key/alarm/rules")
public class KeyAlarmRulesController {

    @Resource
    KeyAlarmRulesService keyAlarmRulesService;

    @ApiOperation("新增报警规则")
    @PostMapping("add")
    public Result<String> add(KeyAlarmRulesAddParam keyAlarmRulesAddParam) {
        return keyAlarmRulesService.add(keyAlarmRulesAddParam);
    }

    @ApiOperation("删除报警规则")
    @DeleteMapping("delete")
    public Result<String> delete(IdParam idParam) {
        return keyAlarmRulesService.delete(idParam);
    }

    @ApiOperation("更新报警规则")
    @PutMapping("modify")
    public Result<String> modify(KeyAlarmRulesModifyParam keyAlarmRulesModifyParam) {
        return keyAlarmRulesService.modify(keyAlarmRulesModifyParam);
    }

    @ApiOperation("导出")
    @GetMapping("export")
    public void export(KeyAlarmRulesExportParam keyAlarmRulesExportParam, HttpServletResponse response) {
        keyAlarmRulesService.export(keyAlarmRulesExportParam, response);
    }

    @ApiOperation("表格查询")
    @GetMapping("page")
    public Result<PageVo<KeyAlarmRulesVo>> page(KeyAlarmRulesPageParam keyAlarmRulesPageParam, PageParam pageParam) {
        return keyAlarmRulesService.page(keyAlarmRulesPageParam, pageParam);
    }
}
