/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.location.beacon;

import com.yiring.app.param.location.beacon.LocationBeaconExportParam;
import com.yiring.app.param.location.beacon.LocationBeaconFindParam;
import com.yiring.app.service.location.beacon.LocationBeaconService;
import com.yiring.app.vo.location.beacon.LocationBeaconVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 定位信标
 *
 * @author LJ-2204
 * @date 2022/4/27
 */

@Slf4j
@Validated
@Api(tags = "定位信标")
@RestController
@RequestMapping("/location/beacon/")
public class LocationBeaconController {

    @Resource
    LocationBeaconService locationBeaconService;

    @ApiOperation("添加定位信标")
    @PostMapping("saveLocationBeacon")
    public void saveLocationBeacon() {
        locationBeaconService.saveLocationBeacon();
    }

    @ApiOperation("表格查询")
    @GetMapping("findLocationBeacon")
    public Result<PageVo<LocationBeaconVo>> findLocationBeacon(
        @Valid LocationBeaconFindParam locationBeaconFindParam,
        @Valid PageParam pageParam
    ) {
        return locationBeaconService.findLocationBeacon(locationBeaconFindParam, pageParam);
    }

    @ApiOperation("导出")
    @GetMapping("exportLocationBeacon")
    public void exportLocationBeacon(
        @Valid LocationBeaconExportParam locationBeaconExportParam,
        HttpServletResponse response
    ) {
        locationBeaconService.exportLocationBeacon(locationBeaconExportParam, response);
    }
}
