/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.location.rule;

import com.yiring.app.design.check.rule.LocationFenceRuleContext;
import com.yiring.app.param.location.rule.LocationFenceRuleAddParam;
import com.yiring.app.param.location.rule.LocationFenceRuleModifyParam;
import com.yiring.app.service.location.rule.impl.LocationFenceRuleServiceImpl;
import com.yiring.app.vo.location.rule.LocationFenceRuleVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.param.IdParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/29 9:05
 */
@Slf4j
@Validated
@Api(tags = "FenceRule(电子围栏报警规则,什么情况下会报警)")
@RestController
@RequestMapping("/location/rule")
public class LocationFenceRuleController {

    @Resource
    private LocationFenceRuleServiceImpl locationFenceRuleService;

    @ApiOperation("添加一条电子围栏的报警规则")
    @PostMapping("/addRule")
    public Result<String> addRule(@Valid @RequestBody LocationFenceRuleAddParam param) {
        Result<String> result = new LocationFenceRuleContext(param.getRelevanceParamType()).paramInit(param);
        if (Status.OK.value() != result.getStatus()) {
            return result;
        }
        return locationFenceRuleService.addRule(param);
    }

    @ApiOperation("修改一条电子围栏的报警规则")
    @PostMapping("/modifyRule")
    public Result<String> modifyRule(@Valid @RequestBody LocationFenceRuleModifyParam param) {
        Result<String> result = new LocationFenceRuleContext(param.getRelevanceParamType()).paramInit(param);
        if (Status.OK.value() != result.getStatus()) {
            return result;
        }
        return locationFenceRuleService.modifyRule(param);
    }

    @ApiOperation("删除一条电子围栏的报警规则")
    @PostMapping("/removeRule")
    public Result<String> removeRule(@Valid IdParam idParam) {
        return locationFenceRuleService.removeRule(idParam);
    }

    @ApiOperation("查询一条电子围栏的报警规则")
    @PostMapping("/findRule")
    public Result<LocationFenceRuleVo> findRule(@Valid IdParam idParam) {
        return locationFenceRuleService.findRule(idParam);
    }
}
