/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.location.tag;

import com.yiring.app.param.location.tag.*;
import com.yiring.app.service.location.tag.LocationTagService;
import com.yiring.app.vo.location.tag.LocationTagIndexVo;
import com.yiring.app.vo.location.tag.LocationTagVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 定位标签
 * @author LJ-2204
 * @date 2022/4/13
 */

@Slf4j
@Validated
@Api(tags = "定位标签")
@RestController
@RequestMapping("/location/tag/")
public class LocationTagController {

    @Resource
    LocationTagService locationTagService;

    @ApiOperation("新增定位标签")
    @PostMapping("addLocationTag")
    public Result<String> addLocationTag(@Valid LocationTagAddParam locationTagAddParam) {
        return locationTagService.addLocationTag(locationTagAddParam);
    }

    @ApiOperation("分页查询")
    @GetMapping("findLocationTagPage")
    public Result<PageVo<LocationTagVo>> findLocationTagPage(
        @Valid LocationTagFindParam locationTagFindParam,
        @Valid PageParam pageParam
    ) {
        return locationTagService.findLocationTagPage(locationTagFindParam, pageParam);
    }

    @ApiOperation("条件查询")
    @GetMapping("findLocationTag")
    public Result<PageVo<LocationTagVo>> findLocationTag(@Valid LocationTagFindParam locationTagFindParam) {
        return locationTagService.findLocationTag(locationTagFindParam);
    }

    @ApiOperation("销毁定位标签")
    @DeleteMapping("deleteLocationTag")
    public Result<String> deleteLocationTag(@Valid LocationTagDeleteParam locationTagDeleteParam) {
        return locationTagService.deleteLocationTag(locationTagDeleteParam);
    }

    @ApiOperation("导出定位标签")
    @GetMapping("exportLocationTagInfo")
    public void exportLocationTagInfo(
        @Valid LocationTagExportParam locationTagExportParam,
        HttpServletResponse response
    ) {
        locationTagService.exportLocationTagInfo(locationTagExportParam, response);
    }

    @ApiOperation("导入定位标签")
    @PostMapping("importLocationTagInfo")
    public Result<String> importLocationTagInfo(@RequestParam("file") MultipartFile file) {
        return locationTagService.importLocationTagInfo(file);
    }

    /*    @ApiOperation("修改定位标签")
    @PutMapping("modifyLocationTag")
    public Result<String> modifyLocationTag(@Valid LocationTagModifyParam locationTagModifyParam) {
        return locationTagService.modifyLocationTag(locationTagModifyParam);
    }*/

    @ApiOperation("标签检索")
    @GetMapping("indexLocationTag")
    public Result<PageVo<LocationTagIndexVo>> indexLocationTag(@Valid IndexParam indexParam) {
        return locationTagService.indexLocationTag(indexParam);
    }
}
