/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.post;

import com.yiring.app.param.post.PostAddParam;
import com.yiring.app.param.post.PostExportParam;
import com.yiring.app.param.post.PostFindParam;
import com.yiring.app.param.post.PostModifyParam;
import com.yiring.app.service.post.PostService;
import com.yiring.app.vo.post.PostIndexVo;
import com.yiring.app.vo.post.PostInfoVo;
import com.yiring.app.vo.post.PostVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 职位信息控制器
 * @author LJ-2204
 * @date 2022/4/12
 */

@Slf4j
@Validated
@Api(tags = "职位信息")
@RestController
@RequestMapping("/post/")
public class PostController {

    @Resource
    PostService postService;

    @ApiOperation(value = "新增职位")
    @PostMapping("addPost")
    public Result<String> addPost(@Valid PostAddParam postAddParam) {
        return postService.addPost(postAddParam);
    }

    @ApiOperation(value = "修改职位")
    @PutMapping("modifyPost")
    public Result<String> modifyPost(@Valid PostModifyParam postModifyParam) {
        return postService.modifyPost(postModifyParam);
    }

    @ApiOperation(value = "销毁职位")
    @DeleteMapping("deletePost")
    public Result<String> deletePost(@Valid IdParam idParam) {
        return postService.deletePost(idParam);
    }

    @ApiOperation(value = "分页查询")
    @GetMapping("findPostPage")
    public Result<PageVo<PostVo>> findPostPage(@Valid PostFindParam postFindParam, @Valid PageParam pageParam) {
        return postService.findPostPage(postFindParam, pageParam);
    }

    @ApiOperation(value = "详细信息查询")
    @GetMapping("findPostById")
    public Result<PostInfoVo> findPostById(@Valid IdParam idParam) {
        return postService.findPostById(idParam);
    }

    @ApiOperation(value = "导出职位信息")
    @GetMapping("exportPostInfo")
    public void exportPostInfo(@Valid PostExportParam postExportParam, HttpServletResponse response) {
        postService.exportPostInfo(postExportParam, response);
    }

    @ApiOperation(value = "职位检索")
    @GetMapping("indexPost")
    public Result<PageVo<PostIndexVo>> indexPost(@Valid IndexParam indexParam) {
        return postService.indexPost(indexParam);
    }
}
