/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.video;

import com.yiring.app.param.video.VideoParam;
import com.yiring.app.param.video.VideoQueryParam;
import com.yiring.app.service.video.VideoService;
import com.yiring.app.vo.video.VideoNameVo;
import com.yiring.app.vo.video.VideoVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.Point;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * 监控点位控制器
 *
 * @author tzl
 * 2022/4/8 16:51
 */
@Slf4j
@Validated
@Api(tags = "Video(监控设备)")
@RestController
@RequestMapping("/video/")
public class VideoController {

    @Resource
    VideoService videoService;

    @ApiOperation(value = "新增监控点位信息")
    @PostMapping("saveVideo")
    public Result<String> saveVideo(@Valid VideoParam videoParam) {
        return videoService.saveVideo(videoParam);
    }

    @ApiOperation(value = "删除监控点位信息")
    @PostMapping("deleteVideo")
    public Result<String> deleteVideo(@Valid IdParam idParam) {
        return videoService.deleteVideo(idParam);
    }

    @ApiOperation(value = "修改监控点位信息")
    @PostMapping("updateVideo")
    public Result<String> updateVideo(@Valid VideoParam videoParam, @Valid IdParam idParam) {
        return videoService.updateVideo(videoParam, idParam);
    }

    @ApiOperation(value = "查看监控点位位置")
    @GetMapping("selectPoint")
    public Result<Point> selectPoint(@Valid IdParam idParam) {
        return videoService.selectPoint(idParam);
    }

    @ApiOperation(value = "分页查询监控点位信息")
    @GetMapping("pageVideo")
    public Result<PageVo<VideoVo>> pageVideo(@Valid VideoQueryParam videoQueryParam) {
        return videoService.pageVideo(videoQueryParam);
    }

    @ApiOperation(value = "导出", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("exportVideo")
    public void exportVideo(HttpServletResponse response, @Valid VideoQueryParam videoQueryParam) {
        videoService.exportVideo(videoQueryParam, response);
    }

    @ApiOperation(value = "导入")
    @ApiImplicitParams({ @ApiImplicitParam(value = "文件", required = true, name = "file") })
    @PostMapping("importVideo")
    public Result<String> importVideo(MultipartFile file) {
        return videoService.importVideo(file);
    }

    @ApiOperation(value = "根据监控点位名称模糊查询")
    @GetMapping("findByVideoNameLike")
    public Result<VideoNameVo> findByVideoNameLike(@Valid IndexParam indexParam) {
        return videoService.findByVideoNameLike(indexParam);
    }
}
