/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.visitor;

import com.yiring.app.param.visitor.CarQueryParam;
import com.yiring.app.service.visitor.CarService;
import com.yiring.app.vo.visitor.CarVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 车辆来访信息控制器
 *
 * @author tzl
 * 2022/4/11 17:02
 */
@Slf4j
@Api(tags = "Car(车辆)")
@Validated
@RestController
@RequestMapping("/Car/")
public class CarController {

    @Resource
    CarService carService;

    //    @ApiOperation(value = "新增车辆来访信息")
    //    @PostMapping("saveCarInfo")
    //    public Result<Long> saveCarInfo(@Valid CarParam carParam) {
    //        return carService.saveCarInfo(carParam);
    //    }

    //    @ApiOperation(value = "修改车辆来访信息")
    //    @PostMapping("updateCarInfo")
    //    public Result<Long> updateCarInfo(@Valid CarParam carParam, @Valid IdParam idParam) {
    //        return carService.updateCarInfo(carParam, idParam);
    //    }

    @ApiOperation(value = "收卡")
    @PostMapping("cardRec")
    public Result<Long> cardRec(@Valid IdParam idParam) {
        return carService.cardRec(idParam);
    }

    @ApiOperation(value = "发卡")
    @ApiImplicitParam(value = "标签卡", example = "DW8544568", required = true, name = "labelCard")
    @PostMapping("cardSend")
    public Result<Long> cardSend(@Valid IdParam idParam, String labelCard) {
        return carService.cardSend(idParam, labelCard);
    }

    //    @ApiOperation(value = "删除车辆来访信息")
    //    @PostMapping("deleteCarInfo")
    //    public Result<String> deleteCarInfo(@Valid IdParam idParam) {
    //        return carService.deleteCarInfo(idParam);
    //    }

    //    @ApiOperation(value = "查看车辆来访信息详情")
    //    @GetMapping("getCarInfo")
    //    public Result<CarVo> getCarInfo(@Valid IdParam idParam) {
    //        return carService.getCarInfo(idParam);
    //    }

    @ApiOperation(value = "查看车辆来访信息(分页)")
    @GetMapping("pageCarInfo")
    public Result<PageVo<CarVo>> pageCarInfo(@Valid CarQueryParam carParam) {
        return carService.pageCarInfo(carParam);
    }

    @ApiOperation(value = "导出车辆来访信息", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("exportCarInfo")
    public void exportCarInfo(HttpServletResponse response, @Valid CarQueryParam carParam) {
        carService.export(carParam, response);
    }
}
