/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.visitor;

import com.yiring.app.param.visitor.InvitationAppQueryParam;
import com.yiring.app.param.visitor.InvitationParam;
import com.yiring.app.param.visitor.InvitationQueryParam;
import com.yiring.app.service.visitor.InvitationService;
import com.yiring.app.vo.visitor.InvitationDetailsVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tzl
 * @version 1.0
 * @description:
 * @date 2022/4/25 11:35
 */
@Slf4j
@Validated
@Api(tags = "Invitation(邀请)")
@RestController
@RequestMapping("/invitation/")
public class InvitationController {

    @Resource
    InvitationService invitationService;

    @ApiOperation(value = "新增邀请信息")
    @PostMapping("saveInv")
    public Result<String> saveInv(@Valid InvitationParam invitationParam) {
        return invitationService.saveInv(invitationParam);
    }

    @ApiOperation(value = "修改邀请信息")
    @PostMapping("updateInv")
    public Result<String> updateInv(@Valid InvitationParam invitationParam, @Valid IdParam idParam) {
        return invitationService.updateInv(invitationParam, idParam);
    }

    @ApiOperation(value = "撤回")
    @PostMapping("recallInv")
    public Result<String> recallInv(@Valid IdParam idParam) {
        return invitationService.recallInv(idParam);
    }

    @ApiOperation(value = "发起邀请")
    @PostMapping("sendInv")
    public Result<String> sendInv(@Valid IdParam idParam) {
        return invitationService.sendInv(idParam);
    }

    @ApiOperation(value = "删除邀请")
    @PostMapping("deleteInv")
    public Result<String> deleteInv(@Valid IdParam idParam) {
        return invitationService.deleteInv(idParam);
    }

    @ApiOperation(value = "查看邀请信息(分页)")
    @GetMapping("pageInv")
    public Result<PageVo<InvitationDetailsVo>> pageInv(@Valid InvitationQueryParam invitationQueryParam) {
        return invitationService.pageInv(invitationQueryParam);
    }

    @ApiOperation(value = "导出邀请信息", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("exportInv")
    public void exportInv(HttpServletResponse response, @Valid InvitationQueryParam invitationQueryParam) {
        invitationService.exportInv(invitationQueryParam, response);
    }

    @ApiOperation(value = "小程序查看邀请详情")
    @GetMapping("detailsInv")
    public Result<InvitationDetailsVo> detailsInv(@Valid IdParam idParam) {
        return invitationService.detailsInv(idParam);
    }

    @ApiOperation(value = "小程序查看邀请")
    @GetMapping("appGetInv")
    public Result<PageVo<InvitationDetailsVo>> appGetInv(@Valid InvitationAppQueryParam invitationAppQueryParam) {
        return invitationService.findAllByVisitor_VisitorMobileAndVisitor_Deleted(invitationAppQueryParam);
    }
}
