/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.visitor;

import com.yiring.app.param.visitor.VisitorAppQueryParam;
import com.yiring.app.param.visitor.VisitorParam;
import com.yiring.app.param.visitor.VisitorQueryParam;
import com.yiring.app.service.visitor.VisitorService;
import com.yiring.app.vo.visitor.VisitorAppVo;
import com.yiring.app.vo.visitor.VisitorDetailsVo;
import com.yiring.app.vo.visitor.VisitorVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tzl
 * 2022/4/21 9:50
 */
@Slf4j
@Validated
@Api(tags = "Visitor(访客)")
@RestController
@RequestMapping("/visitor/")
public class VisitorController {

    @Resource
    VisitorService visitorService;

    @ApiOperation(value = "新增访客信息")
    @PostMapping("saveVisitor")
    public Result<String> saveVisitor(@Valid VisitorParam visitorParam) {
        return visitorService.saveVisitor(visitorParam);
    }

    @ApiOperation(value = "修改访客信息")
    @PostMapping("updateVisitor")
    public Result<String> updateVisitor(@Valid VisitorParam visitorParam, @Valid IdParam idParam) {
        return visitorService.updateVisitor(visitorParam, idParam);
    }

    @ApiOperation(value = "收卡")
    @PostMapping("cardRec")
    public Result<String> cardRec(@Valid IdParam idParam) {
        return visitorService.cardRec(idParam);
    }

    @ApiOperation(value = "发卡")
    @ApiImplicitParam(value = "标签卡", example = "DW8544568", required = true, name = "labelCard")
    @PostMapping("cardSend")
    public Result<String> cardSend(@Valid IdParam idParam, String labelCard) {
        return visitorService.cardSend(labelCard, idParam);
    }

    //    @ApiOperation(value = "删除访客信息")
    //    @PostMapping("deleteVisitor")
    //    public Result<String> deleteVisitor(@Valid IdParam idParam) {
    //        return visitorService.deleteVisitor(idParam);
    //    }

    @ApiOperation(value = "查看访客信息详情")
    @GetMapping("selectVisitor")
    public Result<VisitorDetailsVo> selectVisitor(@Valid IdParam idParam) {
        return visitorService.selectVisitor(idParam);
    }

    @ApiOperation(value = "查看访客信息(分页)")
    @GetMapping("pageVisitor")
    public Result<PageVo<VisitorVo>> pageVisitor(@Valid VisitorQueryParam visitorQueryParam) {
        return visitorService.pageVisitor(visitorQueryParam);
    }

    @ApiOperation(value = "导出访客信息", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    @PostMapping("exportVisitor")
    public void exportVisitor(HttpServletResponse response, @Valid VisitorQueryParam visitorQueryParam) {
        visitorService.exportVisitor(visitorQueryParam, response);
    }

    @ApiOperation(value = "小程序查看来访历史(分页)")
    @GetMapping("selectInfo")
    public Result<PageVo<VisitorAppVo>> selectInfo(@Valid VisitorAppQueryParam visitorAppQueryParam) {
        return visitorService.selectInfo(visitorAppQueryParam);
    }
}
