/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.config;

import cn.dev33.satoken.interceptor.SaRouteInterceptor;
import cn.dev33.satoken.router.SaHttpMethod;
import cn.dev33.satoken.router.SaRouter;
import cn.dev33.satoken.stp.StpUtil;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

/**
 * 路由拦截器鉴权
 *
 * @author Jim
 * @version 0.1
 * 2022/1/28 20:35
 */

@Configuration
public class SaTokenConfigure implements WebMvcConfigurer {

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        // 注册Sa-Token的路由拦截器
        registry
            .addInterceptor(
                new SaRouteInterceptor((req, res, handler) -> {
                    // 登录认证 -- 拦截所有路由，并排除 /auth/** 用于开放授权相关, 以及 swagger 相关
                    SaRouter
                        .match("/**")
                        .notMatchMethod(SaHttpMethod.OPTIONS.name())
                        // 实现用户权限相关后应移除下行代码
                        // .notMatch("/**")
                        // 示例接口
                        .notMatch("/hello/**")
                        // 授权相关接口（登录、登出、注册等）
                        .notMatch("/auth/**")
                        .notMatch("/favicon.ico", "/**/*.html", "/**/*.js", "/**/*.css")
                        .notMatch("/v2/api-docs", "/v3/api-docs", "/swagger-resources/**")
                        .check(r -> StpUtil.checkLogin());
                })
            )
            .addPathPatterns("/**");
    }
}
