/* (C) 2021 YiRing, Inc. */
package com.yiring.auth.param;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.Arrays;
import java.util.Set;
import java.util.stream.Collectors;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 公共的 ID 集合查询参数类
 *
 * @author ifzm
 * @version 0.1
 * 2019/5/28 22:11
 */
@ApiModel("IdsParam")
@Valid
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class IdsParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -8379896695668632733L;

    @ApiModelProperty(value = "ids 多个以逗号分割", example = "1,2", required = true)
    @NotEmpty(message = "ids 不能为空")
    String ids;

    /**
     * 获取 Long 类型的 ID 集合
     * @return ID 集合
     */
    public Set<Long> toIds() {
        return Arrays.stream(this.ids.split(",")).map(Long::parseLong).collect(Collectors.toSet());
    }
}
