/* (C) 2021 YiRing, Inc. */
package com.yiring.auth.param.auth;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户注册参数
 *
 * @author ifzm
 * @version 0.1
 * 2019/5/28 22:11
 */
@ApiModel("RegisterParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class RegisterParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -8690942241103456895L;

    @ApiModelProperty(value = "用户名", example = "admin", required = true)
    @NotEmpty(message = "用户名不能为空")
    String username;

    @ApiModelProperty(value = "密码", example = "123456", required = true)
    @NotEmpty(message = "密码不能为空")
    String password;

    @ApiModelProperty(value = "真实姓名", example = "管理员", required = true)
    @NotEmpty(message = "真实姓名不能为空")
    String realName;

    @ApiModelProperty(value = "手机号", example = "13012345678", required = true)
    @NotEmpty(message = "手机号不能为空")
    @Pattern(regexp = "^1[0-9]{10}$", message = "手机号码格式不正确")
    String mobile;

    @ApiModelProperty(value = "头像", example = "https://s1.ax1x.com/2022/03/30/qggJH0.jpg")
    String avatar;

    @ApiModelProperty(value = "邮箱", example = "developer@yiring.com")
    String email;

    @ApiModelProperty(value = "简介", example = "平台管理员")
    String introduction;

    @ApiModelProperty(value = "是否启用", example = "true")
    Boolean enable;
}
