/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.param.permission;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.yiring.auth.domain.permission.Permission;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 权限信息入参类
 * @author Jim
 * @version 0.1
 * 2022/3/25 17:09
 */

@JsonInclude(JsonInclude.Include.NON_NULL)
@ApiModel("AddPermissionParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PermissionParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -6781934969837655538L;

    @ApiModelProperty(value = "权限类型", example = "MENU", required = true)
    @NotNull(message = "权限类型不能为空")
    Permission.Type type;

    @ApiModelProperty(value = "序号", example = "1")
    Integer serial;

    @ApiModelProperty(value = "标识", example = "Dashboard", required = true)
    @NotEmpty(message = "权限标识不能为空")
    String uid;

    @ApiModelProperty(value = "名称", example = "Dashboard", required = true)
    @NotEmpty(message = "权限名称不能为空")
    String name;

    @ApiModelProperty(value = "路径", example = "/dashboard")
    String path;

    @ApiModelProperty(value = "重定向", example = "/dashboard/workbench")
    String redirect;

    @ApiModelProperty(value = "组件", example = "LAYOUT")
    String component;

    @ApiModelProperty(value = "图标", example = "ion:grid-outline")
    String icon;

    @ApiModelProperty(value = "是否隐藏", example = "false")
    Boolean hidden;

    @ApiModelProperty(value = "是否启用", example = "true")
    Boolean enable;

    @ApiModelProperty(value = "父级ID", example = "0")
    @Builder.Default
    Long pid = 0L;

    @ApiModelProperty(
        value = "元数据",
        example = "{\"title\": \"routes.dashboard.dashboard\", \"hideChildrenInMenu\": true}"
    )
    String meta;
}
