/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.util;

import cn.dev33.satoken.exception.NotLoginException;
import cn.dev33.satoken.stp.StpUtil;
import com.yiring.auth.domain.user.User;
import com.yiring.auth.domain.user.UserRepository;
import com.yiring.common.core.Status;
import java.util.Objects;
import java.util.Optional;
import javax.annotation.Resource;
import lombok.NonNull;
import org.springframework.stereotype.Component;

/**
 * 认证工具类
 *
 * @author Jim
 * @version 0.1
 * 2022/4/8 17:34
 */

@SuppressWarnings("unused")
@Component
public class Auths {

    @Resource
    UserRepository userRepository;

    /**
     * 根据 Token 获取用户信息
     * 如果用户未登录或校验失败会抛出 NotLoginException {@link Status#UNAUTHORIZED}
     * @param token token
     * @return 用户信息
     */
    public User getUserByToken(@NonNull String token) {
        Object id = StpUtil.getLoginIdByToken(token);
        if (id == null) {
            StpUtil.logoutByTokenValue(token);
            throw NotLoginException.newInstance(StpUtil.TYPE, null);
        }

        Optional<User> optional = userRepository.findById(Long.valueOf(Objects.toString(id)));
        if (optional.isEmpty()) {
            StpUtil.logout(id);
            throw NotLoginException.newInstance(StpUtil.TYPE, NotLoginException.INVALID_TOKEN);
        }

        return optional.get();
    }

    /**
     * 获取当前登录用户
     * 如果用户未登录会抛出 NotLoginException {@link Status#UNAUTHORIZED}
     */
    public User getLoginUser() {
        String token = StpUtil.getTokenValue();
        if (token == null) {
            throw NotLoginException.newInstance(StpUtil.TYPE, null);
        }

        return getUserByToken(token);
    }
}
