/* (C) 2022 YiRing, Inc. */
package com.yiring.common.config;

import java.util.concurrent.Executor;
import java.util.concurrent.ThreadPoolExecutor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

/**
 * 线程池
 * @author LJ-2204
 * @date 2022/4/18
 */

@Configuration
@EnableAsync
@Slf4j
public class ExecutorConfig {

    @Bean("httpThreadPool")
    public Executor asyncServiceExecutor() {
        log.info("start asyncServiceExecutor");

        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        //配置核心线程数
        executor.setCorePoolSize(10);
        //配置最大线程数
        executor.setMaxPoolSize(100);
        //配置队列大小
        executor.setQueueCapacity(10000);
        //配置线程池中的线程的名称前缀
        //线程池维护线程所允许的空闲时间
        executor.setKeepAliveSeconds(60);
        executor.setThreadNamePrefix("async--");

        // rejection-policy：当pool已经达到maxsize的时候，如何处理新任务
        // CALLER_RUNS：不在新线程中执行任务，而是有调用者所在的线程来执行
        executor.setRejectedExecutionHandler(new ThreadPoolExecutor.CallerRunsPolicy());
        //执行初始化
        executor.initialize();

        return executor;
    }
}
