/* (C) 2022 YiRing, Inc. */
package com.yiring.common.dict;

import java.io.Serializable;
import java.util.List;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author tzl
 * 2022/4/13 15:32
 */
public interface DictRepository extends JpaRepository<Dict, Serializable>, JpaSpecificationExecutor<Dict> {
    /**
     * 根据字典类型和字典键值查询字典数据信息
     *
     * @param dictType  String
     * @param dictValue String
     * @return 字典标签
     */
    @Query("select dictLabel from Dict where dictType = ?1 and dictValue = ?2")
    String findDictLabel(String dictType, String dictValue);

    /**
     * 根据字典类型查询所有启用的字典数据
     *
     * @param dictType 字典类型
     * @return 字典数据集合
     */
    @Query("select d from Dict d where d.dictType = ?1")
    List<Dict> findByDictType(String dictType);

    @Modifying
    @Transactional
    @Query("update Dict set dictType=?1 where dictType=?2")
    boolean updateDictType(String param, String dictType);
}
