/* (C) 2021 YiRing, Inc. */
package com.yiring.common.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 分页查询响应公共类
 *
 * @author ifzm
 * @version 0.1 2019/3/10 16:29
 */
@ApiModel("PageVo")
@Data
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class PageVo<T extends Serializable> implements Serializable {

    @Serial
    private static final long serialVersionUID = 6103761701912769946L;

    @ApiModelProperty(value = "数据")
    List<T> data;

    @ApiModelProperty(value = "数据总数", example = "100")
    Long total;

    /**
     * 通常在带有时效性的数据查询时有用途（可选参数）
     */
    @ApiModelProperty(value = "数据最新时间")
    LocalDateTime latest;

    /**
     * 构建一个 PageVo
     * @param data 数据
     * @param total 总数据量
     * @return PageVo
     */
    @SuppressWarnings({ "unused" })
    public static <R extends Serializable> PageVo<R> build(List<R> data, long total) {
        return build(data, total, null);
    }

    /**
     * 构建一个 PageVo
     * @param data 数据
     * @param total 总数据量
     * @param latest 数据最新时间
     * @return PageVo
     */
    @SuppressWarnings({ "unused" })
    public static <R extends Serializable> PageVo<R> build(List<R> data, long total, LocalDateTime latest) {
        PageVo<R> vo = new PageVo<>();
        vo.setData(data);
        vo.setTotal(total);
        vo.setLatest(latest);
        return vo;
    }
}
