/* (C) 2022 YiRing, Inc. */
package com.yiring.common.web;

import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import com.yiring.common.core.Minio;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import io.minio.ObjectWriteResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * Minio S3
 */

@Slf4j
@Validated
@Api(tags = "Minio")
@RestController
@RequestMapping("/common/minio/")
public class MinioController {

    @Resource
    Minio minio;

    /**
     * minio 上传文件，成功返回文件 url
     */
    @ApiOperation(value = "文件上传")
    @PostMapping(value = "upload", headers = "Content-Type=Multipart/Form-Data")
    public Result<String> upload(@ApiParam(value = "文件", required = true) @RequestPart("file") MultipartFile file) {
        try {
            Snowflake snowflake = IdUtil.getSnowflake(1, 1);
            long uuid = snowflake.nextId();

            // 文件上传
            String folder =
                "upload/" + LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy/M/d")) + "/" + uuid;
            ObjectWriteResponse response = minio.putObject(file, folder);
            String uri = minio.getURI(response.object());
            return Result.ok(uri);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.no(Status.BAD_REQUEST, "上传失败");
        }
    }
}
